(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    268741,       5270]
NotebookOptionsPosition[    266294,       5219]
NotebookOutlinePosition[    266670,       5235]
CellTagsIndexPosition[    266627,       5232]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Travelling salesman problem", "Title",
 CellChangeTimes->{{3.8498659197237196`*^9, 3.8498659353906155`*^9}, {
   3.8502884358260317`*^9, 3.850288452690901*^9}, {3.8504078931535835`*^9, 
   3.8504079297240343`*^9}, {3.8587553024030123`*^9, 3.8587553131456265`*^9}, 
   3.8590119899661674`*^9},ExpressionUUID->"b15229c8-5a8d-4e56-afb3-\
39951f71899b"],

Cell[CellGroupData[{

Cell["Problem setup", "Section",
 CellChangeTimes->{{3.850284992156113*^9, 3.8502851174278107`*^9}, {
  3.8502884635283027`*^9, 3.8502884649516716`*^9}, {3.850407943113345*^9, 
  3.8504079457856646`*^9}, {3.8504449061005325`*^9, 3.8504449155490723`*^9}, {
  3.850446227606118*^9, 3.8504462511734657`*^9}, {3.8587553227221746`*^9, 
  3.8587553695458527`*^9}, {3.858764261860464*^9, 3.858764277268345*^9}, {
  3.859011999602493*^9, 3.8590120411627245`*^9}, {3.859038099864771*^9, 
  3.85903812597431*^9}, {3.859038242820649*^9, 
  3.8590382494144087`*^9}},ExpressionUUID->"d8dca711-7222-4483-a9ec-\
b9d0ca08e28e"],

Cell["Random cities on a square:", "Text",
 CellChangeTimes->{{3.8590381385441203`*^9, 
  3.859038158854045*^9}},ExpressionUUID->"591d67b5-7567-4a89-ab20-\
371f0f8ac8f8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"distribution", "=", "\"\<TwoSquares\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "40"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", "0.0"}], ";", 
  RowBox[{"xmax", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymin", "=", "0.0"}], ";", 
  RowBox[{"ymax", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"distribution", "\[Equal]", "\"\<Random\>\""}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"cities", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RandomReal", "[", 
          RowBox[{"{", 
           RowBox[{"xmin", ",", "xmax"}], "}"}], "]"}], ",", 
         RowBox[{"RandomReal", "[", 
          RowBox[{"{", 
           RowBox[{"ymin", ",", "ymax"}], "}"}], "]"}]}], "}"}], ",", "n"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"distribution", "\[Equal]", "\"\<Circle\>\""}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x0", ",", "y0"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"xmin", "+", "xmax"}], ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ymin", "+", "ymax"}], ")"}], "/", "2"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "2"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cities", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x0", "+", 
           RowBox[{"r", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"i", "*", "2", "*", 
              RowBox[{"\[Pi]", "/", "n"}]}], "]"}]}]}], ",", 
          RowBox[{"y0", "+", 
           RowBox[{"r", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"i", "*", "2", "*", 
              RowBox[{"\[Pi]", "/", "n"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"distribution", "\[Equal]", "\"\<TwoSquares\>\""}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"cities", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"xmin", ",", 
             RowBox[{"xmax", "/", "3"}]}], "}"}], "]"}], ",", 
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"ymin", ",", 
             RowBox[{"ymax", "/", "3"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"n", "/", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"cities", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"cities", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"RandomReal", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"xmax", "/", "3"}]}], ",", "xmax"}], "}"}], "]"}], 
            ",", 
            RowBox[{"RandomReal", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"ymax", "/", "3"}]}], ",", "ymax"}], "}"}], "]"}]}], 
           "}"}], ",", 
          RowBox[{"n", "/", "2"}]}], "]"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"distances", "=", 
   RowBox[{"DistanceMatrix", "[", "cities", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"NumberForm", "[", 
    RowBox[{
     RowBox[{"MatrixForm", "[", "distances", "]"}], ",", "3"}], "]"}], " ", 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.8590365131599*^9, 3.85903652234002*^9}, 
   3.859037811944024*^9, {3.859037922938665*^9, 3.8590379798048615`*^9}, {
   3.8590381327143497`*^9, 3.859038176254588*^9}, {3.859038286614098*^9, 
   3.8590385552547655`*^9}, {3.8590386451253033`*^9, 3.859038728154519*^9}, {
   3.859038822865164*^9, 3.859038863555127*^9}, {3.8590511361208134`*^9, 
   3.859051142830429*^9}, {3.859375273298732*^9, 3.859375274406795*^9}, {
   3.859382941597333*^9, 3.8593829426183915`*^9}, 3.8593837529137383`*^9, {
   3.859383886145358*^9, 3.859384007199282*^9}, {3.8593840711669407`*^9, 
   3.859384136080654*^9}, {3.8593841730337677`*^9, 3.859384225198751*^9}, {
   3.8593842636179485`*^9, 3.8593842726224637`*^9}, {3.859384330135753*^9, 
   3.859384330988802*^9}, {3.8593843660378065`*^9, 3.859384366644841*^9}, {
   3.859384400942803*^9, 3.8593844027639074`*^9}, {3.859431277105966*^9, 
   3.8594312956950293`*^9}},ExpressionUUID->"45a6232c-391f-4210-9514-\
9e5d2300345f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Efficient built-in algorithm to find the shortest  tour  in Mathematica\
\>", "Section",
 CellChangeTimes->{{3.850284992156113*^9, 3.8502851174278107`*^9}, {
  3.8502884635283027`*^9, 3.8502884649516716`*^9}, {3.850407943113345*^9, 
  3.8504079457856646`*^9}, {3.8504449061005325`*^9, 3.8504449155490723`*^9}, {
  3.850446227606118*^9, 3.8504462511734657`*^9}, {3.8587553227221746`*^9, 
  3.8587553695458527`*^9}, {3.858764261860464*^9, 3.858764277268345*^9}, {
  3.859011999602493*^9, 3.8590120411627245`*^9}, {3.859038099864771*^9, 
  3.85903812597431*^9}, {3.8590391126761723`*^9, 
  3.859039180985834*^9}},ExpressionUUID->"0df30b08-34d4-4ecd-a531-\
7a8c91a746de"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"shortest", "=", 
   RowBox[{"FindShortestTour", "[", "cities", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The length of the shortest tour is \>\"", ",", " ", 
    RowBox[{
    "shortest", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
   "]"}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{
          "cities", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          ",", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"PointSize", "[", "Medium", "]"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Graphics", "[", 
     RowBox[{"Line", "[", 
      RowBox[{"cities", "\[LeftDoubleBracket]", 
       RowBox[{
       "shortest", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       "\[RightDoubleBracket]"}], "]"}], "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.859355617199467*^9, 3.8593556487112694`*^9}, {
   3.8593558292805977`*^9, 3.8593558355259542`*^9}, 3.859355889204025*^9, {
   3.8593562623793693`*^9, 3.8593562929231167`*^9}, {3.859383746690382*^9, 
   3.8593837926100082`*^9}},
 CellLabel->
  "In[1064]:=",ExpressionUUID->"bd16330c-020d-4e25-9e43-640650c07835"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The length of the shortest tour is \"\>", "\[InvisibleSpace]", 
   "7.56889700800269`"}],
  SequenceForm["The length of the shortest tour is ", 7.56889700800269],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.859356333442434*^9, 3.859374003396097*^9, 3.859381985561651*^9, 
   3.859382978914468*^9, {3.8593837746749825`*^9, 3.8593837886617823`*^9}, 
   3.8593838275090046`*^9, 3.859383930110873*^9, 3.8593844449693213`*^9},
 CellLabel->
  "During evaluation of \
In[1064]:=",ExpressionUUID->"815fad7b-1d82-491a-8c80-efec2fa79ac3"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwBkQJu/SFib1JlAgAAACgAAAACAAAAG99uOqNN4j9OC28MQcnbP0w/b4aY
4MQ/RiHZGk1I2T/aoM4LJb/RP7Z8g1iBmtg/P5LWzeBc4D85qGoN7BDlP5Cf
UEGNK80/Yt3M2u9+3T8WjCcaYHncP3j3hoWfuLI/bh7NR/Fn2T+qLqL88dDa
P87mIazwQNs/y7esCoE65D9A7b18IziIP7KvUhp1xNY/WOXQEt1nsT9cOYHS
uKvNPxC7YyygRa4/Jgr7Fc/i0z/w6TiJYJ6tP4vmLm8cNuU/himPpWKO3j8R
vOmHW6LgP6QNa9An5cE/MFZqDegu1D8yaHERL0fbP2iW7Tif97s/Ty5e/pYQ
4T+JqA+Ay6riP+Rob8XRDc4/dLo8ksFgyD8dOQzXdF/kP9HnjokpJeI/hrE4
Bxup2D8upjetJ+jePyMYl2JJTeQ/45KPiRRp5D8T2Ia3f1n3PzHiibFsvfs/
lcUz2Urh9T+1L76+rqn8P26L2TJAuv8/BYaVIpM//D8VvLtjC1X8P2dSk41P
U/4/cx6V+TZ5/T+9yGCxx3f1P6rdfIABkPo/uUk8s3lf+D/MdEWyaLf1PygV
j1Q7J/Y/FEIaGK2Y+z8EiOwO0Zr/P3XpFXYK8v4/ORYnFvll+D9N/G51d7z7
P0RXKTs11Pk/5WS4S+i6+j/133u/eOj7P+nunTLZiPo//FrDfP14/j9X/G1Z
OvP/P6z1fJavXPk/9lhuNgiJ+D/kjmFWFnb8P+hjovESm/0/MID0nZ/Q/z9B
/62+nYL1P2JrrOT/afk/CSXmu+Lt/T+ZjTtk8fj6P0jBfFkjjfg/38TKHgtE
9j+/7s/bg7n8P1CDRm+E0vk/0SDQpZNm/T89JtA67lf3P8KYTjc=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
       AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
       AbsoluteThickness[1.6]}, {}}, {
      TagBox[
       {Opacity[0.], PointBox[{{0.5719772473594021, 0.4341585751937388}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {1}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.1631041199129818, 0.395037914484892}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {2}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.27729154732743455`, 0.38443025249393814`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {3}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.5113376636769046, 0.6583156835597556}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {4}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.22789159478383825`, 0.46087261550152026`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {5}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.4449081664481026, 0.07312962541524637}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {6}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.39696914684143436`, 0.419003006660868}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {7}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.42583863076980044`, 0.6321416100015481}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {8}}]& ], 
      TagBox[
       {Opacity[0.], 
        PointBox[{{0.011825825924225541`, 0.35574081011395287`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {9}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.06799108228087414, 0.23180303839257987`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {10}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.05912495176186472, 0.310718318429425}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {11}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.05784894633366722, 0.6628553554102877}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {12}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.4774405113972978, 0.5198190359641349}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {13}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.13980577160519403`, 0.3153629427918956}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {14}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.42621971801202385`, 0.10924716129155743`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {15}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.5332751243708546, 0.5833489896006238}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {16}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.23479673519506783`, 0.19045276298989544`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {17}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.6366523933554934, 0.5670364081081464}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {18}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.38532138543339334`, 0.48291961589584076`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {19}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.6344344068136291, 0.6378271757826862}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {20}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.4593503159535473`, 1.7337462363340246`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {21}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.3675030216657877`, 1.7914264155287871`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {22}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.9829713808364562`, 1.7655211783352354`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {23}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7707628150781194`, 1.8953395395557437`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {24}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8420934438053365`, 1.3417431763487422`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {25}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.6601576823285122`, 1.5233094216715541`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {26}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.3572775806163007`, 1.3845780661661795`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {27}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7247744504458113`, 1.9752970297781767`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {28}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.93409200789628, 1.5248957505549596`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {29}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7335123622176696`, 1.6143085776324861`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {30}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.6706316907714662`, 1.7442557792510318`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {31}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.6584102608894062`, 1.9045386193808431`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {32}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.9968818181366907`, 1.5851283911173182`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {33}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.5334550977909749`, 1.7788298963795848`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {34}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8503598631707465`, 1.9884334726448394`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {35}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.3443887184548233`, 1.588378804450905}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {36}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8705775584988393`, 1.6857770839058956`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {37}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.534457540092335, 1.3916121676268671`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {38}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7952917658248422`, 1.613895830793087}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {39}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8375431515760747`, 1.458967427958114}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1197688, {
         40}}]& ]}}, {{{{}, {GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.8264062197723867`, 1.447830496154426}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.8264062197723867`, 1.447830496154426}], 
             Offset[{-17., -12.000000000000002`}, {1.8264062197723867`, 
              1.447830496154426}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.8264062197723867`, 
              1.447830496154426}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["40",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.8264062197723867, 1.447830496154426}], \
{0, 0}]}], 
        {Opacity[0], 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6]}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6], 
          TagBox[
           TooltipBox[PointBox[{1.7952917658248422`, 1.613895830793087}],
            StyleBox[
             PaneBox[
              FrameBox[
              "39", LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
               Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
               FrameMargins -> 2, BaselinePosition -> Automatic, StripOnInput -> 
               False], FrameMargins -> 0], {}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Pane[
              Framed[
              39, LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, {
               LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
                Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
                FrameMargins -> 2, BaselinePosition -> Automatic}], 
              FrameMargins -> 0], {}], "Tooltip"]& ]}}, GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 1.7763568394002505`*^-15}, {1.545594471896023, 
              1.380475235823179}], 
             Offset[{17., -11.999999999999998`}, {1.545594471896023, 
              1.380475235823179}], 
             Offset[{1.7763568394002505`*^-15, -12.000000000000002`}, {
              1.545594471896023, 1.380475235823179}], 
             Offset[{-1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.545594471896023, 1.380475235823179}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["38",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, -6.}, {1.545594471896023, 1.380475235823179}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              1.8548275584988394`, 1.6857770839058956`}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              1.8548275584988394`, 1.6857770839058956`}], 
             Offset[{-17., -6.000000000000002}, {1.8548275584988394`, 
              1.6857770839058956`}], 
             Offset[{-17., 5.999999999999998}, {1.8548275584988394`, 
              1.6857770839058956`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["37",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {1.8548275584988394, 1.6857770839058956}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.3332517866511353`, 1.577241872647217}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.3332517866511353`, 1.577241872647217}], 
             Offset[{-17., -12.000000000000002`}, {1.3332517866511353`, 
              1.577241872647217}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.3332517866511353`, 
              1.577241872647217}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["36",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.3332517866511353, 1.577241872647217}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              1.8503598631707465`, 1.9726834726448395`}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              1.8503598631707465`, 1.9726834726448395`}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              1.8503598631707465`, 1.9726834726448395`}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              1.8503598631707465`, 1.9726834726448395`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["35",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {1.8503598631707465, 1.9726834726448395}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 12.000000000000002`}, {1.544592029594663, 
              1.7899668281832728`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {1.544592029594663, 
              1.7899668281832728`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.544592029594663, 1.7899668281832728`}], 
             Offset[{-1.7763568394002505`*^-15, 11.999999999999998`}, {
              1.544592029594663, 1.7899668281832728`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["34",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.}, {1.544592029594663, 1.7899668281832728}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              1.9811318181366908`, 1.5851283911173182`}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              1.9811318181366908`, 1.5851283911173182`}], 
             Offset[{-17., -6.000000000000002}, {1.9811318181366908`, 
              1.5851283911173182`}], 
             Offset[{-17., 5.999999999999998}, {1.9811318181366908`, 
              1.5851283911173182`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["33",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {1.9811318181366908, 1.5851283911173182}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              1.6426602608894063`, 1.9045386193808431`}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              1.6426602608894063`, 1.9045386193808431`}], 
             Offset[{-17., -6.000000000000002}, {1.6426602608894063`, 
              1.9045386193808431`}], 
             Offset[{-17., 5.999999999999998}, {1.6426602608894063`, 
              1.9045386193808431`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["32",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {1.6426602608894063, 1.9045386193808431}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.6594947589677782`, 1.7331188474473438`}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.6594947589677782`, 1.7331188474473438`}], 
             Offset[{-17., -12.000000000000002`}, {1.6594947589677782`, 
              1.7331188474473438`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.6594947589677782`, 
              1.7331188474473438`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["31",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.6594947589677782, 1.7331188474473438}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              1.7335123622176696`, 1.5985585776324862`}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              1.7335123622176696`, 1.5985585776324862`}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              1.7335123622176696`, 1.5985585776324862`}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              1.7335123622176696`, 1.5985585776324862`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["30",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {1.7335123622176696, 1.5985585776324862}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              1.93409200789628, 1.5091457505549597`}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              1.93409200789628, 1.5091457505549597`}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              1.93409200789628, 1.5091457505549597`}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              1.93409200789628, 1.5091457505549597`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["29",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {1.93409200789628, 1.5091457505549597}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              1.7090244504458114`, 1.9752970297781767`}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              1.7090244504458114`, 1.9752970297781767`}], 
             Offset[{-17., -6.000000000000002}, {1.7090244504458114`, 
              1.9752970297781767`}], 
             Offset[{-17., 5.999999999999998}, {1.7090244504458114`, 
              1.9752970297781767`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["28",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {1.7090244504458114, 1.9752970297781767}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.3461406488126126`, 1.3734411343624915`}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.3461406488126126`, 1.3734411343624915`}], 
             Offset[{-17., -12.000000000000002`}, {1.3461406488126126`, 
              1.3734411343624915`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.3461406488126126`, 
              1.3734411343624915`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["27",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.3461406488126126, 1.3734411343624915}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.6490207505248242`, 1.5121724898678661`}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.6490207505248242`, 1.5121724898678661`}], 
             Offset[{-17., -12.000000000000002`}, {1.6490207505248242`, 
              1.5121724898678661`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.6490207505248242`, 
              1.5121724898678661`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["26",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.6490207505248242, 1.5121724898678661}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.8309565120016484`, 1.3306062445450542`}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.8309565120016484`, 1.3306062445450542`}], 
             Offset[{-17., -12.000000000000002`}, {1.8309565120016484`, 
              1.3306062445450542`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.8309565120016484`, 
              1.3306062445450542`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["25",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.8309565120016484, 1.3306062445450542}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              1.7707628150781194`, 1.8795895395557438`}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              1.7707628150781194`, 1.8795895395557438`}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              1.7707628150781194`, 1.8795895395557438`}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              1.7707628150781194`, 1.8795895395557438`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["24",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {1.7707628150781194, 1.8795895395557438}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              1.9672213808364563`, 1.7655211783352354`}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              1.9672213808364563`, 1.7655211783352354`}], 
             Offset[{-17., -6.000000000000002}, {1.9672213808364563`, 
              1.7655211783352354`}], 
             Offset[{-17., 5.999999999999998}, {1.9672213808364563`, 
              1.7655211783352354`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["23",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {1.9672213808364563, 1.7655211783352354}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 12.000000000000002`}, {
              1.3563660898620997`, 1.8025633473324751`}], 
             Offset[{1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.3563660898620997`, 1.8025633473324751`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.3563660898620997`, 
              1.8025633473324751`}], 
             Offset[{-17., 11.999999999999998`}, {1.3563660898620997`, 
              1.8025633473324751`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["22",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 6.}, {1.3563660898620997, 1.8025633473324751}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.4482133841498592`, 1.7226093045303366`}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.4482133841498592`, 1.7226093045303366`}], 
             Offset[{-17., -12.000000000000002`}, {1.4482133841498592`, 
              1.7226093045303366`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.4482133841498592`, 
              1.7226093045303366`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["21",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.4482133841498592, 1.7226093045303366}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 12.000000000000002`}, {0.6455713386173172, 
              0.6489641075863744}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.6455713386173172, 
              0.6489641075863744}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.6455713386173172, 0.6489641075863744}], 
             Offset[{-1.7763568394002505`*^-15, 11.999999999999998`}, {
              0.6455713386173172, 0.6489641075863744}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["20",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.}, {0.6455713386173172, 0.6489641075863744}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 12.000000000000002`}, {
              0.3741844536297052, 0.4940565476995289}], 
             Offset[{1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              0.3741844536297052, 0.4940565476995289}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {0.3741844536297052, 
              0.4940565476995289}], 
             Offset[{-17., 11.999999999999998`}, {0.3741844536297052, 
              0.4940565476995289}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["19",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 6.}, {0.3741844536297052, 0.4940565476995289}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 1.7763568394002505`*^-15}, {0.6477893251591815, 
              0.5558994763044582}], 
             Offset[{17., -11.999999999999998`}, {0.6477893251591815, 
              0.5558994763044582}], 
             Offset[{1.7763568394002505`*^-15, -12.000000000000002`}, {
              0.6477893251591815, 0.5558994763044582}], 
             Offset[{-1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.6477893251591815, 0.5558994763044582}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["18",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, -6.}, {0.6477893251591815, 0.5558994763044582}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 12.000000000000002`}, {0.24593366699875596`, 
              0.20158969479358357`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.24593366699875596`, 
              0.20158969479358357`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.24593366699875596`, 0.20158969479358357`}], 
             Offset[{-1.7763568394002505`*^-15, 11.999999999999998`}, {
              0.24593366699875596`, 0.20158969479358357`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["17",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.}, {0.24593366699875596, 0.20158969479358357}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              0.5175251243708545, 0.5833489896006238}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              0.5175251243708545, 0.5833489896006238}], 
             Offset[{-17., -6.000000000000002}, {0.5175251243708545, 
              0.5833489896006238}], 
             Offset[{-17., 5.999999999999998}, {0.5175251243708545, 
              0.5833489896006238}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["16",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {0.5175251243708545, 0.5833489896006238}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 12.000000000000002`}, {0.437356649815712, 
              0.12038409309524555`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.437356649815712, 
              0.12038409309524555`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.437356649815712, 0.12038409309524555`}], 
             Offset[{-1.7763568394002505`*^-15, 11.999999999999998`}, {
              0.437356649815712, 0.12038409309524555`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["15",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.}, {0.437356649815712, 0.12038409309524555}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              0.13980577160519403`, 0.2996129427918956}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              0.13980577160519403`, 0.2996129427918956}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              0.13980577160519403`, 0.2996129427918956}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              0.13980577160519403`, 0.2996129427918956}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["14",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {0.13980577160519403, 0.2996129427918956}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.000000000000002}, {0.4931905113972978, 
              0.5198190359641349}], 
             Offset[{17., -5.999999999999998}, {0.4931905113972978, 
              0.5198190359641349}], 
             Offset[{1.7763568394002505`*^-15, -6.000000000000002}, {
              0.4931905113972978, 0.5198190359641349}], 
             Offset[{-1.7763568394002505`*^-15, 5.999999999999998}, {
              0.4931905113972978, 0.5198190359641349}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["13",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {0.4931905113972978, 0.5198190359641349}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 12.000000000000002`}, {0.06898587813735534, 
              0.6739922872139759}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.06898587813735534, 
              0.6739922872139759}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.06898587813735534, 0.6739922872139759}], 
             Offset[{-1.7763568394002505`*^-15, 11.999999999999998`}, {
              0.06898587813735534, 0.6739922872139759}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["12",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.}, {0.06898587813735534, 0.6739922872139759}], \
{0, 0}]}], 
        {Opacity[0], 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6]}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6], 
          TagBox[
           TooltipBox[PointBox[{0.05912495176186472, 0.310718318429425}],
            StyleBox[
             PaneBox[
              FrameBox[
              "11", LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
               Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
               FrameMargins -> 2, BaselinePosition -> Automatic, StripOnInput -> 
               False], FrameMargins -> 0], {}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Pane[
              Framed[
              11, LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, {
               LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
                Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
                FrameMargins -> 2, BaselinePosition -> Automatic}], 
              FrameMargins -> 0], {}], "Tooltip"]& ]}}, GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              0.06799108228087414, 0.2160530383925799}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              0.06799108228087414, 0.2160530383925799}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              0.06799108228087414, 0.2160530383925799}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              0.06799108228087414, 0.2160530383925799}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["10",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {0.06799108228087414, 0.2160530383925799}], \
{0, 0}]}], 
        {Opacity[0], 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6]}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6], 
          TagBox[
           TooltipBox[PointBox[{0.011825825924225541`, 0.35574081011395287`}],
            StyleBox[
             PaneBox[
              FrameBox[
              "9", LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
               Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
               FrameMargins -> 2, BaselinePosition -> Automatic, StripOnInput -> 
               False], FrameMargins -> 0], {}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Pane[
              Framed[
              9, LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, {
               LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
                Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
                FrameMargins -> 2, BaselinePosition -> Automatic}], 
              FrameMargins -> 0], {}], "Tooltip"]& ]}}, GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 12.}, {0.4147016989661123, 
              0.6432785418052362}], 
             Offset[{1.7763568394002505`*^-15, 8.881784197001252*^-16}, {
              0.4147016989661123, 0.6432785418052362}], 
             Offset[{-10.999999999999998`, -8.881784197001252*^-16}, {
              0.4147016989661123, 0.6432785418052362}], 
             Offset[{-11.000000000000002`, 12.}, {0.4147016989661123, 
              0.6432785418052362}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["8",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-5.5, 6.}, {0.4147016989661123, 0.6432785418052362}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              0.4081060786451225, 0.40786607485717985`}], 
             Offset[{11.000000000000002`, -12.}, {0.4081060786451225, 
              0.40786607485717985`}], 
             Offset[{1.7763568394002505`*^-15, -12.}, {0.4081060786451225, 
              0.40786607485717985`}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              0.4081060786451225, 0.40786607485717985`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["7",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.}, {0.4081060786451225, 0.40786607485717985}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 6.000000000000001}, {
              0.4606581664481026, 0.07312962541524637}], 
             Offset[{11.000000000000002`, -5.999999999999999}, {
              0.4606581664481026, 0.07312962541524637}], 
             Offset[{1.7763568394002505`*^-15, -6.000000000000001}, {
              0.4606581664481026, 0.07312962541524637}], 
             Offset[{-1.7763568394002505`*^-15, 5.999999999999999}, {
              0.4606581664481026, 0.07312962541524637}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["6",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, 0.}, {0.4606581664481026, 0.07312962541524637}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 12.}, {0.21675466298015011`, 
              0.4720095473052084}], 
             Offset[{1.7763568394002505`*^-15, 8.881784197001252*^-16}, {
              0.21675466298015011`, 0.4720095473052084}], 
             Offset[{-10.999999999999998`, -8.881784197001252*^-16}, {
              0.21675466298015011`, 0.4720095473052084}], 
             Offset[{-11.000000000000002`, 12.}, {0.21675466298015011`, 
              0.4720095473052084}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["5",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-5.5, 6.}, {0.21675466298015011, 0.4720095473052084}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{5.499999999999998, 12.}, {0.5113376636769046, 
              0.6740656835597556}], 
             Offset[{5.500000000000002, 8.881784197001252*^-16}, {
              0.5113376636769046, 0.6740656835597556}], 
             Offset[{-5.499999999999998, -8.881784197001252*^-16}, {
              0.5113376636769046, 0.6740656835597556}], 
             Offset[{-5.500000000000002, 12.}, {0.5113376636769046, 
              0.6740656835597556}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["4",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.}, {0.5113376636769046, 0.6740656835597556}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              0.2884284791311227, 0.37329332069025}], 
             Offset[{11.000000000000002`, -12.}, {0.2884284791311227, 
              0.37329332069025}], 
             Offset[{1.7763568394002505`*^-15, -12.}, {0.2884284791311227, 
              0.37329332069025}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              0.2884284791311227, 0.37329332069025}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["3",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.}, {0.2884284791311227, 0.37329332069025}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 12.}, {0.15196718810929366`, 
              0.40617484628858014`}], 
             Offset[{1.7763568394002505`*^-15, 8.881784197001252*^-16}, {
              0.15196718810929366`, 0.40617484628858014`}], 
             Offset[{-10.999999999999998`, -8.881784197001252*^-16}, {
              0.15196718810929366`, 0.40617484628858014`}], 
             Offset[{-11.000000000000002`, 12.}, {0.15196718810929366`, 
              0.40617484628858014`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["2",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-5.5, 6.}, {0.15196718810929366, 0.40617484628858014}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              0.5831141791630903, 0.42302164339005066`}], 
             Offset[{11.000000000000002`, -12.}, {0.5831141791630903, 
              0.42302164339005066`}], 
             Offset[{1.7763568394002505`*^-15, -12.}, {0.5831141791630903, 
              0.42302164339005066`}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              0.5831141791630903, 0.42302164339005066`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["1",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.}, {0.5831141791630903, 0.42302164339005066}], \
{0, 0}]}]}}, {}}, {}}}, LineBox[CompressedData["
1:eJxd0v0v1AEAx3G1WuWhEGanLBnXrXakJU/tQ/PUw8VUHspyHfJUd2t5XLci
dbnJwxhJE1MaOoxWnpnFUp7uZHLk6brT3YZcde7pe3fVr/3w3usfeDswWGHx
W42MjCh/+6fdItPrBU2E8yYsU7+Pc9jvafolNUYMwfdCLsVJBEfbJ4zTNDG+
lRRxrZLEGE0NaEtsV+CQddFFb/ImggfYUY4FKiwOfrI38d9E4zw7e0uxBp2n
fd5kxahw275M7Z6lQ+8wvfVDhgKCA/y60us6nHTme61HKJEms043/qmHpw3Z
Rh2vQgRxM8rrlwE8Bbu8JVoNZr7QzbfLgO2csoOlILDLaaVbtKbD0wLvOLlK
g/71ibncTgKhuYGsB5Nq0AhmWkaPFv4RFO/jU2pI4jrOSrs0UCze6c+UamHd
0x1rcolAQlhpQcgFPaSxtXLLZzq4Zv+uquYbYHWKZNtUocW2vNXdgkoDZOtV
bsI8DYjL79m6TD02I5nuO7kqiAuvhdukE9g7w2m/F6XEURG39UavFmVDx4Rn
lhV469LX19xAwM/Q1Fd1XwFGCk9sSFIDJdNjS9FL8KxPNls1l2B8xYG34TuH
kXaecY6XGCHUq/py82Vw6/dkjzSKwKEU1TEKF2DRI3t0pXYJnFaPHXYNM6C+
OtFEli6AaT8WJE8QopFaS8j5s5itGTdx6hfgHTs3MqdyBsXVoX4Fh8fAmB+d
/XF3HhsyDy79eRPyV6isfe4SnAOLU7E0iEAHIYkWLMRLsxQ+WTIA1/BkMyl1
CubdsUdqAprhbKy1nhB9hu9aL9vRIw9tLWGktMFpREr4lvMJrYj2zJnseD0G
cSJrSGA2jtQun5IB+jDcEm9ZuATNIbF8zaNa2Q2bx2QSPesrMpWch9Udbfj/
vz+vKlTj
    "]]},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{306.5, Automatic},
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 2.}, {0., 2.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.859012336380873*^9, 3.8590123998433876`*^9, 3.8590124400834656`*^9, {
   3.859012557903231*^9, 3.859012561325844*^9}, {3.8590366117998*^9, 
   3.8590366423522243`*^9}, 3.8590375441936755`*^9, 3.859037589043541*^9, {
   3.859037665665844*^9, 3.8590376907354903`*^9}, 3.859037995203351*^9, 
   3.8590380441440544`*^9, 3.8590388787447453`*^9, 3.859038985894938*^9, 
   3.8590390391347337`*^9, 3.8590390738748426`*^9, 3.8590416807564464`*^9, {
   3.859042043832177*^9, 3.859042051232082*^9}, 3.8590511487261305`*^9, 
   3.8593554072804604`*^9, 3.8593554478527813`*^9, 3.85935554994462*^9, 
   3.8593563336944485`*^9, 3.8593740036361113`*^9, 3.859381985856668*^9, 
   3.8593829791444807`*^9, {3.8593837746699824`*^9, 3.8593837886587825`*^9}, 
   3.85938382760901*^9, 3.859383930388889*^9, 3.85938444529434*^9},
 CellLabel->
  "Out[1066]=",ExpressionUUID->"237a2574-05a1-4d04-a6f6-aa997bb7ce46"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Approximative solution using thermodynamic Monte Carlo method\
\>", "Section",
 CellChangeTimes->{{3.850284992156113*^9, 3.8502851174278107`*^9}, {
  3.8502884635283027`*^9, 3.8502884649516716`*^9}, {3.850407943113345*^9, 
  3.8504079457856646`*^9}, {3.8504449061005325`*^9, 3.8504449155490723`*^9}, {
  3.850446227606118*^9, 3.8504462511734657`*^9}, {3.8587553227221746`*^9, 
  3.8587553695458527`*^9}, {3.858764261860464*^9, 3.858764277268345*^9}, {
  3.859011999602493*^9, 3.8590120411627245`*^9}, {3.859038099864771*^9, 
  3.85903812597431*^9}, {3.8590391126761723`*^9, 3.859039180985834*^9}, {
  3.8590415901590443`*^9, 
  3.859041650450469*^9}},ExpressionUUID->"6045c388-2f2b-4767-9a08-\
97aaff3123e2"],

Cell[CellGroupData[{

Cell["\<\
Simple algorithm - just switch two random cities and use Metropolis to accept \
or reject a new tour\
\>", "Subsubsection",
 CellChangeTimes->{{3.859012626100502*^9, 3.8590126806907263`*^9}, {
  3.859368335192895*^9, 
  3.8593684349666014`*^9}},ExpressionUUID->"0cc8be72-eacd-420d-9af0-\
32b8bf2826db"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MCSolutionOfTSP", "[", 
    RowBox[{
    "cities_", ",", "distances_", ",", "iniPerm_", ",", "startingT_", ",", 
     "nIter_", ",", "model_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"input", ":", " ", "\[IndentingNewLine]", "cities"}], " ", "=", 
      " ", 
      RowBox[{"a", " ", "list", " ", "of", " ", "coordinates", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], " ", "of", " ", "all", " ", 
       "cities"}]}], ",", "\[IndentingNewLine]", "  ", 
     RowBox[{"distances", " ", "=", " ", 
      RowBox[{
      "a", " ", "matrix", " ", "of", " ", "distances", " ", "between", " ", 
       "each", " ", "pair", " ", "of", " ", "cities"}]}], ",", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{"iniPerm", " ", "=", " ", 
      RowBox[{
      "a", " ", "list", " ", "with", " ", "initial", " ", "permutation", " ", 
       "of", " ", "cities"}]}], ",", "\[IndentingNewLine]", "  ", 
     RowBox[{"startingT", " ", "=", " ", 
      RowBox[{"starting", " ", "temperature"}]}], ",", "\[IndentingNewLine]", 
     "  ", 
     RowBox[{"nIter", " ", "=", " ", 
      RowBox[{
      "number", " ", "of", " ", "iterations", " ", "of", " ", "the", " ", 
       "MC", " ", "algorithm"}]}], ",", "\[IndentingNewLine]", "    ", 
     RowBox[{"model", " ", "=", " ", 
      RowBox[{"\"\<Simple\>\"", " ", 
       RowBox[{"(", 
        RowBox[{
        "just", " ", "switch", " ", "two", " ", "random", " ", "cities"}], 
        ")"}], " ", "or", " ", "\"\<Cerny\>\"", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"switch", " ", "systematically", " ", "i"}], "-", 
          RowBox[{
          "th", " ", "city", " ", "with", " ", "a", " ", "random", " ", 
           "one"}]}], ",", " ", 
         RowBox[{
         "but", " ", "go", " ", "in", " ", "a", " ", "reverse", " ", 
          "direction", " ", "half", " ", "of", " ", "the", " ", "tour"}]}], 
        ")"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"output", ":", "\[IndentingNewLine]", "shortestDistance"}], " ",
       "=", " ", 
      RowBox[{
      "the", " ", "found", " ", "shortest", " ", "total", " ", "distance", 
       " ", "travelled"}]}], ",", "\[IndentingNewLine]", "  ", 
     RowBox[{"shortestPerm", " ", "=", " ", 
      RowBox[{
      "the", " ", "found", " ", "permutations", " ", "of", " ", "cities", " ",
        "corresponding", " ", "to", " ", "the", " ", "shortest", " ", "total",
        " ", "distance", " ", "travelled"}]}], ",", "\[IndentingNewLine]", 
     "  ", 
     RowBox[{"totalDistances", " ", "=", " ", 
      RowBox[{
      "a", " ", "list", " ", "of", " ", "total", " ", "distances", " ", 
       "travelled", " ", "at", " ", "each", " ", "iteration"}]}], ",", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{"savedPerm", " ", "=", " ", 
      RowBox[{
      "a", " ", "list", " ", "of", " ", "saved", " ", "permutations"}]}], ",",
      " ", 
     RowBox[{
     "only", " ", "new", " ", "accepted", " ", "permutations", " ", "are", 
      " ", "saved"}]}], "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "i", ",", "j", ",", "ii", ",", "jj", ",", "n", ",", "totalDistances", 
       ",", "T", ",", "plus", ",", "minus", ",", "\[IndentingNewLine]", 
       "curDist", ",", "curPerm", ",", "savedPerm", ",", 
       "\[IndentingNewLine]", "shortestDist", ",", "shortestPerm", ",", 
       "\[IndentingNewLine]", "tryPerm", ",", "newDist", ",", "rejected"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "cities", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"totalDistances", "=", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"nIter", "+", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"T", "=", "startingT"}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "auxiliary", " ", "arrays", " ", "for", " ", "simple", " ", 
        "treatment", " ", "of", " ", "periodic", " ", "boundary", " ", 
        "conditions"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"plus", "=", 
       RowBox[{"Array", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "+", 
           RowBox[{"Mod", "[", 
            RowBox[{"#", ",", "n"}], "]"}]}], "&"}], ",", "n"}], "]"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"minus", "=", 
       RowBox[{"Array", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "+", 
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"#", "-", "2"}], ",", "n"}], "]"}]}], "&"}], ",", "n"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "initial", " ", "permutation", " ", "and", " ", "distance", " ", 
        "travelled"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"curPerm", "=", "iniPerm"}], ";", "\[IndentingNewLine]", 
      RowBox[{"curDist", "=", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"distances", "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{
           "curPerm", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
           ",", 
           RowBox[{"curPerm", "\[LeftDoubleBracket]", 
            RowBox[{
            "plus", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"shortestDist", "=", "curDist"}], ";", "\[IndentingNewLine]", 
      RowBox[{"shortestPerm", "=", "curPerm"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
       "totalDistances", "\[LeftDoubleBracket]", "1", 
        "\[RightDoubleBracket]"}], "=", "curDist"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "auxiliary", " ", "array", " ", "for", " ", "saving", " ", "accepted", 
        " ", "permutations"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"savedPerm", "=", 
       RowBox[{"{", "curPerm", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Monte", " ", "Carlo", " ", "iterations"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"rejected", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"i", "=", "1"}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"for", " ", "Cerny", " ", "algorithm"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"prepare", " ", "a", " ", "trial", " ", "permuation"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"tryPerm", "=", "curPerm"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"model", "\[Equal]", "\"\<Simple\>\""}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "=", 
             RowBox[{"RandomSample", "[", 
              RowBox[{
               RowBox[{"Range", "[", "n", "]"}], ",", "2"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
               "tryPerm", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "tryPerm", "\[LeftDoubleBracket]", "j", 
                "\[RightDoubleBracket]"}]}], "}"}], "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
               "curPerm", "\[LeftDoubleBracket]", "j", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "curPerm", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}]}], "}"}]}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{"else", " ", "algorithm", " ", "of", " ", 
             RowBox[{"V", ".", " ", "\[CapitalCHacek]ern\[YAcute]"}]}], " ", 
            "*)"}], "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"j", "=", 
             RowBox[{"RandomInteger", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"n", "-", "1"}]}], "}"}], "]"}]}], ";", " ", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"j", "\[GreaterEqual]", "i"}], ",", 
              RowBox[{"j", "++"}]}], "]"}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "random", " ", "j", " ", "different", " ", "from", " ", "i"}], 
             " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"ii", ",", "jj"}], "}"}], "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Min", "[", 
                RowBox[{"i", ",", "j"}], "]"}], ",", 
               RowBox[{"Max", "[", 
                RowBox[{"i", ",", "j"}], "]"}]}], "}"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"tryPerm", "\[LeftDoubleBracket]", 
              RowBox[{"ii", ";;", "jj"}], "\[RightDoubleBracket]"}], "=", 
             RowBox[{"Reverse", "[", 
              RowBox[{"curPerm", "\[LeftDoubleBracket]", 
               RowBox[{"ii", ";;", "jj"}], "\[RightDoubleBracket]"}], 
              "]"}]}]}]}], "\[IndentingNewLine]", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{"use", " ", "Metropolis", " ", 
           RowBox[{"alg", ".", " ", "to"}], " ", "decide", " ", "whether", 
           " ", "to", " ", "accept", " ", "or", " ", "reject", " ", "a", " ", 
           "new", " ", "permutation"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"newDist", "=", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{"distances", "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{
              "tryPerm", "\[LeftDoubleBracket]", "i", 
               "\[RightDoubleBracket]"}], ",", 
              RowBox[{"tryPerm", "\[LeftDoubleBracket]", 
               RowBox[{
               "plus", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"newDist", "<", "curDist"}], " ", "||", " ", 
            RowBox[{
             RowBox[{"RandomReal", "[", "]"}], "<", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"curDist", "-", "newDist"}], ")"}], "/", "T"}], 
              "]"}]}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"curPerm", "=", "tryPerm"}], ";", "\[IndentingNewLine]", 
            RowBox[{"curDist", "=", "newDist"}], ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"curDist", "<", "shortestDist"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"shortestDist", "=", "curDist"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"shortestPerm", "=", "curPerm"}]}]}], 
             "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"savedPerm", ",", "curPerm"}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"rejected", "++"}]}], "\[IndentingNewLine]", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"totalDistances", "\[LeftDoubleBracket]", 
           RowBox[{"it", "+", "1"}], "\[RightDoubleBracket]"}], "=", 
          "curDist"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"i", "<", "n"}], ",", 
           RowBox[{"i", "++"}], ",", 
           RowBox[{"i", "=", "1"}]}], "]"}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
         "move", " ", "to", " ", "the", " ", "neighbouring", " ", "city"}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Mod", "[", 
              RowBox[{"it", ",", "4000"}], "]"}], "\[Equal]", "0"}], ",", 
            RowBox[{"T", "=", 
             RowBox[{"0.1", "*", "T"}]}]}], "]"}], ","}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"it", ",", "1", ",", "nIter"}], "}"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<Total permutations rejected: \>\"", ",", " ", "rejected"}], "]"}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{"{", 
        RowBox[{
        "shortestDist", ",", "shortestPerm", ",", "totalDistances", ",", 
         "savedPerm"}], "}"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.8496065737332587`*^9, 3.849606654427*^9}, {
   3.8496066854068832`*^9, 3.8496066856924987`*^9}, {3.8496067692497735`*^9, 
   3.849606771348775*^9}, {3.8496068224442654`*^9, 3.8496068951102657`*^9}, {
   3.849606941073992*^9, 3.8496069670037174`*^9}, {3.849607002220313*^9, 
   3.8496074760208178`*^9}, {3.8496077119325123`*^9, 3.849607748132677*^9}, {
   3.8498659522565804`*^9, 3.849866234045698*^9}, {3.8498664501880603`*^9, 
   3.849866560979398*^9}, {3.849866608770131*^9, 3.8498667563615727`*^9}, {
   3.849866795952837*^9, 3.8498668229203796`*^9}, {3.849866856288288*^9, 
   3.8498669046880565`*^9}, {3.8498669577040887`*^9, 
   3.8498669937121487`*^9}, {3.849867326660192*^9, 3.8498675569833655`*^9}, {
   3.8498677067099295`*^9, 3.849867729758248*^9}, {3.849867794714963*^9, 
   3.8498679708510375`*^9}, {3.8498680893228135`*^9, 
   3.8498681521384068`*^9}, {3.8498682229434566`*^9, 
   3.8498682412875056`*^9}, {3.8498682825118637`*^9, 3.849868329421547*^9}, {
   3.849868428544216*^9, 3.8498684496614237`*^9}, {3.849868692556317*^9, 
   3.8498687736739564`*^9}, {3.8498688480182085`*^9, 
   3.8498688742667103`*^9}, {3.849868979090706*^9, 3.8498690248643236`*^9}, {
   3.8498690758832417`*^9, 3.849869083128656*^9}, {3.8498691286262584`*^9, 
   3.84986920680873*^9}, {3.849869250843249*^9, 3.8498692561335516`*^9}, {
   3.849869287120324*^9, 3.8498693018551664`*^9}, {3.849869419129874*^9, 
   3.849869486052702*^9}, {3.849869551278433*^9, 3.8498695722186303`*^9}, {
   3.850209338624843*^9, 3.8502093666224446`*^9}, {3.8502094626939397`*^9, 
   3.850209506746459*^9}, {3.8502095758124094`*^9, 3.850209612623515*^9}, {
   3.8502097222337847`*^9, 3.8502097240948906`*^9}, {3.850209784338337*^9, 
   3.850209804590495*^9}, {3.85021004804742*^9, 3.8502100678515525`*^9}, {
   3.8502823883410573`*^9, 3.8502823904519043`*^9}, {3.8502827091554527`*^9, 
   3.8502827305592375`*^9}, {3.8502827633875566`*^9, 3.850282770436743*^9}, {
   3.850282809667946*^9, 3.850283014461815*^9}, {3.8502830628918743`*^9, 
   3.8502833755911655`*^9}, {3.8502834085701785`*^9, 3.850283420387255*^9}, {
   3.850283596583228*^9, 3.850283597528829*^9}, {3.850283844925599*^9, 
   3.850283883214069*^9}, {3.8502839989512444`*^9, 3.850284008881238*^9}, {
   3.850284444798033*^9, 3.850284445065889*^9}, {3.8502846732782197`*^9, 
   3.850284741112954*^9}, {3.850284922195149*^9, 3.850284923148017*^9}, {
   3.8502851222664003`*^9, 3.8502851244583917`*^9}, 3.850286085594694*^9, {
   3.850286679977948*^9, 3.850286703311764*^9}, {3.8502869522880197`*^9, 
   3.8502871242314744`*^9}, {3.8502871663999095`*^9, 
   3.8502871678013754`*^9}, {3.850288488694371*^9, 3.850288522186626*^9}, {
   3.8502885981612406`*^9, 3.8502886355455885`*^9}, {3.8502991493940296`*^9, 
   3.8502991738098364`*^9}, {3.8502992349912353`*^9, 3.850299246362059*^9}, {
   3.8502993318357267`*^9, 3.850299348849098*^9}, {3.850299381766471*^9, 
   3.8502996020037723`*^9}, {3.8502997381470404`*^9, 3.850299822578452*^9}, {
   3.850299907763318*^9, 3.8503000556463923`*^9}, {3.850300113499284*^9, 
   3.850300153813047*^9}, {3.850300260418194*^9, 3.850300333934967*^9}, {
   3.8503003745621414`*^9, 3.8503003749608736`*^9}, 3.8503004195304165`*^9, {
   3.8503004674465656`*^9, 3.850300477941496*^9}, {3.8503010662506666`*^9, 
   3.850301253842307*^9}, {3.850301305078566*^9, 3.850301306922103*^9}, {
   3.850301355617137*^9, 3.8503014822213535`*^9}, {3.8503015812921886`*^9, 
   3.850301637662247*^9}, {3.850301721175931*^9, 3.850301818225009*^9}, {
   3.850302006250021*^9, 3.8503020322460113`*^9}, {3.8503020670259323`*^9, 
   3.850302133564114*^9}, {3.850302166479986*^9, 3.850302224098697*^9}, {
   3.8503022558635283`*^9, 3.850302285007962*^9}, {3.850302378289647*^9, 
   3.850302507333518*^9}, {3.850302563268634*^9, 3.850302563901643*^9}, {
   3.850305309239606*^9, 3.8503054709155135`*^9}, {3.850306308238212*^9, 
   3.850306311398385*^9}, {3.850306342873065*^9, 3.850306421387246*^9}, {
   3.8503064627927437`*^9, 3.8503065650437765`*^9}, {3.8503065999805307`*^9, 
   3.8503066580431275`*^9}, {3.850306703344405*^9, 3.850306920178565*^9}, {
   3.850306964667661*^9, 3.850307050066254*^9}, {3.8503070892171*^9, 
   3.8503070949580555`*^9}, {3.8503071579808345`*^9, 3.85030716108549*^9}, {
   3.8503074109208455`*^9, 3.8503074124391117`*^9}, {3.8503074627379093`*^9, 
   3.8503074731979485`*^9}, {3.850307601886543*^9, 3.850307631581897*^9}, {
   3.8503077342177167`*^9, 3.850307818409624*^9}, 3.8503078809044504`*^9, {
   3.8503079170340476`*^9, 3.850307944974044*^9}, {3.850308068703856*^9, 
   3.8503080821448064`*^9}, {3.8503081141002674`*^9, 3.8503081998117094`*^9}, 
   3.8503082486967936`*^9, {3.850309877717277*^9, 3.8503099293016024`*^9}, {
   3.850310006619562*^9, 3.850310033809697*^9}, {3.850310302493517*^9, 
   3.8503103145364757`*^9}, {3.8503197013229585`*^9, 
   3.8503197789306507`*^9}, {3.850319858615965*^9, 3.850319862884163*^9}, {
   3.8503203669429846`*^9, 3.850320369592593*^9}, {3.8504079506451187`*^9, 
   3.8504081787888556`*^9}, {3.8504082245844355`*^9, 3.850408228460683*^9}, {
   3.8504082702512283`*^9, 3.8504083433004293`*^9}, {3.850408391736351*^9, 
   3.8504084692662354`*^9}, {3.8504087677049923`*^9, 3.850409019284892*^9}, {
   3.8504090558370075`*^9, 3.8504090609312153`*^9}, {3.8504091022368665`*^9, 
   3.8504092822744045`*^9}, {3.850410055147817*^9, 3.850410098779961*^9}, {
   3.8504101562701273`*^9, 3.8504101590205097`*^9}, {3.850411243074305*^9, 
   3.850411301531823*^9}, {3.8504113795392327`*^9, 3.850411440279065*^9}, {
   3.8504116883696384`*^9, 3.8504116902135515`*^9}, {3.8504118383514524`*^9, 
   3.8504119601881313`*^9}, {3.8504120848238535`*^9, 
   3.8504120978282266`*^9}, {3.850412356139202*^9, 3.8504123886535387`*^9}, {
   3.8504124208751507`*^9, 3.8504127498974795`*^9}, {3.850414384318515*^9, 
   3.8504144098138947`*^9}, {3.850416289766465*^9, 3.8504163050832624`*^9}, {
   3.8504164348664446`*^9, 3.850416437320009*^9}, {3.8504165158598332`*^9, 
   3.850416518563015*^9}, {3.8504165491820536`*^9, 3.850416661477475*^9}, {
   3.8504167393187723`*^9, 3.850416771380473*^9}, {3.8504175895941625`*^9, 
   3.850417640639447*^9}, {3.8504453494788923`*^9, 3.8504453556452446`*^9}, 
   3.85044548126943*^9, {3.850446242941995*^9, 3.8504462663463335`*^9}, {
   3.858755384479707*^9, 3.8587557133135147`*^9}, {3.858755753281801*^9, 
   3.858755761433267*^9}, {3.8587560395981774`*^9, 3.858756162942232*^9}, {
   3.8587562102299366`*^9, 3.8587562110539837`*^9}, {3.8587564158836994`*^9, 
   3.8587564169627614`*^9}, {3.85875699966109*^9, 3.8587571621213818`*^9}, {
   3.8587590807131195`*^9, 3.858759183809016*^9}, {3.8587606227413177`*^9, 
   3.858760693324355*^9}, {3.858760731659548*^9, 3.8587607612192383`*^9}, {
   3.8587611374637585`*^9, 3.85876113767177*^9}, {3.85876385251305*^9, 
   3.8587638531290855`*^9}, {3.8587640260479765`*^9, 3.858764162086757*^9}, {
   3.8587642881109653`*^9, 3.858764314614481*^9}, {3.858764363229262*^9, 
   3.8587644381245456`*^9}, {3.858764492386649*^9, 3.85876455533925*^9}, {
   3.8587646723459425`*^9, 3.8587647022426524`*^9}, {3.8587647325853877`*^9, 
   3.858764981431621*^9}, {3.858765068940626*^9, 3.8587651155182905`*^9}, {
   3.8587653596982565`*^9, 3.858765488033597*^9}, {3.858767165349534*^9, 
   3.8587673193403416`*^9}, 3.8587674567552013`*^9, {3.858767754705243*^9, 
   3.85876776688894*^9}, {3.8587682446242647`*^9, 3.8587682512636447`*^9}, {
   3.8587682857516174`*^9, 3.858768361814968*^9}, {3.85876842094435*^9, 
   3.8587685768382664`*^9}, 3.8587686469142747`*^9, {3.858768732290158*^9, 
   3.8587687390925465`*^9}, 3.85876888268576*^9, {3.8587689261552467`*^9, 
   3.858768961681278*^9}, {3.858769029418153*^9, 3.858769095615939*^9}, {
   3.858769258905278*^9, 3.8587692627745*^9}, {3.858769311887309*^9, 
   3.8587693251740685`*^9}, {3.858769527754656*^9, 3.858769530411808*^9}, 
   3.858769609876353*^9, {3.8587701811910305`*^9, 3.858770199003049*^9}, {
   3.858770300620861*^9, 3.8587703270983753`*^9}, {3.858770539480523*^9, 
   3.8587705435027533`*^9}, {3.858771009663416*^9, 3.858771010356456*^9}, {
   3.858779899347877*^9, 3.858779963633554*^9}, {3.8587801350723596`*^9, 
   3.858780380095374*^9}, {3.85878046393417*^9, 3.8587804838133063`*^9}, {
   3.8587805139010277`*^9, 3.8587805399185157`*^9}, {3.858780593828599*^9, 
   3.858780619669077*^9}, {3.85878075155062*^9, 3.858780752179656*^9}, {
   3.8587815838712263`*^9, 3.8587816080866113`*^9}, {3.8587817936302233`*^9, 
   3.8587819116919765`*^9}, {3.8587819421887207`*^9, 3.858782022635322*^9}, {
   3.8587821551859035`*^9, 3.85878215565493*^9}, {3.858782587510631*^9, 
   3.858782756515298*^9}, {3.858782788923151*^9, 3.8587827999547825`*^9}, {
   3.858783493699462*^9, 3.858783494834527*^9}, 3.8587835426332607`*^9, {
   3.8587837010023193`*^9, 3.858783732184103*^9}, {3.858783777620702*^9, 
   3.8587837801038437`*^9}, {3.8587843336115026`*^9, 
   3.8587843857524843`*^9}, {3.859012050207283*^9, 3.8590121087172866`*^9}, {
   3.859012956111888*^9, 3.85901302847807*^9}, {3.8590136629341373`*^9, 
   3.859013740952004*^9}, {3.859013813638775*^9, 3.8590138760058765`*^9}, {
   3.8590417165968666`*^9, 3.859041800186434*^9}, {3.859041977031814*^9, 
   3.8590420235523963`*^9}, {3.8590424485078297`*^9, 
   3.8590425050209885`*^9}, {3.859042535482889*^9, 3.8590426036228085`*^9}, {
   3.859042850622978*^9, 3.859042903158701*^9}, {3.859044386383974*^9, 
   3.8590446319738846`*^9}, {3.859044705254281*^9, 3.859044914594019*^9}, {
   3.8590449857445593`*^9, 3.8590450217445817`*^9}, {3.8590450935446224`*^9, 
   3.859045127974939*^9}, {3.859045603702179*^9, 3.859045609694762*^9}, {
   3.8590459014290056`*^9, 3.859045942078935*^9}, {3.859046296889555*^9, 
   3.8590463093092723`*^9}, {3.8590463474390917`*^9, 3.859046395149968*^9}, {
   3.8590470854194283`*^9, 3.8590470877299747`*^9}, {3.8590471786197996`*^9, 
   3.8590471969698324`*^9}, {3.859047589252037*^9, 3.8590476631022806`*^9}, {
   3.8590476955623207`*^9, 3.8590477237220526`*^9}, {3.8590477894331865`*^9, 
   3.859047890942811*^9}, {3.8590479728691816`*^9, 3.8590480381024475`*^9}, {
   3.859048364752597*^9, 3.8590485387531652`*^9}, {3.859048595286194*^9, 
   3.8590486909132137`*^9}, {3.8590487292232018`*^9, 
   3.8590487384732533`*^9}, {3.8590488137232533`*^9, 3.859048842033739*^9}, {
   3.859048955527667*^9, 3.8590489585334044`*^9}, {3.8590499178201885`*^9, 
   3.8590499496696444`*^9}, {3.859050004269805*^9, 3.8590500048633194`*^9}, {
   3.8590504807254534`*^9, 3.8590505640601635`*^9}, {3.859050608480425*^9, 
   3.859050742560134*^9}, {3.859050773370059*^9, 3.8590507984205675`*^9}, {
   3.859050930070422*^9, 3.85905093060155*^9}, 3.8590510332709503`*^9, {
   3.8593568987787695`*^9, 3.859356919350946*^9}, {3.8593586041333103`*^9, 
   3.859358606333436*^9}, {3.859365942854061*^9, 3.859365971132678*^9}, {
   3.859366230844533*^9, 3.859366330010205*^9}, {3.8593664430706716`*^9, 
   3.8593664535292697`*^9}, {3.859366885967004*^9, 3.859366910542409*^9}, {
   3.8593672097665243`*^9, 3.859367218827042*^9}, {3.859367442641844*^9, 
   3.859367484607244*^9}, {3.8593685083718*^9, 3.859368670496073*^9}, {
   3.8593687120154476`*^9, 3.859368891502714*^9}, {3.859369473355994*^9, 
   3.8593698360067368`*^9}, {3.8593703677121477`*^9, 3.859370430439736*^9}, {
   3.859370469270957*^9, 3.8593704954394536`*^9}, {3.8593705435272045`*^9, 
   3.85937054800646*^9}, {3.859370618381486*^9, 3.8593707377643137`*^9}, {
   3.8593708445154195`*^9, 3.85937100082436*^9}, {3.8593714308929586`*^9, 
   3.8593714770115967`*^9}, {3.8593715233262453`*^9, 3.859371525123348*^9}, {
   3.8593825467837515`*^9, 3.859382554435189*^9}, {3.8593826071162024`*^9, 
   3.8593827846733575`*^9}},
 CellLabel->
  "In[968]:=",ExpressionUUID->"ecdda7ec-fa69-4d39-bc74-0c1c937e0baf"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"nIter", "=", "40000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"initialPerm", "=", 
    RowBox[{"RandomSample", "[", 
     RowBox[{"Range", "[", "n", "]"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"shortest", "\[LeftDoubleBracket]", 
     RowBox[{"2", ",", 
      RowBox[{"1", ";;", "n"}]}], "\[RightDoubleBracket]"}], ";"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"temp", "=", "0.03"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "shortestDist", ",", "shortestPerm", ",", "totalDistances", ",", 
     "savedPerm"}], "}"}], "=", 
   RowBox[{"MCSolutionOfTSP", "[", 
    RowBox[{
    "cities", ",", "distances", ",", "initialPerm", ",", "temp", ",", "nIter",
      ",", "\"\<Cerny\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"temp", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "shortestDist", ",", "shortestPerm", ",", "totalDistances", ",", 
     "savedPerm"}], "}"}], "=", 
   RowBox[{"MCSolutionOfTSP", "[", 
    RowBox[{
    "cities", ",", "distances", ",", "shortestPerm", ",", "temp", ",", 
     "nIter", ",", "\"\<Cerny\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nSave", "=", 
   RowBox[{"Length", "[", "savedPerm", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Shortest tour found (black) is \>\"", ",", "shortestDist", ",", " ", 
    "\"\<, but the actual shortest tour (green) is \>\"", ",", " ", 
    RowBox[{
    "shortest", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
   "]"}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{
          "cities", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          ",", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"PointSize", "[", "Medium", "]"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Black", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"cities", "\[LeftDoubleBracket]", 
         RowBox[{"Append", "[", 
          RowBox[{"shortestPerm", ",", 
           RowBox[{
           "shortestPerm", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]}], "]"}], "\[RightDoubleBracket]"}], 
        "]"}], ",", "Thin", ",", "Red", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"cities", "\[LeftDoubleBracket]", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"Last", "[", "savedPerm", "]"}], ",", 
           RowBox[{
            RowBox[{"Last", "[", "savedPerm", "]"}], "\[LeftDoubleBracket]", 
            "1", "\[RightDoubleBracket]"}]}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], ",", "Thin", ",", "Dashed", ",", 
       "Green", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"cities", "\[LeftDoubleBracket]", 
         RowBox[{
         "shortest", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "\[RightDoubleBracket]"}], "]"}]}], "}"}], "]"}]}], "}"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"totalDistances", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8590451524048386`*^9, 3.85904517817447*^9}, 
   3.8590489403630157`*^9, {3.8590489923656435`*^9, 3.8590489945235825`*^9}, {
   3.859050022465147*^9, 3.8590500277001524`*^9}, {3.859051000250376*^9, 
   3.8590510038005934`*^9}, 3.8590510459006414`*^9, {3.859051173910393*^9, 
   3.859051175805846*^9}, {3.859051249080512*^9, 3.859051250381168*^9}, {
   3.8593568126628437`*^9, 3.8593568650208387`*^9}, {3.859356922011098*^9, 
   3.8593569395791025`*^9}, {3.859356977083248*^9, 3.859356983106592*^9}, {
   3.85935889156075*^9, 3.859358921615469*^9}, 3.8593658851267586`*^9, {
   3.8593659821243067`*^9, 3.8593660032185135`*^9}, {3.8593661430275097`*^9, 
   3.859366146152689*^9}, {3.8593665397702026`*^9, 3.859366540647252*^9}, {
   3.8593665782014008`*^9, 3.859366584557764*^9}, {3.85936666664946*^9, 
   3.8593666699006453`*^9}, {3.859366726544885*^9, 3.8593667406466923`*^9}, {
   3.8593669357948537`*^9, 3.8593669517457657`*^9}, {3.8593669913180294`*^9, 
   3.8593669964243217`*^9}, 3.859367049141337*^9, 3.859367146637913*^9, 
   3.8593672422193804`*^9, {3.859367368864624*^9, 3.859367369757675*^9}, {
   3.859367549158936*^9, 3.859367571188196*^9}, {3.8593689020303164`*^9, 
   3.859368953642268*^9}, {3.859369003402114*^9, 3.8593690438334265`*^9}, {
   3.8593690811175594`*^9, 3.8593690902730827`*^9}, {3.859369251749319*^9, 
   3.859369257340638*^9}, {3.8593693133568425`*^9, 3.8593693218563285`*^9}, 
   3.8593694033299885`*^9, {3.8593710303750505`*^9, 3.859371049323134*^9}, {
   3.8593713794750175`*^9, 3.8593713937338333`*^9}, {3.859371551751871*^9, 
   3.859371556244128*^9}, {3.8593743814137187`*^9, 3.859374382585786*^9}, {
   3.8593745543756113`*^9, 3.8593745799180727`*^9}, {3.859375095252548*^9, 
   3.8593750963436103`*^9}, {3.859375182899561*^9, 3.859375183591601*^9}, {
   3.859375243267014*^9, 3.859375245663151*^9}, {3.8593823852825136`*^9, 
   3.859382393030957*^9}, {3.8593824480941067`*^9, 3.859382457318634*^9}, {
   3.8593827935918674`*^9, 3.859382838995465*^9}, 3.8593830763720417`*^9, {
   3.859383111338042*^9, 3.859383113367158*^9}, {3.8593831753027*^9, 
   3.859383209597662*^9}, {3.8593832563893385`*^9, 3.8593833279164295`*^9}, 
   3.8593835154281545`*^9, {3.8593836293476706`*^9, 3.859383690601174*^9}, {
   3.859383838761648*^9, 3.8593838391926727`*^9}, {3.859384470168762*^9, 
   3.859384470684792*^9}, {3.85938458341524*^9, 3.8593845837952614`*^9}, {
   3.8593846651269135`*^9, 3.8593848148494773`*^9}, {3.859431460785472*^9, 
   3.8594314948044176`*^9}, 3.859431554863853*^9, {3.8594315982313337`*^9, 
   3.8594316023955717`*^9}, {3.8594317159670677`*^9, 3.859431738704368*^9}},
 CellLabel->
  "In[1434]:=",ExpressionUUID->"acf4e686-9a95-417c-9ebd-460e38edbdd4"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total permutations rejected: \"\>", "\[InvisibleSpace]", 
   "39115"}],
  SequenceForm["Total permutations rejected: ", 39115],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.859366960954293*^9, {3.8593670330704174`*^9, 3.8593670497133694`*^9}, 
   3.8593671503011227`*^9, {3.8593672267324944`*^9, 3.8593672430174255`*^9}, 
   3.859367370312707*^9, {3.859367533877062*^9, 3.859367571793231*^9}, {
   3.8593690288195677`*^9, 3.8593690447054763`*^9}, 3.8593690918271713`*^9, {
   3.859369258204688*^9, 3.859369268157257*^9}, {3.8593693226073713`*^9, 
   3.8593694309805703`*^9}, {3.859371036506401*^9, 3.8593710499911723`*^9}, {
   3.859371380143056*^9, 3.8593713946698866`*^9}, 3.8593714832769547`*^9, {
   3.859371534001856*^9, 3.8593715579442253`*^9}, 3.859374055388071*^9, {
   3.8593743274536324`*^9, 3.8593743491538734`*^9}, {3.8593743857139645`*^9, 
   3.859374397616646*^9}, {3.8593744958642645`*^9, 3.859374505954842*^9}, 
   3.859374583067253*^9, 3.859375099640799*^9, 3.8593751541139145`*^9, {
   3.8593751848756742`*^9, 3.8593752046568055`*^9}, 3.859381996525278*^9, 
   3.859382474415612*^9, 3.8593827985851536`*^9, 3.8593828462258787`*^9, 
   3.859382990175112*^9, 3.8593830774381027`*^9, 3.859383114507223*^9, {
   3.859383160523855*^9, 3.859383223871478*^9}, {3.8593833026079817`*^9, 
   3.8593833317626495`*^9}, 3.8593835184113255`*^9, 3.8593836938153577`*^9, 
   3.85938384002672*^9, {3.859384458340086*^9, 3.8593844727269087`*^9}, 
   3.859384585724372*^9, {3.859384668128085*^9, 3.8593848347176137`*^9}, {
   3.8594315414280844`*^9, 3.8594317589245243`*^9}},
 CellLabel->
  "During evaluation of \
In[1434]:=",ExpressionUUID->"f539e9b3-8c8e-4708-82b4-63f0a8ce4807"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total permutations rejected: \"\>", "\[InvisibleSpace]", 
   "39663"}],
  SequenceForm["Total permutations rejected: ", 39663],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.859366960954293*^9, {3.8593670330704174`*^9, 3.8593670497133694`*^9}, 
   3.8593671503011227`*^9, {3.8593672267324944`*^9, 3.8593672430174255`*^9}, 
   3.859367370312707*^9, {3.859367533877062*^9, 3.859367571793231*^9}, {
   3.8593690288195677`*^9, 3.8593690447054763`*^9}, 3.8593690918271713`*^9, {
   3.859369258204688*^9, 3.859369268157257*^9}, {3.8593693226073713`*^9, 
   3.8593694309805703`*^9}, {3.859371036506401*^9, 3.8593710499911723`*^9}, {
   3.859371380143056*^9, 3.8593713946698866`*^9}, 3.8593714832769547`*^9, {
   3.859371534001856*^9, 3.8593715579442253`*^9}, 3.859374055388071*^9, {
   3.8593743274536324`*^9, 3.8593743491538734`*^9}, {3.8593743857139645`*^9, 
   3.859374397616646*^9}, {3.8593744958642645`*^9, 3.859374505954842*^9}, 
   3.859374583067253*^9, 3.859375099640799*^9, 3.8593751541139145`*^9, {
   3.8593751848756742`*^9, 3.8593752046568055`*^9}, 3.859381996525278*^9, 
   3.859382474415612*^9, 3.8593827985851536`*^9, 3.8593828462258787`*^9, 
   3.859382990175112*^9, 3.8593830774381027`*^9, 3.859383114507223*^9, {
   3.859383160523855*^9, 3.859383223871478*^9}, {3.8593833026079817`*^9, 
   3.8593833317626495`*^9}, 3.8593835184113255`*^9, 3.8593836938153577`*^9, 
   3.85938384002672*^9, {3.859384458340086*^9, 3.8593844727269087`*^9}, 
   3.859384585724372*^9, {3.859384668128085*^9, 3.8593848347176137`*^9}, {
   3.8594315414280844`*^9, 3.8594317619937*^9}},
 CellLabel->
  "During evaluation of \
In[1434]:=",ExpressionUUID->"37d04ce0-1498-447e-90bf-438bb4ad2fcf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Shortest tour found (black) is \"\>", "\[InvisibleSpace]", 
   "7.565622656636479`", 
   "\[InvisibleSpace]", "\<\", but the actual shortest tour (green) is \"\>", 
   "\[InvisibleSpace]", "7.56889700800269`"}],
  SequenceForm[
  "Shortest tour found (black) is ", 7.565622656636479, 
   ", but the actual shortest tour (green) is ", 7.56889700800269],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.859366960954293*^9, {3.8593670330704174`*^9, 3.8593670497133694`*^9}, 
   3.8593671503011227`*^9, {3.8593672267324944`*^9, 3.8593672430174255`*^9}, 
   3.859367370312707*^9, {3.859367533877062*^9, 3.859367571793231*^9}, {
   3.8593690288195677`*^9, 3.8593690447054763`*^9}, 3.8593690918271713`*^9, {
   3.859369258204688*^9, 3.859369268157257*^9}, {3.8593693226073713`*^9, 
   3.8593694309805703`*^9}, {3.859371036506401*^9, 3.8593710499911723`*^9}, {
   3.859371380143056*^9, 3.8593713946698866`*^9}, 3.8593714832769547`*^9, {
   3.859371534001856*^9, 3.8593715579442253`*^9}, 3.859374055388071*^9, {
   3.8593743274536324`*^9, 3.8593743491538734`*^9}, {3.8593743857139645`*^9, 
   3.859374397616646*^9}, {3.8593744958642645`*^9, 3.859374505954842*^9}, 
   3.859374583067253*^9, 3.859375099640799*^9, 3.8593751541139145`*^9, {
   3.8593751848756742`*^9, 3.8593752046568055`*^9}, 3.859381996525278*^9, 
   3.859382474415612*^9, 3.8593827985851536`*^9, 3.8593828462258787`*^9, 
   3.859382990175112*^9, 3.8593830774381027`*^9, 3.859383114507223*^9, {
   3.859383160523855*^9, 3.859383223871478*^9}, {3.8593833026079817`*^9, 
   3.8593833317626495`*^9}, 3.8593835184113255`*^9, 3.8593836938153577`*^9, 
   3.85938384002672*^9, {3.859384458340086*^9, 3.8593844727269087`*^9}, 
   3.859384585724372*^9, {3.859384668128085*^9, 3.8593848347176137`*^9}, {
   3.8594315414280844`*^9, 3.8594317619967003`*^9}},
 CellLabel->
  "During evaluation of \
In[1434]:=",ExpressionUUID->"d75b46b5-07de-459b-8ca2-3b93a9fa2ad9"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwBkQJu/SFib1JlAgAAACgAAAACAAAAG99uOqNN4j9OC28MQcnbP0w/b4aY
4MQ/RiHZGk1I2T/aoM4LJb/RP7Z8g1iBmtg/P5LWzeBc4D85qGoN7BDlP5Cf
UEGNK80/Yt3M2u9+3T8WjCcaYHncP3j3hoWfuLI/bh7NR/Fn2T+qLqL88dDa
P87mIazwQNs/y7esCoE65D9A7b18IziIP7KvUhp1xNY/WOXQEt1nsT9cOYHS
uKvNPxC7YyygRa4/Jgr7Fc/i0z/w6TiJYJ6tP4vmLm8cNuU/himPpWKO3j8R
vOmHW6LgP6QNa9An5cE/MFZqDegu1D8yaHERL0fbP2iW7Tif97s/Ty5e/pYQ
4T+JqA+Ay6riP+Rob8XRDc4/dLo8ksFgyD8dOQzXdF/kP9HnjokpJeI/hrE4
Bxup2D8upjetJ+jePyMYl2JJTeQ/45KPiRRp5D8T2Ia3f1n3PzHiibFsvfs/
lcUz2Urh9T+1L76+rqn8P26L2TJAuv8/BYaVIpM//D8VvLtjC1X8P2dSk41P
U/4/cx6V+TZ5/T+9yGCxx3f1P6rdfIABkPo/uUk8s3lf+D/MdEWyaLf1PygV
j1Q7J/Y/FEIaGK2Y+z8EiOwO0Zr/P3XpFXYK8v4/ORYnFvll+D9N/G51d7z7
P0RXKTs11Pk/5WS4S+i6+j/133u/eOj7P+nunTLZiPo//FrDfP14/j9X/G1Z
OvP/P6z1fJavXPk/9lhuNgiJ+D/kjmFWFnb8P+hjovESm/0/MID0nZ/Q/z9B
/62+nYL1P2JrrOT/afk/CSXmu+Lt/T+ZjTtk8fj6P0jBfFkjjfg/38TKHgtE
9j+/7s/bg7n8P1CDRm+E0vk/0SDQpZNm/T89JtA67lf3P8KYTjc=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
       AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
       AbsoluteThickness[1.6]}, {}}, {
      TagBox[
       {Opacity[0.], PointBox[{{0.5719772473594021, 0.4341585751937388}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {1}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.1631041199129818, 0.395037914484892}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {2}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.27729154732743455`, 0.38443025249393814`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {3}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.5113376636769046, 0.6583156835597556}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {4}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.22789159478383825`, 0.46087261550152026`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {5}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.4449081664481026, 0.07312962541524637}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {6}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.39696914684143436`, 0.419003006660868}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {7}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.42583863076980044`, 0.6321416100015481}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {8}}]& ], 
      TagBox[
       {Opacity[0.], 
        PointBox[{{0.011825825924225541`, 0.35574081011395287`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {9}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.06799108228087414, 0.23180303839257987`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {10}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.05912495176186472, 0.310718318429425}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {11}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.05784894633366722, 0.6628553554102877}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {12}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.4774405113972978, 0.5198190359641349}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {13}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.13980577160519403`, 0.3153629427918956}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {14}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.42621971801202385`, 0.10924716129155743`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {15}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.5332751243708546, 0.5833489896006238}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {16}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.23479673519506783`, 0.19045276298989544`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {17}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.6366523933554934, 0.5670364081081464}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {18}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.38532138543339334`, 0.48291961589584076`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {19}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.6344344068136291, 0.6378271757826862}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {20}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.4593503159535473`, 1.7337462363340246`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {21}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.3675030216657877`, 1.7914264155287871`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {22}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.9829713808364562`, 1.7655211783352354`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {23}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7707628150781194`, 1.8953395395557437`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {24}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8420934438053365`, 1.3417431763487422`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {25}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.6601576823285122`, 1.5233094216715541`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {26}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.3572775806163007`, 1.3845780661661795`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {27}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7247744504458113`, 1.9752970297781767`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {28}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.93409200789628, 1.5248957505549596`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {29}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7335123622176696`, 1.6143085776324861`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {30}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.6706316907714662`, 1.7442557792510318`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {31}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.6584102608894062`, 1.9045386193808431`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {32}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.9968818181366907`, 1.5851283911173182`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {33}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.5334550977909749`, 1.7788298963795848`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {34}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8503598631707465`, 1.9884334726448394`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {35}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.3443887184548233`, 1.588378804450905}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {36}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8705775584988393`, 1.6857770839058956`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {37}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.534457540092335, 1.3916121676268671`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {38}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7952917658248422`, 1.613895830793087}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {39}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8375431515760747`, 1.458967427958114}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$1509266, {
         40}}]& ]}}, {{{{}, {GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.8264062197723867`, 1.447830496154426}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.8264062197723867`, 1.447830496154426}], 
             Offset[{-17., -12.000000000000002`}, {1.8264062197723867`, 
              1.447830496154426}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.8264062197723867`, 
              1.447830496154426}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["40",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.8264062197723867, 1.447830496154426}], \
{0, 0}]}], 
        {Opacity[0], 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6]}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6], 
          TagBox[
           TooltipBox[PointBox[{1.7952917658248422`, 1.613895830793087}],
            StyleBox[
             PaneBox[
              FrameBox[
              "39", LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
               Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
               FrameMargins -> 2, BaselinePosition -> Automatic, StripOnInput -> 
               False], FrameMargins -> 0], {}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Pane[
              Framed[
              39, LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, {
               LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
                Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
                FrameMargins -> 2, BaselinePosition -> Automatic}], 
              FrameMargins -> 0], {}], "Tooltip"]& ]}}, GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 1.7763568394002505`*^-15}, {1.545594471896023, 
              1.380475235823179}], 
             Offset[{17., -11.999999999999998`}, {1.545594471896023, 
              1.380475235823179}], 
             Offset[{1.7763568394002505`*^-15, -12.000000000000002`}, {
              1.545594471896023, 1.380475235823179}], 
             Offset[{-1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.545594471896023, 1.380475235823179}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["38",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, -6.}, {1.545594471896023, 1.380475235823179}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              1.8548275584988394`, 1.6857770839058956`}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              1.8548275584988394`, 1.6857770839058956`}], 
             Offset[{-17., -6.000000000000002}, {1.8548275584988394`, 
              1.6857770839058956`}], 
             Offset[{-17., 5.999999999999998}, {1.8548275584988394`, 
              1.6857770839058956`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["37",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {1.8548275584988394, 1.6857770839058956}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.3332517866511353`, 1.577241872647217}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.3332517866511353`, 1.577241872647217}], 
             Offset[{-17., -12.000000000000002`}, {1.3332517866511353`, 
              1.577241872647217}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.3332517866511353`, 
              1.577241872647217}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["36",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.3332517866511353, 1.577241872647217}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              1.8503598631707465`, 1.9726834726448395`}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              1.8503598631707465`, 1.9726834726448395`}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              1.8503598631707465`, 1.9726834726448395`}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              1.8503598631707465`, 1.9726834726448395`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["35",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {1.8503598631707465, 1.9726834726448395}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 12.000000000000002`}, {1.544592029594663, 
              1.7899668281832728`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {1.544592029594663, 
              1.7899668281832728`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.544592029594663, 1.7899668281832728`}], 
             Offset[{-1.7763568394002505`*^-15, 11.999999999999998`}, {
              1.544592029594663, 1.7899668281832728`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["34",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.}, {1.544592029594663, 1.7899668281832728}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              1.9811318181366908`, 1.5851283911173182`}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              1.9811318181366908`, 1.5851283911173182`}], 
             Offset[{-17., -6.000000000000002}, {1.9811318181366908`, 
              1.5851283911173182`}], 
             Offset[{-17., 5.999999999999998}, {1.9811318181366908`, 
              1.5851283911173182`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["33",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {1.9811318181366908, 1.5851283911173182}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              1.6426602608894063`, 1.9045386193808431`}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              1.6426602608894063`, 1.9045386193808431`}], 
             Offset[{-17., -6.000000000000002}, {1.6426602608894063`, 
              1.9045386193808431`}], 
             Offset[{-17., 5.999999999999998}, {1.6426602608894063`, 
              1.9045386193808431`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["32",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {1.6426602608894063, 1.9045386193808431}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.6594947589677782`, 1.7331188474473438`}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.6594947589677782`, 1.7331188474473438`}], 
             Offset[{-17., -12.000000000000002`}, {1.6594947589677782`, 
              1.7331188474473438`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.6594947589677782`, 
              1.7331188474473438`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["31",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.6594947589677782, 1.7331188474473438}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              1.7335123622176696`, 1.5985585776324862`}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              1.7335123622176696`, 1.5985585776324862`}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              1.7335123622176696`, 1.5985585776324862`}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              1.7335123622176696`, 1.5985585776324862`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["30",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {1.7335123622176696, 1.5985585776324862}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              1.93409200789628, 1.5091457505549597`}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              1.93409200789628, 1.5091457505549597`}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              1.93409200789628, 1.5091457505549597`}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              1.93409200789628, 1.5091457505549597`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["29",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {1.93409200789628, 1.5091457505549597}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              1.7090244504458114`, 1.9752970297781767`}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              1.7090244504458114`, 1.9752970297781767`}], 
             Offset[{-17., -6.000000000000002}, {1.7090244504458114`, 
              1.9752970297781767`}], 
             Offset[{-17., 5.999999999999998}, {1.7090244504458114`, 
              1.9752970297781767`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["28",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {1.7090244504458114, 1.9752970297781767}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.3461406488126126`, 1.3734411343624915`}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.3461406488126126`, 1.3734411343624915`}], 
             Offset[{-17., -12.000000000000002`}, {1.3461406488126126`, 
              1.3734411343624915`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.3461406488126126`, 
              1.3734411343624915`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["27",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.3461406488126126, 1.3734411343624915}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.6490207505248242`, 1.5121724898678661`}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.6490207505248242`, 1.5121724898678661`}], 
             Offset[{-17., -12.000000000000002`}, {1.6490207505248242`, 
              1.5121724898678661`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.6490207505248242`, 
              1.5121724898678661`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["26",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.6490207505248242, 1.5121724898678661}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.8309565120016484`, 1.3306062445450542`}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.8309565120016484`, 1.3306062445450542`}], 
             Offset[{-17., -12.000000000000002`}, {1.8309565120016484`, 
              1.3306062445450542`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.8309565120016484`, 
              1.3306062445450542`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["25",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.8309565120016484, 1.3306062445450542}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              1.7707628150781194`, 1.8795895395557438`}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              1.7707628150781194`, 1.8795895395557438`}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              1.7707628150781194`, 1.8795895395557438`}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              1.7707628150781194`, 1.8795895395557438`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["24",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {1.7707628150781194, 1.8795895395557438}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              1.9672213808364563`, 1.7655211783352354`}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              1.9672213808364563`, 1.7655211783352354`}], 
             Offset[{-17., -6.000000000000002}, {1.9672213808364563`, 
              1.7655211783352354`}], 
             Offset[{-17., 5.999999999999998}, {1.9672213808364563`, 
              1.7655211783352354`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["23",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {1.9672213808364563, 1.7655211783352354}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 12.000000000000002`}, {
              1.3563660898620997`, 1.8025633473324751`}], 
             Offset[{1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.3563660898620997`, 1.8025633473324751`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.3563660898620997`, 
              1.8025633473324751`}], 
             Offset[{-17., 11.999999999999998`}, {1.3563660898620997`, 
              1.8025633473324751`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["22",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 6.}, {1.3563660898620997, 1.8025633473324751}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.4482133841498592`, 1.7226093045303366`}], 
             Offset[{1.7763568394002505`*^-15, -11.999999999999998`}, {
              1.4482133841498592`, 1.7226093045303366`}], 
             Offset[{-17., -12.000000000000002`}, {1.4482133841498592`, 
              1.7226093045303366`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.4482133841498592`, 
              1.7226093045303366`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["21",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.}, {1.4482133841498592, 1.7226093045303366}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 12.000000000000002`}, {0.6455713386173172, 
              0.6489641075863744}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.6455713386173172, 
              0.6489641075863744}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.6455713386173172, 0.6489641075863744}], 
             Offset[{-1.7763568394002505`*^-15, 11.999999999999998`}, {
              0.6455713386173172, 0.6489641075863744}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["20",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.}, {0.6455713386173172, 0.6489641075863744}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 12.000000000000002`}, {
              0.3741844536297052, 0.4940565476995289}], 
             Offset[{1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              0.3741844536297052, 0.4940565476995289}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {0.3741844536297052, 
              0.4940565476995289}], 
             Offset[{-17., 11.999999999999998`}, {0.3741844536297052, 
              0.4940565476995289}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["19",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 6.}, {0.3741844536297052, 0.4940565476995289}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 1.7763568394002505`*^-15}, {0.6477893251591815, 
              0.5558994763044582}], 
             Offset[{17., -11.999999999999998`}, {0.6477893251591815, 
              0.5558994763044582}], 
             Offset[{1.7763568394002505`*^-15, -12.000000000000002`}, {
              0.6477893251591815, 0.5558994763044582}], 
             Offset[{-1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.6477893251591815, 0.5558994763044582}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["18",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, -6.}, {0.6477893251591815, 0.5558994763044582}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 12.000000000000002`}, {0.24593366699875596`, 
              0.20158969479358357`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.24593366699875596`, 
              0.20158969479358357`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.24593366699875596`, 0.20158969479358357`}], 
             Offset[{-1.7763568394002505`*^-15, 11.999999999999998`}, {
              0.24593366699875596`, 0.20158969479358357`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["17",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.}, {0.24593366699875596, 0.20158969479358357}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 6.000000000000002}, {
              0.5175251243708545, 0.5833489896006238}], 
             Offset[{1.7763568394002505`*^-15, -5.999999999999998}, {
              0.5175251243708545, 0.5833489896006238}], 
             Offset[{-17., -6.000000000000002}, {0.5175251243708545, 
              0.5833489896006238}], 
             Offset[{-17., 5.999999999999998}, {0.5175251243708545, 
              0.5833489896006238}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["16",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 0.}, {0.5175251243708545, 0.5833489896006238}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 12.000000000000002`}, {0.437356649815712, 
              0.12038409309524555`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.437356649815712, 
              0.12038409309524555`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.437356649815712, 0.12038409309524555`}], 
             Offset[{-1.7763568394002505`*^-15, 11.999999999999998`}, {
              0.437356649815712, 0.12038409309524555`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["15",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.}, {0.437356649815712, 0.12038409309524555}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              0.13980577160519403`, 0.2996129427918956}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              0.13980577160519403`, 0.2996129427918956}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              0.13980577160519403`, 0.2996129427918956}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              0.13980577160519403`, 0.2996129427918956}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["14",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {0.13980577160519403, 0.2996129427918956}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.000000000000002}, {0.4931905113972978, 
              0.5198190359641349}], 
             Offset[{17., -5.999999999999998}, {0.4931905113972978, 
              0.5198190359641349}], 
             Offset[{1.7763568394002505`*^-15, -6.000000000000002}, {
              0.4931905113972978, 0.5198190359641349}], 
             Offset[{-1.7763568394002505`*^-15, 5.999999999999998}, {
              0.4931905113972978, 0.5198190359641349}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["13",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {0.4931905113972978, 0.5198190359641349}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 12.000000000000002`}, {0.06898587813735534, 
              0.6739922872139759}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.06898587813735534, 
              0.6739922872139759}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.06898587813735534, 0.6739922872139759}], 
             Offset[{-1.7763568394002505`*^-15, 11.999999999999998`}, {
              0.06898587813735534, 0.6739922872139759}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["12",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.}, {0.06898587813735534, 0.6739922872139759}], \
{0, 0}]}], 
        {Opacity[0], 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6]}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6], 
          TagBox[
           TooltipBox[PointBox[{0.05912495176186472, 0.310718318429425}],
            StyleBox[
             PaneBox[
              FrameBox[
              "11", LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
               Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
               FrameMargins -> 2, BaselinePosition -> Automatic, StripOnInput -> 
               False], FrameMargins -> 0], {}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Pane[
              Framed[
              11, LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, {
               LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
                Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
                FrameMargins -> 2, BaselinePosition -> Automatic}], 
              FrameMargins -> 0], {}], "Tooltip"]& ]}}, GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              0.06799108228087414, 0.2160530383925799}], 
             Offset[{8.500000000000002, -11.999999999999998`}, {
              0.06799108228087414, 0.2160530383925799}], 
             Offset[{-8.499999999999998, -12.000000000000002`}, {
              0.06799108228087414, 0.2160530383925799}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              0.06799108228087414, 0.2160530383925799}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["10",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.}, {0.06799108228087414, 0.2160530383925799}], \
{0, 0}]}], 
        {Opacity[0], 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6]}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6], 
          TagBox[
           TooltipBox[PointBox[{0.011825825924225541`, 0.35574081011395287`}],
            StyleBox[
             PaneBox[
              FrameBox[
              "9", LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
               Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
               FrameMargins -> 2, BaselinePosition -> Automatic, StripOnInput -> 
               False], FrameMargins -> 0], {}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Pane[
              Framed[
              9, LabelStyle -> {}, Background -> None, ContentPadding -> 
               False, {
               LabelStyle -> {}, Frame -> True, RoundingRadius -> 4, 
                Background -> GrayLevel[1, 0.65], FrameStyle -> None, 
                FrameMargins -> 2, BaselinePosition -> Automatic}], 
              FrameMargins -> 0], {}], "Tooltip"]& ]}}, GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 12.}, {0.4147016989661123, 
              0.6432785418052362}], 
             Offset[{1.7763568394002505`*^-15, 8.881784197001252*^-16}, {
              0.4147016989661123, 0.6432785418052362}], 
             Offset[{-10.999999999999998`, -8.881784197001252*^-16}, {
              0.4147016989661123, 0.6432785418052362}], 
             Offset[{-11.000000000000002`, 12.}, {0.4147016989661123, 
              0.6432785418052362}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["8",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-5.5, 6.}, {0.4147016989661123, 0.6432785418052362}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              0.4081060786451225, 0.40786607485717985`}], 
             Offset[{11.000000000000002`, -12.}, {0.4081060786451225, 
              0.40786607485717985`}], 
             Offset[{1.7763568394002505`*^-15, -12.}, {0.4081060786451225, 
              0.40786607485717985`}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              0.4081060786451225, 0.40786607485717985`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["7",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.}, {0.4081060786451225, 0.40786607485717985}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 6.000000000000001}, {
              0.4606581664481026, 0.07312962541524637}], 
             Offset[{11.000000000000002`, -5.999999999999999}, {
              0.4606581664481026, 0.07312962541524637}], 
             Offset[{1.7763568394002505`*^-15, -6.000000000000001}, {
              0.4606581664481026, 0.07312962541524637}], 
             Offset[{-1.7763568394002505`*^-15, 5.999999999999999}, {
              0.4606581664481026, 0.07312962541524637}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["6",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, 0.}, {0.4606581664481026, 0.07312962541524637}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 12.}, {0.21675466298015011`, 
              0.4720095473052084}], 
             Offset[{1.7763568394002505`*^-15, 8.881784197001252*^-16}, {
              0.21675466298015011`, 0.4720095473052084}], 
             Offset[{-10.999999999999998`, -8.881784197001252*^-16}, {
              0.21675466298015011`, 0.4720095473052084}], 
             Offset[{-11.000000000000002`, 12.}, {0.21675466298015011`, 
              0.4720095473052084}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["5",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-5.5, 6.}, {0.21675466298015011, 0.4720095473052084}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{5.499999999999998, 12.}, {0.5113376636769046, 
              0.6740656835597556}], 
             Offset[{5.500000000000002, 8.881784197001252*^-16}, {
              0.5113376636769046, 0.6740656835597556}], 
             Offset[{-5.499999999999998, -8.881784197001252*^-16}, {
              0.5113376636769046, 0.6740656835597556}], 
             Offset[{-5.500000000000002, 12.}, {0.5113376636769046, 
              0.6740656835597556}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["4",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.}, {0.5113376636769046, 0.6740656835597556}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              0.2884284791311227, 0.37329332069025}], 
             Offset[{11.000000000000002`, -12.}, {0.2884284791311227, 
              0.37329332069025}], 
             Offset[{1.7763568394002505`*^-15, -12.}, {0.2884284791311227, 
              0.37329332069025}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              0.2884284791311227, 0.37329332069025}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["3",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.}, {0.2884284791311227, 0.37329332069025}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 12.}, {0.15196718810929366`, 
              0.40617484628858014`}], 
             Offset[{1.7763568394002505`*^-15, 8.881784197001252*^-16}, {
              0.15196718810929366`, 0.40617484628858014`}], 
             Offset[{-10.999999999999998`, -8.881784197001252*^-16}, {
              0.15196718810929366`, 0.40617484628858014`}], 
             Offset[{-11.000000000000002`, 12.}, {0.15196718810929366`, 
              0.40617484628858014`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["2",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-5.5, 6.}, {0.15196718810929366, 0.40617484628858014}], \
{0, 0}]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              0.5831141791630903, 0.42302164339005066`}], 
             Offset[{11.000000000000002`, -12.}, {0.5831141791630903, 
              0.42302164339005066`}], 
             Offset[{1.7763568394002505`*^-15, -12.}, {0.5831141791630903, 
              0.42302164339005066`}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              0.5831141791630903, 0.42302164339005066`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["1",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.}, {0.5831141791630903, 0.42302164339005066}], \
{0, 0}]}]}}, {}}, {}}}, {
    {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxd0v0v1AEAx3G1WuWhEGanLBnXrXakJU/tQ/PUw8VUHspyHfJUd2t5XLci
dbnJwxhJE1MaOoxWnpnFUp7uZHLk6brT3YZcde7pe3fVr/3w3usfeDswWGHx
W42MjCh/+ydKpseWopfgWZ9stmouwfiKA2/Ddw4j7TzjHC8xQqhX9eXmy+DW
78keaRSBQymqYxQuwKJH9uhK7RI4rR477BpmQH11ooksXQDTfixIniBEI7WW
kPNnMVszbuLUL8A7dm5kTuUMiqtD/QoOj4ExPzr74+48NmQeXPrzJuSvUFn7
3CU4BxanYmkQgQ5CEi1YiJdmKXyyZACu4clmUuoUfNd62Y4eeWhrCSOlDU7D
vDv2SE1AM5yNtdYTos+IlPAt5xNaEe2ZM9nxegziRNaQwGwcqV0+JQP0Ybgl
3rJwCZpDYvmaR7WyGzaPySR61ldkKjkPqzvaYLfI9HpBE+G8CcvU7+Mc9nua
fkmNEUPwvZBLcRLB0fYJ4zRNjG8lRVyrJDFGUwPaEtsVOGRddNGbvIngAXaU
Y4EKi4Of7E38N9E4z87eUqxB52mfN1kxKty2L1O7Z+nQO0xv/ZChgOAAv670
ug4nnfle6xFKpMms041/6uFpQ7ZRx6sQQdyM8vplAE/BLm+JVoOZL3Tz7TJg
O6fsYCkI7HJa6Rat6fC0wDtOrtKgf31iLreTQGhuIOvBpBo0gpmW0aOFfwTF
+/iUGpK4jrPSLg0Ui3f6M6VaWPd0x5pcIpAQVloQckEPaWyt3PKZDq7Zv6uq
+QZYnSLZNlVosS1vdbeg0gDZepWbME8D4vJ7ti5Tj81IpvtOrgriwmvhNukE
9s5w2u9FKXFUxG290atF2dAx4ZllBd669PU1NxDwMzT1Vd1XgJHCExuS1Pj/
vz88FVZ/
      "]]}, 
    {RGBColor[1, 0, 0], Thickness[Tiny], LineBox[CompressedData["
1:eJxd0v0v1AEAx3G1WuWhEGanLBnXrXakJU/tQ/PUw8VUHspyHfJUd2t5XLci
dbnJwxhJE1MaOoxWnpnFUp7uZHLk6brT3YZcde7pe3fVr/3w3usfeDswWGHx
W42MjCh/+6ej7RPGaZoY30qKuFZJYuz3NP2SGiOG4Hshl+Ikgt0i0+sFTYTz
JixTv49zsHlMJtGzviJTyXlY3dEGt8RbFi5Bc0gsX/OoVnZDnMgaEpiNI7XL
p2SAPoxICd9yPqEV0Z45kx2vx2DeHXukJqAZzsZa6wnRZ/iu9bIdPfLQ1hJG
ShucxkuzFD5ZMgDX8GQzKXUK58DiVCwNItBBSKIFC7Eh8+DSnzchf4XK2ucu
QXF1qF/B4TEw5kdnf9ydx2zNuIlTvwDv2LmROZUzYNqPBckThGik1hJy/iw4
rR477BpmQH11ooksXQCHUlTHKFyARY/s0ZXaJYyvOPA2fOcw0s4zzvESI4R6
VV9uvgxu/Z7skUYRUDI9thS9BM/6ZLNVcwn8DE19VfcVYKTwxIYkNcqGjgnP
LCvw1qWvr7mBwN4ZTvu9KCWOiritN3q12Ixkuu/kqiAuvBZuk05Atl7lJszT
gLj8nq3L1MPqFMm2qUKLbXmruwWVBkhja+WWz3Rwzf5dVc03wLqnO9bkEoGE
sNKCkAt6SOI6zkq7NFAs3unPlGpBI5hpGT1a+EdQvI9PqdG/PjGX20kgNDeQ
9WBSjV1OK92iNR2eFnjHyVUaMPOFbr5dBmznlB0sBYEI4maU1y8DeAp2eUu0
Gmky63Tjn3p42pBt1PEqCA7w60qv63DSme+1HqHEbfsytXuWDr3D9NYPGQo0
zrOztxRr0Hna501WjArBA+woxwIVFgc/2Zv4b2I0NaAtsV2BQ9ZFF73Jm/j/
vz+0ZlVS
      "]]}, 
    {RGBColor[0, 1, 0], Thickness[Tiny], Dashing[{Small, Small}], 
     LineBox[CompressedData["
1:eJxd0v0v1AEAx3G1WuWhEGanLBnXrXakJU/tQ/PUw8VUHspyHfJUd2t5XLci
dbnJwxhJE1MaOoxWnpnFUp7uZHLk6brT3YZcde7pe3fVr/3w3usfeDswWGHx
W42MjCh/+6fdItPrBU2E8yYsU7+Pc9jvafolNUYMwfdCLsVJBEfbJ4zTNDG+
lRRxrZLEGE0NaEtsV+CQddFFb/ImggfYUY4FKiwOfrI38d9E4zw7e0uxBp2n
fd5kxahw275M7Z6lQ+8wvfVDhgKCA/y60us6nHTme61HKJEms043/qmHpw3Z
Rh2vQgRxM8rrlwE8Bbu8JVoNZr7QzbfLgO2csoOlILDLaaVbtKbD0wLvOLlK
g/71ibncTgKhuYGsB5Nq0AhmWkaPFv4RFO/jU2pI4jrOSrs0UCze6c+UamHd
0x1rcolAQlhpQcgFPaSxtXLLZzq4Zv+uquYbYHWKZNtUocW2vNXdgkoDZOtV
bsI8DYjL79m6TD02I5nuO7kqiAuvhdukE9g7w2m/F6XEURG39UavFmVDx4Rn
lhV469LX19xAwM/Q1Fd1XwFGCk9sSFIDJdNjS9FL8KxPNls1l2B8xYG34TuH
kXaecY6XGCHUq/py82Vw6/dkjzSKwKEU1TEKF2DRI3t0pXYJnFaPHXYNM6C+
OtFEli6AaT8WJE8QopFaS8j5s5itGTdx6hfgHTs3MqdyBsXVoX4Fh8fAmB+d
/XF3HhsyDy79eRPyV6isfe4SnAOLU7E0iEAHIYkWLMRLsxQ+WTIA1/BkMyl1
CubdsUdqAprhbKy1nhB9hu9aL9vRIw9tLWGktMFpREr4lvMJrYj2zJnseD0G
cSJrSGA2jtQun5IB+jDcEm9ZuATNIbF8zaNa2Q2bx2QSPesrMpWch9Udbfj/
vz+vKlTj
      "]]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{526.6666666666664, Automatic},
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 2.}, {0., 2.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8590452610658383`*^9, 3.8590500574739714`*^9, 3.859050853020894*^9, 
   3.8590509036002817`*^9, 3.8590509436805825`*^9, 3.859051017385399*^9, 
   3.859051058916754*^9, {3.859051165111351*^9, 3.859051180960532*^9}, {
   3.859051241215539*^9, 3.8590512578605976`*^9}, 3.8593559200407887`*^9, 
   3.8593559654633865`*^9, 3.859358733615716*^9, {3.8593588981281257`*^9, 
   3.859358939586497*^9}, 3.859365890463064*^9, 3.8593660080597906`*^9, 
   3.859366046099966*^9, 3.859366090273493*^9, 3.859366147455763*^9, {
   3.859366341757877*^9, 3.859366370415516*^9}, 3.859366463300829*^9, 
   3.859366542278346*^9, 3.8593665861758566`*^9, 3.8593666729818215`*^9, {
   3.8593667306791215`*^9, 3.8593667439328794`*^9}, {3.8593669531658473`*^9, 
   3.8593669611953063`*^9}, {3.8593670333164315`*^9, 3.859367049961384*^9}, 
   3.859367150536136*^9, {3.859367226983509*^9, 3.859367243289441*^9}, 
   3.8593673705567207`*^9, {3.859367534121076*^9, 3.859367572037245*^9}, {
   3.8593690290755825`*^9, 3.8593690449824924`*^9}, 3.859369092102187*^9, {
   3.859369258470703*^9, 3.8593692684262724`*^9}, {3.8593693228843875`*^9, 
   3.8593694312335844`*^9}, {3.8593710368094187`*^9, 3.859371050264188*^9}, {
   3.8593713804000707`*^9, 3.859371394924901*^9}, 3.859371483790984*^9, {
   3.859371534274872*^9, 3.8593715582132406`*^9}, 3.859374055632085*^9, {
   3.859374327713647*^9, 3.8593743494318895`*^9}, {3.85937438597998*^9, 
   3.859374397882661*^9}, {3.8593744961142793`*^9, 3.859374506220857*^9}, 
   3.859374583337268*^9, 3.8593750998988132`*^9, 3.8593751544389334`*^9, {
   3.8593751851396894`*^9, 3.859375204924821*^9}, 3.859381996769292*^9, 
   3.8593824746516256`*^9, 3.859382798821167*^9, 3.859382846468892*^9, 
   3.8593829904141254`*^9, 3.859383077700118*^9, 3.859383114769238*^9, {
   3.8593831607828703`*^9, 3.859383224131493*^9}, {3.859383302866997*^9, 
   3.8593833320286646`*^9}, 3.8593835186513386`*^9, 3.8593836940623717`*^9, 
   3.8593838401667285`*^9, {3.859384458680105*^9, 3.85938447309593*^9}, 
   3.859384586064391*^9, {3.8593846684711046`*^9, 3.8593848350786343`*^9}, {
   3.859431544936285*^9, 3.85943176233272*^9}},
 CellLabel->
  "Out[1442]=",ExpressionUUID->"d227af57-fd90-4e2c-a488-8ea958f2535e"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      NCache[
       Rational[1, 360], 0.002777777777777778]], AbsoluteThickness[1.6], 
     PointBox[CompressedData["
1:eJxc3HF01vP7OP5bkkkymUwmk8lkMplMJrdMJslkMplMJpPJZDKZ3DKZTCbJ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      "]]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       NCache[
        Rational[1, 360], 0.002777777777777778]], AbsoluteThickness[
      1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       NCache[
        Rational[1, 360], 0.002777777777777778]], AbsoluteThickness[
      1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 7.558556766675365},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{534.0000000000003, Automatic},
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 40001.}, {7.558556766675365, 7.692808675936492}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8590452610658383`*^9, 3.8590500574739714`*^9, 3.859050853020894*^9, 
   3.8590509036002817`*^9, 3.8590509436805825`*^9, 3.859051017385399*^9, 
   3.859051058916754*^9, {3.859051165111351*^9, 3.859051180960532*^9}, {
   3.859051241215539*^9, 3.8590512578605976`*^9}, 3.8593559200407887`*^9, 
   3.8593559654633865`*^9, 3.859358733615716*^9, {3.8593588981281257`*^9, 
   3.859358939586497*^9}, 3.859365890463064*^9, 3.8593660080597906`*^9, 
   3.859366046099966*^9, 3.859366090273493*^9, 3.859366147455763*^9, {
   3.859366341757877*^9, 3.859366370415516*^9}, 3.859366463300829*^9, 
   3.859366542278346*^9, 3.8593665861758566`*^9, 3.8593666729818215`*^9, {
   3.8593667306791215`*^9, 3.8593667439328794`*^9}, {3.8593669531658473`*^9, 
   3.8593669611953063`*^9}, {3.8593670333164315`*^9, 3.859367049961384*^9}, 
   3.859367150536136*^9, {3.859367226983509*^9, 3.859367243289441*^9}, 
   3.8593673705567207`*^9, {3.859367534121076*^9, 3.859367572037245*^9}, {
   3.8593690290755825`*^9, 3.8593690449824924`*^9}, 3.859369092102187*^9, {
   3.859369258470703*^9, 3.8593692684262724`*^9}, {3.8593693228843875`*^9, 
   3.8593694312335844`*^9}, {3.8593710368094187`*^9, 3.859371050264188*^9}, {
   3.8593713804000707`*^9, 3.859371394924901*^9}, 3.859371483790984*^9, {
   3.859371534274872*^9, 3.8593715582132406`*^9}, 3.859374055632085*^9, {
   3.859374327713647*^9, 3.8593743494318895`*^9}, {3.85937438597998*^9, 
   3.859374397882661*^9}, {3.8593744961142793`*^9, 3.859374506220857*^9}, 
   3.859374583337268*^9, 3.8593750998988132`*^9, 3.8593751544389334`*^9, {
   3.8593751851396894`*^9, 3.859375204924821*^9}, 3.859381996769292*^9, 
   3.8593824746516256`*^9, 3.859382798821167*^9, 3.859382846468892*^9, 
   3.8593829904141254`*^9, 3.859383077700118*^9, 3.859383114769238*^9, {
   3.8593831607828703`*^9, 3.859383224131493*^9}, {3.859383302866997*^9, 
   3.8593833320286646`*^9}, 3.8593835186513386`*^9, 3.8593836940623717`*^9, 
   3.8593838401667285`*^9, {3.859384458680105*^9, 3.85938447309593*^9}, 
   3.859384586064391*^9, {3.8593846684711046`*^9, 3.8593848350786343`*^9}, {
   3.859431544936285*^9, 3.859431762774745*^9}},
 CellLabel->"Out[1443]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"567531bc-c9e2-429b-a5c0-752c4a59e87a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{
            RowBox[{
            "cities", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            ",", "i"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"PointSize", "[", "Medium", "]"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Line", "[", 
        RowBox[{"cities", "\[LeftDoubleBracket]", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{
           "savedPerm", "\[LeftDoubleBracket]", "j", 
            "\[RightDoubleBracket]"}], ",", 
           RowBox[{"savedPerm", "\[LeftDoubleBracket]", 
            RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "1", ",", "nSave", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8593567864943466`*^9, 3.8593568008411674`*^9}, {
  3.8593586691650295`*^9, 3.8593587015288806`*^9}, {3.859383375142131*^9, 
  3.859383400691592*^9}, {3.8593834888366337`*^9, 3.859383494841977*^9}},
 CellLabel->
  "In[1444]:=",ExpressionUUID->"75f1c713-a4e6-4bdd-af8f-204ba6adb139"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`j$$ = 338, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`j$$], 1, 338, 1}}, Typeset`size$$ = {
    540., {264., 272.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`j$1513336$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`j$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`j$$, $CellContext`j$1513336$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[{
         ListPlot[
          Table[
           Labeled[
            
            Part[$CellContext`cities, $CellContext`i], $CellContext`i], \
{$CellContext`i, 1, $CellContext`n}], PlotStyle -> PointSize[Medium], 
          PlotRange -> {{$CellContext`xmin, $CellContext`xmax}, \
{$CellContext`ymin, $CellContext`ymax}}, AspectRatio -> 1], 
         Graphics[
          Line[
           Part[$CellContext`cities, 
            Append[
             Part[$CellContext`savedPerm, $CellContext`j$$], 
             Part[$CellContext`savedPerm, $CellContext`j$$, 1]]]]]}], 
      "Specifications" :> {{$CellContext`j$$, 1, 338, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{612., {327., 336.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.8593586432705483`*^9, 3.859358710366386*^9, 3.8593589810688696`*^9, 
   3.8593658994195766`*^9, {3.8593661288697004`*^9, 3.8593661670738854`*^9}, 
   3.8593664097607665`*^9, 3.8593665597183437`*^9, 3.859366680347243*^9, 
   3.8593672573592463`*^9, 3.8593673795062323`*^9, 3.8593694420352025`*^9, 
   3.8593713649541874`*^9, 3.859373747641469*^9, 3.8593744050660715`*^9, 
   3.8593752154584236`*^9, {3.859382850752137*^9, 3.8593828617307653`*^9}, {
   3.8593830009917307`*^9, 3.8593830036858845`*^9}, {3.8593833396761017`*^9, 
   3.859383342285251*^9}, 3.859383401500638*^9, 3.859383495192997*^9, {
   3.8593835480000176`*^9, 3.859383571311351*^9}, 3.8593838613099375`*^9, 
   3.859384489199851*^9, 3.8593846090187044`*^9, {3.8593848963191366`*^9, 
   3.8593849163832846`*^9}, 3.859431792518446*^9},
 CellLabel->
  "Out[1444]=",ExpressionUUID->"9651fdfb-8030-4676-83e6-5e84d7d41c63"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1428, 862},
WindowMargins->{{Automatic, -1545}, {Automatic, 99}},
Magnification:>1.5 Inherited,
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 355, 5, 146, "Title",ExpressionUUID->"b15229c8-5a8d-4e56-afb3-39951f71899b"],
Cell[CellGroupData[{
Cell[960, 31, 611, 9, 99, "Section",ExpressionUUID->"d8dca711-7222-4483-a9ec-b9d0ca08e28e"],
Cell[1574, 42, 170, 3, 52, "Text",ExpressionUUID->"591d67b5-7567-4a89-ab20-371f0f8ac8f8"],
Cell[1747, 47, 5025, 134, 537, "Input",ExpressionUUID->"45a6232c-391f-4210-9514-9e5d2300345f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6809, 186, 677, 11, 99, "Section",ExpressionUUID->"0df30b08-34d4-4ecd-a531-7a8c91a746de"],
Cell[CellGroupData[{
Cell[7511, 201, 1803, 47, 160, "Input",ExpressionUUID->"bd16330c-020d-4e25-9e43-640650c07835"],
Cell[9317, 250, 587, 12, 34, "Print",ExpressionUUID->"815fad7b-1d82-491a-8c80-efec2fa79ac3"],
Cell[9907, 264, 57856, 1240, 500, "Output",ExpressionUUID->"237a2574-05a1-4d04-a6f6-aa997bb7ce46"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[67812, 1510, 718, 12, 99, "Section",ExpressionUUID->"6045c388-2f2b-4767-9a08-97aaff3123e2"],
Cell[CellGroupData[{
Cell[68555, 1526, 312, 7, 67, "Subsubsection",ExpressionUUID->"0cc8be72-eacd-420d-9af0-32b8bf2826db"],
Cell[68870, 1535, 25204, 471, 28, "Input",ExpressionUUID->"ecdda7ec-fa69-4d39-bc74-0c1c937e0baf",
 CellOpen->False],
Cell[CellGroupData[{
Cell[94099, 2010, 6578, 140, 479, "Input",ExpressionUUID->"acf4e686-9a95-417c-9ebd-460e38edbdd4"],
Cell[CellGroupData[{
Cell[100702, 2154, 1739, 28, 34, "Print",ExpressionUUID->"f539e9b3-8c8e-4708-82b4-63f0a8ce4807"],
Cell[102444, 2184, 1735, 28, 34, "Print",ExpressionUUID->"37d04ce0-1498-447e-90bf-438bb4ad2fcf"],
Cell[104182, 2214, 1964, 32, 34, "Print",ExpressionUUID->"d75b46b5-07de-459b-8ca2-3b93a9fa2ad9"]
}, Open  ]],
Cell[106161, 2249, 61272, 1296, 830, "Output",ExpressionUUID->"d227af57-fd90-4e2c-a488-8ea958f2535e"],
Cell[167436, 3547, 93959, 1555, 535, 84285, 1401, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"567531bc-c9e2-429b-a5c0-752c4a59e87a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[261432, 5107, 1828, 45, 131, "Input",ExpressionUUID->"75f1c713-a4e6-4bdd-af8f-204ba6adb139"],
Cell[263263, 5154, 2979, 59, 743, "Output",ExpressionUUID->"9651fdfb-8030-4676-83e6-5e84d7d41c63"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

