(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    184713,       3883]
NotebookOptionsPosition[    181293,       3823]
NotebookOutlinePosition[    181729,       3840]
CellTagsIndexPosition[    181686,       3837]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Travelling salesman problem", "Title",
 CellChangeTimes->{{3.8498659197237196`*^9, 3.8498659353906155`*^9}, {
   3.8502884358260317`*^9, 3.850288452690901*^9}, {3.8504078931535835`*^9, 
   3.8504079297240343`*^9}, {3.8587553024030123`*^9, 3.8587553131456265`*^9}, 
   3.8590119899661674`*^9},ExpressionUUID->"b15229c8-5a8d-4e56-afb3-\
39951f71899b"],

Cell[CellGroupData[{

Cell["Problem setup", "Section",
 CellChangeTimes->{{3.850284992156113*^9, 3.8502851174278107`*^9}, {
  3.8502884635283027`*^9, 3.8502884649516716`*^9}, {3.850407943113345*^9, 
  3.8504079457856646`*^9}, {3.8504449061005325`*^9, 3.8504449155490723`*^9}, {
  3.850446227606118*^9, 3.8504462511734657`*^9}, {3.8587553227221746`*^9, 
  3.8587553695458527`*^9}, {3.858764261860464*^9, 3.858764277268345*^9}, {
  3.859011999602493*^9, 3.8590120411627245`*^9}, {3.859038099864771*^9, 
  3.85903812597431*^9}, {3.859038242820649*^9, 
  3.8590382494144087`*^9}},ExpressionUUID->"d8dca711-7222-4483-a9ec-\
b9d0ca08e28e"],

Cell["Random cities on a square:", "Text",
 CellChangeTimes->{{3.8590381385441203`*^9, 
  3.859038158854045*^9}},ExpressionUUID->"591d67b5-7567-4a89-ab20-\
371f0f8ac8f8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"distribution", "=", "\"\<Circle\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "40"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", "0.0"}], ";", 
  RowBox[{"xmax", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymin", "=", "0.0"}], ";", 
  RowBox[{"ymax", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"distribution", "\[Equal]", "\"\<Random\>\""}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"cities", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RandomReal", "[", 
          RowBox[{"{", 
           RowBox[{"xmin", ",", "xmax"}], "}"}], "]"}], ",", 
         RowBox[{"RandomReal", "[", 
          RowBox[{"{", 
           RowBox[{"ymin", ",", "ymax"}], "}"}], "]"}]}], "}"}], ",", "n"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"distribution", "\[Equal]", "\"\<Circle\>\""}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x0", ",", "y0"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"xmin", "+", "xmax"}], ")"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ymin", "+", "ymax"}], ")"}], "/", "2"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"r", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "2"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cities", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x0", "+", 
           RowBox[{"r", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"i", "*", "2", "*", 
              RowBox[{"\[Pi]", "/", "n"}]}], "]"}]}]}], ",", 
          RowBox[{"y0", "+", 
           RowBox[{"r", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"i", "*", "2", "*", 
              RowBox[{"\[Pi]", "/", "n"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"distribution", "\[Equal]", "\"\<TwoSquares\>\""}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"cities", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"xmin", ",", 
             RowBox[{"xmax", "/", "3"}]}], "}"}], "]"}], ",", 
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"ymin", ",", 
             RowBox[{"ymax", "/", "3"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"n", "/", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"cities", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"cities", ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"RandomReal", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"xmax", "/", "3"}]}], ",", "xmax"}], "}"}], "]"}], 
            ",", 
            RowBox[{"RandomReal", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"ymax", "/", "3"}]}], ",", "ymax"}], "}"}], "]"}]}], 
           "}"}], ",", 
          RowBox[{"n", "/", "2"}]}], "]"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"distances", "=", 
   RowBox[{"DistanceMatrix", "[", "cities", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"NumberForm", "[", 
    RowBox[{
     RowBox[{"MatrixForm", "[", "distances", "]"}], ",", "3"}], "]"}], " ", 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.8590365131599*^9, 3.85903652234002*^9}, 
   3.859037811944024*^9, {3.859037922938665*^9, 3.8590379798048615`*^9}, {
   3.8590381327143497`*^9, 3.859038176254588*^9}, {3.859038286614098*^9, 
   3.8590385552547655`*^9}, {3.8590386451253033`*^9, 3.859038728154519*^9}, {
   3.859038822865164*^9, 3.859038863555127*^9}, {3.8590511361208134`*^9, 
   3.859051142830429*^9}, {3.859375273298732*^9, 3.859375274406795*^9}, {
   3.859382941597333*^9, 3.8593829426183915`*^9}, 3.8593837529137383`*^9, {
   3.859383886145358*^9, 3.859384007199282*^9}, {3.8593840711669407`*^9, 
   3.859384136080654*^9}, {3.8593841730337677`*^9, 3.859384225198751*^9}, {
   3.8593842636179485`*^9, 3.8593842726224637`*^9}, {3.859384330135753*^9, 
   3.859384330988802*^9}, {3.8593843660378065`*^9, 3.859384366644841*^9}, {
   3.859384400942803*^9, 3.8593844027639074`*^9}, {3.859431277105966*^9, 
   3.8594312956950293`*^9}, {3.859432010846934*^9, 3.8594320119109945`*^9}},
 CellLabel->
  "In[326]:=",ExpressionUUID->"45a6232c-391f-4210-9514-9e5d2300345f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Efficient built-in algorithm to find the shortest  tour  in Mathematica\
\>", "Section",
 CellChangeTimes->{{3.850284992156113*^9, 3.8502851174278107`*^9}, {
  3.8502884635283027`*^9, 3.8502884649516716`*^9}, {3.850407943113345*^9, 
  3.8504079457856646`*^9}, {3.8504449061005325`*^9, 3.8504449155490723`*^9}, {
  3.850446227606118*^9, 3.8504462511734657`*^9}, {3.8587553227221746`*^9, 
  3.8587553695458527`*^9}, {3.858764261860464*^9, 3.858764277268345*^9}, {
  3.859011999602493*^9, 3.8590120411627245`*^9}, {3.859038099864771*^9, 
  3.85903812597431*^9}, {3.8590391126761723`*^9, 
  3.859039180985834*^9}},ExpressionUUID->"0df30b08-34d4-4ecd-a531-\
7a8c91a746de"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"shortest", "=", 
   RowBox[{"FindShortestTour", "[", "cities", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The length of the shortest tour is \>\"", ",", " ", 
    RowBox[{
    "shortest", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
   "]"}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{
          "cities", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          ",", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"PointSize", "[", "Medium", "]"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Graphics", "[", 
     RowBox[{"Line", "[", 
      RowBox[{"cities", "\[LeftDoubleBracket]", 
       RowBox[{
       "shortest", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       "\[RightDoubleBracket]"}], "]"}], "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.859355617199467*^9, 3.8593556487112694`*^9}, {
   3.8593558292805977`*^9, 3.8593558355259542`*^9}, 3.859355889204025*^9, {
   3.8593562623793693`*^9, 3.8593562929231167`*^9}, {3.859383746690382*^9, 
   3.8593837926100082`*^9}},
 CellLabel->
  "In[334]:=",ExpressionUUID->"bd16330c-020d-4e25-9e43-640650c07835"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The length of the shortest tour is \"\>", "\[InvisibleSpace]", 
   "6.276727658227593`"}],
  SequenceForm["The length of the shortest tour is ", 6.276727658227593],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.859356333442434*^9, 3.859374003396097*^9, 3.859381985561651*^9, 
   3.859382978914468*^9, {3.8593837746749825`*^9, 3.8593837886617823`*^9}, 
   3.8593838275090046`*^9, 3.859383930110873*^9, 3.8593844449693213`*^9, 
   3.8594320501601825`*^9, 3.8788874200397463`*^9},
 CellLabel->
  "During evaluation of \
In[334]:=",ExpressionUUID->"171a8f37-d473-416d-909f-bef09111b181"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQrfdJ3GvS2f/2+Vxfcw42fLJv0FrE2W7+3z7k1+mz
uz9+sTebNo9vguM/+wbzi13dzt+h4n/s9ddaNU1M/2n/bK69sX/AbzgNE4ep
g+mDmQMzF2YPzF6YOxjA4AOUZnBQfi2qVvvvFVw+gjsjpUPmGVw/w8TYVy8q
HsLNd/EW/b4z8Rbc/owORuPD+y7B3Zegu2CiYtEJuDtnzBET+/9sN9ydAht2
nZbjXwl3J8NLti+3zDrh7mRAAR/g8jB3wvTD3AkzH+ZOmP0wd8LcB6Nh4jB1
MH0wc2DmwuyB2QtzB1r4McDdDZWH+QumH+ZvmPmwcIHZDws3mPtg4QpzJyzc
Ye6ExQvMnbB4g7sTGq8wdwIAGCMm0Q==
       "]]}, {
      TagBox[
       {Opacity[0.], PointBox[{{1.9876883405951378`, 1.156434465040231}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {1}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.9510565162951536`, 1.3090169943749475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {2}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8910065241883678`, 1.4539904997395467`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {3}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8090169943749475`, 1.5877852522924731`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {4}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7071067811865475`, 1.7071067811865475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {5}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.5877852522924731`, 1.8090169943749475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {6}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.4539904997395467`, 1.8910065241883678`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {7}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.3090169943749475`, 1.9510565162951536`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {8}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.156434465040231, 1.9876883405951378`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {9}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1., 2.}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {10}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.8435655349597692, 1.9876883405951378`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {11}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.6909830056250525, 1.9510565162951536`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {12}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.5460095002604533, 1.8910065241883678`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {13}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.41221474770752686`, 1.8090169943749475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {14}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.29289321881345254`, 1.7071067811865475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {15}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.19098300562505255`, 1.5877852522924731`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {16}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.1089934758116321, 1.4539904997395467`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {17}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.04894348370484647, 1.3090169943749475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {18}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.01231165940486223, 1.156434465040231}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {19}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0., 1.}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {20}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.01231165940486223, 0.8435655349597692}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {21}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.04894348370484647, 0.6909830056250525}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {22}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.1089934758116321, 0.5460095002604533}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {23}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.19098300562505255`, 0.41221474770752686`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {24}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.29289321881345254`, 0.29289321881345254`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {25}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.41221474770752686`, 0.19098300562505255`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {26}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.5460095002604533, 0.1089934758116321}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {27}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.6909830056250525, 0.04894348370484647}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {28}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.8435655349597692, 0.01231165940486223}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {29}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1., 0.}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {30}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.156434465040231, 0.01231165940486223}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {31}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.3090169943749475`, 0.04894348370484647}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {32}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.4539904997395467`, 0.1089934758116321}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {33}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.5877852522924731`, 0.19098300562505255`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {34}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7071067811865475`, 0.29289321881345254`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {35}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8090169943749475`, 0.41221474770752686`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {36}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8910065241883678`, 0.5460095002604533}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {37}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.9510565162951536`, 0.6909830056250525}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {38}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.9876883405951378`, 0.8435655349597692}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {39}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{2., 1.}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$41301, {
         40}}]& ]}}, {{{{}, {GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 13.000000000000002`}, {
              1.9878946393438173`, 1.0121053606561827`}], 
             Offset[{1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.9878946393438173`, 1.0121053606561827`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.9878946393438173`, 
              1.0121053606561827`}], 
             Offset[{-17., 12.999999999999998`}, {1.9878946393438173`, 
              1.0121053606561827`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["40",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 6.5}, {1.9878946393438173, 1.0121053606561827}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {1.9997937012513205`, 
              0.8556708956159519}], 
             Offset[{17., 1.7763568394002505`*^-15}, {1.9997937012513205`, 
              0.8556708956159519}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.9997937012513205`, 0.8556708956159519}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              1.9997937012513205`, 0.8556708956159519}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["39",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {1.9997937012513205, 0.8556708956159519}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.938951155638971, 0.6788776449688698}], 
             Offset[{1.7763568394002505`*^-15, -12.999999999999998`}, {
              1.938951155638971, 0.6788776449688698}], 
             Offset[{-17., -13.000000000000002`}, {1.938951155638971, 
              0.6788776449688698}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.938951155638971, 
              0.6788776449688698}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["38",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.5}, {1.938951155638971, 0.6788776449688698}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {1.908126089405759, 
              0.5460095002604533}], 
             Offset[{17., -6.499999999999998}, {1.908126089405759, 
              0.5460095002604533}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              1.908126089405759, 0.5460095002604533}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              1.908126089405759, 0.5460095002604533}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["37",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {1.908126089405759, 0.5460095002604533}], NCache[
           ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {1.8211223550311302`, 
              0.4243201083637096}], 
             Offset[{17., 1.7763568394002505`*^-15}, {1.8211223550311302`, 
              0.4243201083637096}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.8211223550311302`, 0.4243201083637096}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              1.8211223550311302`, 0.4243201083637096}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["36",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {1.8211223550311302, 0.4243201083637096}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {1.7192121418427302`, 
              0.30499857946963527`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {1.7192121418427302`, 
              0.30499857946963527`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.7192121418427302`, 0.30499857946963527`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              1.7192121418427302`, 0.30499857946963527`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["35",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {1.7192121418427302, 0.30499857946963527}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {1.6049048175098644`, 
              0.19098300562505255`}], 
             Offset[{17., -6.499999999999998}, {1.6049048175098644`, 
              0.19098300562505255`}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              1.6049048175098644`, 0.19098300562505255`}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              1.6049048175098644`, 0.19098300562505255`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["34",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {1.6049048175098644, 0.19098300562505255}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {1.471110064956938, 
              0.1089934758116321}], 
             Offset[{17., -6.499999999999998}, {1.471110064956938, 
              0.1089934758116321}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              1.471110064956938, 0.1089934758116321}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              1.471110064956938, 0.1089934758116321}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["33",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {1.471110064956938, 0.1089934758116321}], NCache[
           ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {1.3261365595923387`, 
              0.04894348370484647}], 
             Offset[{17., -6.499999999999998}, {1.3261365595923387`, 
              0.04894348370484647}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              1.3261365595923387`, 0.04894348370484647}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              1.3261365595923387`, 0.04894348370484647}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["32",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {1.3261365595923387, 0.04894348370484647}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              1.156434465040231, 0.029431224622253532`}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              1.156434465040231, 0.029431224622253532`}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              1.156434465040231, 0.029431224622253532`}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              1.156434465040231, 0.029431224622253532`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["31",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {1.156434465040231, 0.029431224622253532}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {1., 
              0.017119565217391303`}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {1., 
              0.017119565217391303`}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {1., 
              0.017119565217391303`}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {1., 
              0.017119565217391303`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["30",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], Offset[{0., 6.5}, {1., 0.017119565217391303}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.8435655349597692, 0.029431224622253532`}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.8435655349597692, 0.029431224622253532`}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.8435655349597692, 0.029431224622253532`}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.8435655349597692, 0.029431224622253532`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["29",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.8435655349597692, 0.029431224622253532}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.6909830056250525, 0.06606304892223777}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.6909830056250525, 0.06606304892223777}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.6909830056250525, 0.06606304892223777}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.6909830056250525, 0.06606304892223777}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["28",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.6909830056250525, 0.06606304892223777}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.5460095002604533, 0.1261130410290234}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.5460095002604533, 0.1261130410290234}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.5460095002604533, 0.1261130410290234}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.5460095002604533, 0.1261130410290234}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["27",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.5460095002604533, 0.1261130410290234}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.41221474770752686`, 0.20810257084244385`}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.41221474770752686`, 0.20810257084244385`}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.41221474770752686`, 0.20810257084244385`}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.41221474770752686`, 0.20810257084244385`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["26",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.41221474770752686, 0.20810257084244385}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 13.000000000000002`}, {
              0.2807878581572698, 0.30499857946963527`}], 
             Offset[{1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              0.2807878581572698, 0.30499857946963527`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {0.2807878581572698, 
              0.30499857946963527`}], 
             Offset[{-17., 12.999999999999998`}, {0.2807878581572698, 
              0.30499857946963527`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["25",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 6.5}, {0.2807878581572698, 0.30499857946963527}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.19098300562505255`, 0.4293343129249182}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.19098300562505255`, 0.4293343129249182}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.19098300562505255`, 0.4293343129249182}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.19098300562505255`, 0.4293343129249182}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["24",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.19098300562505255, 0.4293343129249182}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              0.1089934758116321, 0.5288899350430619}], 
             Offset[{8.500000000000002, -12.999999999999998`}, {
              0.1089934758116321, 0.5288899350430619}], 
             Offset[{-8.499999999999998, -13.000000000000002`}, {
              0.1089934758116321, 0.5288899350430619}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              0.1089934758116321, 0.5288899350430619}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["23",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.5}, {0.1089934758116321, 0.5288899350430619}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.06104884436102921, 
              0.7030883662812353}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.06104884436102921, 
              0.7030883662812353}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.06104884436102921, 0.7030883662812353}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.06104884436102921, 0.7030883662812353}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["22",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.06104884436102921, 0.7030883662812353}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.024417020061044972`, 
              0.8556708956159519}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.024417020061044972`, 
              0.8556708956159519}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.024417020061044972`, 0.8556708956159519}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.024417020061044972`, 0.8556708956159519}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["21",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.024417020061044972, 0.8556708956159519}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.01210536065618274, 
              1.0121053606561827`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.01210536065618274, 
              1.0121053606561827`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.01210536065618274, 1.0121053606561827`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.01210536065618274, 1.0121053606561827`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["20",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.01210536065618274, 1.0121053606561827}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.024417020061044972`, 
              1.1685398256964137`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.024417020061044972`, 
              1.1685398256964137`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.024417020061044972`, 1.1685398256964137`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.024417020061044972`, 1.1685398256964137`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["19",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.024417020061044972, 1.1685398256964137}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.06104884436102921, 
              1.3211223550311302`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.06104884436102921, 
              1.3211223550311302`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.06104884436102921, 1.3211223550311302`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.06104884436102921, 1.3211223550311302`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["18",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.06104884436102921, 1.3211223550311302}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.12109883646781484`, 
              1.4660958603957295`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.12109883646781484`, 
              1.4660958603957295`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.12109883646781484`, 1.4660958603957295`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.12109883646781484`, 1.4660958603957295`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["17",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.12109883646781484, 1.4660958603957295}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.20308836628123528`, 
              1.5998906129486559`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.20308836628123528`, 
              1.5998906129486559`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.20308836628123528`, 1.5998906129486559`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.20308836628123528`, 1.5998906129486559`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["16",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.20308836628123528, 1.5998906129486559}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {0.31001278403084387`, 
              1.7071067811865475`}], 
             Offset[{17., -6.499999999999998}, {0.31001278403084387`, 
              1.7071067811865475`}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              0.31001278403084387`, 1.7071067811865475`}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              0.31001278403084387`, 1.7071067811865475`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["15",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {0.31001278403084387, 1.7071067811865475}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {0.4293343129249182, 
              1.8090169943749475`}], 
             Offset[{17., -6.499999999999998}, {0.4293343129249182, 
              1.8090169943749475`}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              0.4293343129249182, 1.8090169943749475`}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              0.4293343129249182, 1.8090169943749475`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["14",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {0.4293343129249182, 1.8090169943749475}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {0.5631290654778446, 
              1.8910065241883678`}], 
             Offset[{17., -6.499999999999998}, {0.5631290654778446, 
              1.8910065241883678`}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              0.5631290654778446, 1.8910065241883678`}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              0.5631290654778446, 1.8910065241883678`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["13",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {0.5631290654778446, 1.8910065241883678}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.6909830056250525, 1.9681760815125449`}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.6909830056250525, 1.9681760815125449`}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.6909830056250525, 1.9681760815125449`}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.6909830056250525, 1.9681760815125449`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["12",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.6909830056250525, 1.9681760815125449}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 1.7763568394002505`*^-15}, {0.8556708956159519, 
              1.975582979938955}], 
             Offset[{17., -12.999999999999998`}, {0.8556708956159519, 
              1.975582979938955}], 
             Offset[{1.7763568394002505`*^-15, -13.000000000000002`}, {
              0.8556708956159519, 1.975582979938955}], 
             Offset[{-1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.8556708956159519, 1.975582979938955}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["11",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, -6.5}, {0.8556708956159519, 1.975582979938955}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {1.0121053606561827`, 
              2.0121053606561827`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {1.0121053606561827`, 
              2.0121053606561827`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.0121053606561827`, 2.0121053606561827`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              1.0121053606561827`, 2.0121053606561827`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["10",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {1.0121053606561827, 2.0121053606561827}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{5.499999999999998, 8.881784197001252*^-16}, {
              1.156434465040231, 1.9705687753777466`}], 
             Offset[{5.500000000000002, -13.}, {1.156434465040231, 
              1.9705687753777466`}], 
             Offset[{-5.499999999999998, -13.}, {1.156434465040231, 
              1.9705687753777466`}], 
             Offset[{-5.500000000000002, -8.881784197001252*^-16}, {
              1.156434465040231, 1.9705687753777466`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["9",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.5}, {1.156434465040231, 1.9705687753777466}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 13.}, {1.3211223550311302`, 
              1.9631618769513364`}], 
             Offset[{11.000000000000002`, 8.881784197001252*^-16}, {
              1.3211223550311302`, 1.9631618769513364`}], 
             Offset[{1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.3211223550311302`, 1.9631618769513364`}], 
             Offset[{-1.7763568394002505`*^-15, 13.}, {1.3211223550311302`, 
              1.9631618769513364`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["8",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, 6.5}, {1.3211223550311302, 1.9631618769513364}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 13.}, {1.4660958603957295`, 
              1.9031118848445505`}], 
             Offset[{11.000000000000002`, 8.881784197001252*^-16}, {
              1.4660958603957295`, 1.9031118848445505`}], 
             Offset[{1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.4660958603957295`, 1.9031118848445505`}], 
             Offset[{-1.7763568394002505`*^-15, 13.}, {1.4660958603957295`, 
              1.9031118848445505`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["7",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, 6.5}, {1.4660958603957295, 1.9031118848445505}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 13.}, {1.5998906129486559`, 
              1.8211223550311302`}], 
             Offset[{11.000000000000002`, 8.881784197001252*^-16}, {
              1.5998906129486559`, 1.8211223550311302`}], 
             Offset[{1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.5998906129486559`, 1.8211223550311302`}], 
             Offset[{-1.7763568394002505`*^-15, 13.}, {1.5998906129486559`, 
              1.8211223550311302`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["6",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, 6.5}, {1.5998906129486559, 1.8211223550311302}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 13.}, {1.7192121418427302`, 
              1.7192121418427302`}], 
             Offset[{11.000000000000002`, 8.881784197001252*^-16}, {
              1.7192121418427302`, 1.7192121418427302`}], 
             Offset[{1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.7192121418427302`, 1.7192121418427302`}], 
             Offset[{-1.7763568394002505`*^-15, 13.}, {1.7192121418427302`, 
              1.7192121418427302`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["5",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, 6.5}, {1.7192121418427302, 1.7192121418427302}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              1.8211223550311302`, 1.5756798916362904`}], 
             Offset[{11.000000000000002`, -13.}, {1.8211223550311302`, 
              1.5756798916362904`}], 
             Offset[{1.7763568394002505`*^-15, -13.}, {1.8211223550311302`, 
              1.5756798916362904`}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.8211223550311302`, 1.5756798916362904`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["4",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.5}, {1.8211223550311302, 1.5756798916362904}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              1.9031118848445505`, 1.441885139083364}], 
             Offset[{11.000000000000002`, -13.}, {1.9031118848445505`, 
              1.441885139083364}], 
             Offset[{1.7763568394002505`*^-15, -13.}, {1.9031118848445505`, 
              1.441885139083364}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.9031118848445505`, 1.441885139083364}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["3",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.5}, {1.9031118848445505, 1.441885139083364}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 8.881784197001252*^-16}, {
              1.938951155638971, 1.2969116337187647`}], 
             Offset[{1.7763568394002505`*^-15, -13.}, {1.938951155638971, 
              1.2969116337187647`}], 
             Offset[{-10.999999999999998`, -13.}, {1.938951155638971, 
              1.2969116337187647`}], 
             Offset[{-11.000000000000002`, -8.881784197001252*^-16}, {
              1.938951155638971, 1.2969116337187647`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["2",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-5.5, -6.5}, {1.938951155638971, 1.2969116337187647}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              1.9997937012513205`, 1.1443291043840482`}], 
             Offset[{11.000000000000002`, -13.}, {1.9997937012513205`, 
              1.1443291043840482`}], 
             Offset[{1.7763568394002505`*^-15, -13.}, {1.9997937012513205`, 
              1.1443291043840482`}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.9997937012513205`, 1.1443291043840482`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["1",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.5}, {1.9997937012513205, 1.1443291043840482}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}]}}, {}}, {}}}, LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQrfdJ3GvS2f/2+Vxfcw42fLJngAAHCPXBHiav/FpU
rfbfK/sGrUWc7eb/7SO4M1I6ZJ7Zm02bxzfB8Z89w8TYVy8qHtqH/Dp9dvfH
P/Yu3qLfdybesn82197YP+C3fUYHo/HhfZfs9ddaNU1M/2mfoLtgomLRCfsG
84td3c7f7WfMERP7/2w3VP8Xe4ENu07L8a9EuOsl25dbZp32MHdB3ckAcxdM
HuYumH6Yu2Dmw9wFsx/mLhgNE4epg+mDmQMzF2YPzF64O1DAB7g8zB8w/TB/
wsyHhQPMflg4wdwFC0eYu2DhDHMXLB5g7oLFE8xdsHhECz8HmLtg8jB3wfTD
3AUzH+YumP0wd8FomDhMHUwfzByYuTB70NMfAM6XLzw=
    "]]},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{All, All}, {All, All}},
  ImageSize->{306.5, Automatic},
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 2.}, {0., 2.}},
  PlotRangePadding->{{0, 
     Scaled[0.08]}, {0, 
     Scaled[0.08]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.859012336380873*^9, 3.8590123998433876`*^9, 3.8590124400834656`*^9, {
   3.859012557903231*^9, 3.859012561325844*^9}, {3.8590366117998*^9, 
   3.8590366423522243`*^9}, 3.8590375441936755`*^9, 3.859037589043541*^9, {
   3.859037665665844*^9, 3.8590376907354903`*^9}, 3.859037995203351*^9, 
   3.8590380441440544`*^9, 3.8590388787447453`*^9, 3.859038985894938*^9, 
   3.8590390391347337`*^9, 3.8590390738748426`*^9, 3.8590416807564464`*^9, {
   3.859042043832177*^9, 3.859042051232082*^9}, 3.8590511487261305`*^9, 
   3.8593554072804604`*^9, 3.8593554478527813`*^9, 3.85935554994462*^9, 
   3.8593563336944485`*^9, 3.8593740036361113`*^9, 3.859381985856668*^9, 
   3.8593829791444807`*^9, {3.8593837746699824`*^9, 3.8593837886587825`*^9}, 
   3.85938382760901*^9, 3.859383930388889*^9, 3.85938444529434*^9, 
   3.859432050434198*^9, 3.878887420350314*^9},
 CellLabel->
  "Out[336]=",ExpressionUUID->"af16ed3d-8aa8-4faf-9091-43c9d21e9e47"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Approximative solution using thermodynamic Monte Carlo method\
\>", "Section",
 CellChangeTimes->{{3.850284992156113*^9, 3.8502851174278107`*^9}, {
  3.8502884635283027`*^9, 3.8502884649516716`*^9}, {3.850407943113345*^9, 
  3.8504079457856646`*^9}, {3.8504449061005325`*^9, 3.8504449155490723`*^9}, {
  3.850446227606118*^9, 3.8504462511734657`*^9}, {3.8587553227221746`*^9, 
  3.8587553695458527`*^9}, {3.858764261860464*^9, 3.858764277268345*^9}, {
  3.859011999602493*^9, 3.8590120411627245`*^9}, {3.859038099864771*^9, 
  3.85903812597431*^9}, {3.8590391126761723`*^9, 3.859039180985834*^9}, {
  3.8590415901590443`*^9, 
  3.859041650450469*^9}},ExpressionUUID->"6045c388-2f2b-4767-9a08-\
97aaff3123e2"],

Cell[CellGroupData[{

Cell["\<\
Simple algorithm - just switch two random cities and use Metropolis to accept \
or reject a new tour\
\>", "Subsubsection",
 CellChangeTimes->{{3.859012626100502*^9, 3.8590126806907263`*^9}, {
  3.859368335192895*^9, 
  3.8593684349666014`*^9}},ExpressionUUID->"0cc8be72-eacd-420d-9af0-\
32b8bf2826db"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MCSolutionOfTSP", "[", 
    RowBox[{
    "cities_", ",", "distances_", ",", "iniPerm_", ",", "startingT_", ",", 
     "nIter_", ",", "model_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"input", ":", " ", "\[IndentingNewLine]", "cities"}], " ", "=", 
      " ", 
      RowBox[{"a", " ", "list", " ", "of", " ", "coordinates", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], " ", "of", " ", "all", " ", 
       "cities"}]}], ",", "\[IndentingNewLine]", "  ", 
     RowBox[{"distances", " ", "=", " ", 
      RowBox[{
      "a", " ", "matrix", " ", "of", " ", "distances", " ", "between", " ", 
       "each", " ", "pair", " ", "of", " ", "cities"}]}], ",", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{"iniPerm", " ", "=", " ", 
      RowBox[{
      "a", " ", "list", " ", "with", " ", "initial", " ", "permutation", " ", 
       "of", " ", "cities"}]}], ",", "\[IndentingNewLine]", "  ", 
     RowBox[{"startingT", " ", "=", " ", 
      RowBox[{"starting", " ", "temperature"}]}], ",", "\[IndentingNewLine]", 
     "  ", 
     RowBox[{"nIter", " ", "=", " ", 
      RowBox[{
      "number", " ", "of", " ", "iterations", " ", "of", " ", "the", " ", 
       "MC", " ", "algorithm"}]}], ",", "\[IndentingNewLine]", "    ", 
     RowBox[{"model", " ", "=", " ", 
      RowBox[{"\"\<Simple\>\"", " ", 
       RowBox[{"(", 
        RowBox[{
        "just", " ", "switch", " ", "two", " ", "random", " ", "cities"}], 
        ")"}], " ", "or", " ", "\"\<Cerny\>\"", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"switch", " ", "systematically", " ", "i"}], "-", 
          RowBox[{
          "th", " ", "city", " ", "with", " ", "a", " ", "random", " ", 
           "one"}]}], ",", " ", 
         RowBox[{
         "but", " ", "go", " ", "in", " ", "a", " ", "reverse", " ", 
          "direction", " ", "half", " ", "of", " ", "the", " ", "tour"}]}], 
        ")"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"output", ":", "\[IndentingNewLine]", "shortestDistance"}], " ",
       "=", " ", 
      RowBox[{
      "the", " ", "found", " ", "shortest", " ", "total", " ", "distance", 
       " ", "travelled"}]}], ",", "\[IndentingNewLine]", "  ", 
     RowBox[{"shortestPerm", " ", "=", " ", 
      RowBox[{
      "the", " ", "found", " ", "permutations", " ", "of", " ", "cities", " ",
        "corresponding", " ", "to", " ", "the", " ", "shortest", " ", "total",
        " ", "distance", " ", "travelled"}]}], ",", "\[IndentingNewLine]", 
     "  ", 
     RowBox[{"totalDistances", " ", "=", " ", 
      RowBox[{
      "a", " ", "list", " ", "of", " ", "total", " ", "distances", " ", 
       "travelled", " ", "at", " ", "each", " ", "iteration"}]}], ",", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{"savedPerm", " ", "=", " ", 
      RowBox[{
      "a", " ", "list", " ", "of", " ", "saved", " ", "permutations"}]}], ",",
      " ", 
     RowBox[{
     "only", " ", "new", " ", "accepted", " ", "permutations", " ", "are", 
      " ", "saved"}]}], "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "i", ",", "j", ",", "ii", ",", "jj", ",", "n", ",", "totalDistances", 
       ",", "T", ",", "plus", ",", "minus", ",", "\[IndentingNewLine]", 
       "curDist", ",", "curPerm", ",", "savedPerm", ",", 
       "\[IndentingNewLine]", "shortestDist", ",", "shortestPerm", ",", 
       "\[IndentingNewLine]", "tryPerm", ",", "newDist", ",", "rejected"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "cities", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"totalDistances", "=", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"nIter", "+", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"T", "=", "startingT"}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "auxiliary", " ", "arrays", " ", "for", " ", "simple", " ", 
        "treatment", " ", "of", " ", "periodic", " ", "boundary", " ", 
        "conditions"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"plus", "=", 
       RowBox[{"Array", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "+", 
           RowBox[{"Mod", "[", 
            RowBox[{"#", ",", "n"}], "]"}]}], "&"}], ",", "n"}], "]"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"minus", "=", 
       RowBox[{"Array", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "+", 
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"#", "-", "2"}], ",", "n"}], "]"}]}], "&"}], ",", "n"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "initial", " ", "permutation", " ", "and", " ", "distance", " ", 
        "travelled"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"curPerm", "=", "iniPerm"}], ";", "\[IndentingNewLine]", 
      RowBox[{"curDist", "=", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"distances", "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{
           "curPerm", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
           ",", 
           RowBox[{"curPerm", "\[LeftDoubleBracket]", 
            RowBox[{
            "plus", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"shortestDist", "=", "curDist"}], ";", "\[IndentingNewLine]", 
      RowBox[{"shortestPerm", "=", "curPerm"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
       "totalDistances", "\[LeftDoubleBracket]", "1", 
        "\[RightDoubleBracket]"}], "=", "curDist"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "auxiliary", " ", "array", " ", "for", " ", "saving", " ", "accepted", 
        " ", "permutations"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"savedPerm", "=", 
       RowBox[{"{", "curPerm", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Monte", " ", "Carlo", " ", "iterations"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"rejected", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"i", "=", "1"}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"for", " ", "Cerny", " ", "algorithm"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"prepare", " ", "a", " ", "trial", " ", "permuation"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"tryPerm", "=", "curPerm"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"model", "\[Equal]", "\"\<Simple\>\""}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "=", 
             RowBox[{"RandomSample", "[", 
              RowBox[{
               RowBox[{"Range", "[", "n", "]"}], ",", "2"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
               "tryPerm", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "tryPerm", "\[LeftDoubleBracket]", "j", 
                "\[RightDoubleBracket]"}]}], "}"}], "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
               "curPerm", "\[LeftDoubleBracket]", "j", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "curPerm", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}]}], "}"}]}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{"else", " ", "algorithm", " ", "of", " ", 
             RowBox[{"V", ".", " ", "\[CapitalCHacek]ern\[YAcute]"}]}], " ", 
            "*)"}], "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"j", "=", 
             RowBox[{"RandomInteger", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"n", "-", "1"}]}], "}"}], "]"}]}], ";", " ", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"j", "\[GreaterEqual]", "i"}], ",", 
              RowBox[{"j", "++"}]}], "]"}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "random", " ", "j", " ", "different", " ", "from", " ", "i"}], 
             " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"ii", ",", "jj"}], "}"}], "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Min", "[", 
                RowBox[{"i", ",", "j"}], "]"}], ",", 
               RowBox[{"Max", "[", 
                RowBox[{"i", ",", "j"}], "]"}]}], "}"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"tryPerm", "\[LeftDoubleBracket]", 
              RowBox[{"ii", ";;", "jj"}], "\[RightDoubleBracket]"}], "=", 
             RowBox[{"Reverse", "[", 
              RowBox[{"curPerm", "\[LeftDoubleBracket]", 
               RowBox[{"ii", ";;", "jj"}], "\[RightDoubleBracket]"}], 
              "]"}]}]}]}], "\[IndentingNewLine]", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{"use", " ", "Metropolis", " ", 
           RowBox[{"alg", ".", " ", "to"}], " ", "decide", " ", "whether", 
           " ", "to", " ", "accept", " ", "or", " ", "reject", " ", "a", " ", 
           "new", " ", "permutation"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"newDist", "=", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{"distances", "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{
              "tryPerm", "\[LeftDoubleBracket]", "i", 
               "\[RightDoubleBracket]"}], ",", 
              RowBox[{"tryPerm", "\[LeftDoubleBracket]", 
               RowBox[{
               "plus", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"newDist", "<", "curDist"}], " ", "||", " ", 
            RowBox[{
             RowBox[{"RandomReal", "[", "]"}], "<", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"curDist", "-", "newDist"}], ")"}], "/", "T"}], 
              "]"}]}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"curPerm", "=", "tryPerm"}], ";", "\[IndentingNewLine]", 
            RowBox[{"curDist", "=", "newDist"}], ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"curDist", "<", "shortestDist"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"shortestDist", "=", "curDist"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"shortestPerm", "=", "curPerm"}]}]}], 
             "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"savedPerm", ",", "curPerm"}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"rejected", "++"}]}], "\[IndentingNewLine]", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"totalDistances", "\[LeftDoubleBracket]", 
           RowBox[{"it", "+", "1"}], "\[RightDoubleBracket]"}], "=", 
          "curDist"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"i", "<", "n"}], ",", 
           RowBox[{"i", "++"}], ",", 
           RowBox[{"i", "=", "1"}]}], "]"}]}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{
         "move", " ", "to", " ", "the", " ", "neighbouring", " ", "city"}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Mod", "[", 
              RowBox[{"it", ",", "4000"}], "]"}], "\[Equal]", "0"}], ",", 
            RowBox[{"T", "=", 
             RowBox[{"0.1", "*", "T"}]}]}], "]"}], ","}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"it", ",", "1", ",", "nIter"}], "}"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<Total permutations rejected: \>\"", ",", " ", "rejected"}], "]"}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{"{", 
        RowBox[{
        "shortestDist", ",", "shortestPerm", ",", "totalDistances", ",", 
         "savedPerm"}], "}"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.8496065737332587`*^9, 3.849606654427*^9}, {
   3.8496066854068832`*^9, 3.8496066856924987`*^9}, {3.8496067692497735`*^9, 
   3.849606771348775*^9}, {3.8496068224442654`*^9, 3.8496068951102657`*^9}, {
   3.849606941073992*^9, 3.8496069670037174`*^9}, {3.849607002220313*^9, 
   3.8496074760208178`*^9}, {3.8496077119325123`*^9, 3.849607748132677*^9}, {
   3.8498659522565804`*^9, 3.849866234045698*^9}, {3.8498664501880603`*^9, 
   3.849866560979398*^9}, {3.849866608770131*^9, 3.8498667563615727`*^9}, {
   3.849866795952837*^9, 3.8498668229203796`*^9}, {3.849866856288288*^9, 
   3.8498669046880565`*^9}, {3.8498669577040887`*^9, 
   3.8498669937121487`*^9}, {3.849867326660192*^9, 3.8498675569833655`*^9}, {
   3.8498677067099295`*^9, 3.849867729758248*^9}, {3.849867794714963*^9, 
   3.8498679708510375`*^9}, {3.8498680893228135`*^9, 
   3.8498681521384068`*^9}, {3.8498682229434566`*^9, 
   3.8498682412875056`*^9}, {3.8498682825118637`*^9, 3.849868329421547*^9}, {
   3.849868428544216*^9, 3.8498684496614237`*^9}, {3.849868692556317*^9, 
   3.8498687736739564`*^9}, {3.8498688480182085`*^9, 
   3.8498688742667103`*^9}, {3.849868979090706*^9, 3.8498690248643236`*^9}, {
   3.8498690758832417`*^9, 3.849869083128656*^9}, {3.8498691286262584`*^9, 
   3.84986920680873*^9}, {3.849869250843249*^9, 3.8498692561335516`*^9}, {
   3.849869287120324*^9, 3.8498693018551664`*^9}, {3.849869419129874*^9, 
   3.849869486052702*^9}, {3.849869551278433*^9, 3.8498695722186303`*^9}, {
   3.850209338624843*^9, 3.8502093666224446`*^9}, {3.8502094626939397`*^9, 
   3.850209506746459*^9}, {3.8502095758124094`*^9, 3.850209612623515*^9}, {
   3.8502097222337847`*^9, 3.8502097240948906`*^9}, {3.850209784338337*^9, 
   3.850209804590495*^9}, {3.85021004804742*^9, 3.8502100678515525`*^9}, {
   3.8502823883410573`*^9, 3.8502823904519043`*^9}, {3.8502827091554527`*^9, 
   3.8502827305592375`*^9}, {3.8502827633875566`*^9, 3.850282770436743*^9}, {
   3.850282809667946*^9, 3.850283014461815*^9}, {3.8502830628918743`*^9, 
   3.8502833755911655`*^9}, {3.8502834085701785`*^9, 3.850283420387255*^9}, {
   3.850283596583228*^9, 3.850283597528829*^9}, {3.850283844925599*^9, 
   3.850283883214069*^9}, {3.8502839989512444`*^9, 3.850284008881238*^9}, {
   3.850284444798033*^9, 3.850284445065889*^9}, {3.8502846732782197`*^9, 
   3.850284741112954*^9}, {3.850284922195149*^9, 3.850284923148017*^9}, {
   3.8502851222664003`*^9, 3.8502851244583917`*^9}, 3.850286085594694*^9, {
   3.850286679977948*^9, 3.850286703311764*^9}, {3.8502869522880197`*^9, 
   3.8502871242314744`*^9}, {3.8502871663999095`*^9, 
   3.8502871678013754`*^9}, {3.850288488694371*^9, 3.850288522186626*^9}, {
   3.8502885981612406`*^9, 3.8502886355455885`*^9}, {3.8502991493940296`*^9, 
   3.8502991738098364`*^9}, {3.8502992349912353`*^9, 3.850299246362059*^9}, {
   3.8502993318357267`*^9, 3.850299348849098*^9}, {3.850299381766471*^9, 
   3.8502996020037723`*^9}, {3.8502997381470404`*^9, 3.850299822578452*^9}, {
   3.850299907763318*^9, 3.8503000556463923`*^9}, {3.850300113499284*^9, 
   3.850300153813047*^9}, {3.850300260418194*^9, 3.850300333934967*^9}, {
   3.8503003745621414`*^9, 3.8503003749608736`*^9}, 3.8503004195304165`*^9, {
   3.8503004674465656`*^9, 3.850300477941496*^9}, {3.8503010662506666`*^9, 
   3.850301253842307*^9}, {3.850301305078566*^9, 3.850301306922103*^9}, {
   3.850301355617137*^9, 3.8503014822213535`*^9}, {3.8503015812921886`*^9, 
   3.850301637662247*^9}, {3.850301721175931*^9, 3.850301818225009*^9}, {
   3.850302006250021*^9, 3.8503020322460113`*^9}, {3.8503020670259323`*^9, 
   3.850302133564114*^9}, {3.850302166479986*^9, 3.850302224098697*^9}, {
   3.8503022558635283`*^9, 3.850302285007962*^9}, {3.850302378289647*^9, 
   3.850302507333518*^9}, {3.850302563268634*^9, 3.850302563901643*^9}, {
   3.850305309239606*^9, 3.8503054709155135`*^9}, {3.850306308238212*^9, 
   3.850306311398385*^9}, {3.850306342873065*^9, 3.850306421387246*^9}, {
   3.8503064627927437`*^9, 3.8503065650437765`*^9}, {3.8503065999805307`*^9, 
   3.8503066580431275`*^9}, {3.850306703344405*^9, 3.850306920178565*^9}, {
   3.850306964667661*^9, 3.850307050066254*^9}, {3.8503070892171*^9, 
   3.8503070949580555`*^9}, {3.8503071579808345`*^9, 3.85030716108549*^9}, {
   3.8503074109208455`*^9, 3.8503074124391117`*^9}, {3.8503074627379093`*^9, 
   3.8503074731979485`*^9}, {3.850307601886543*^9, 3.850307631581897*^9}, {
   3.8503077342177167`*^9, 3.850307818409624*^9}, 3.8503078809044504`*^9, {
   3.8503079170340476`*^9, 3.850307944974044*^9}, {3.850308068703856*^9, 
   3.8503080821448064`*^9}, {3.8503081141002674`*^9, 3.8503081998117094`*^9}, 
   3.8503082486967936`*^9, {3.850309877717277*^9, 3.8503099293016024`*^9}, {
   3.850310006619562*^9, 3.850310033809697*^9}, {3.850310302493517*^9, 
   3.8503103145364757`*^9}, {3.8503197013229585`*^9, 
   3.8503197789306507`*^9}, {3.850319858615965*^9, 3.850319862884163*^9}, {
   3.8503203669429846`*^9, 3.850320369592593*^9}, {3.8504079506451187`*^9, 
   3.8504081787888556`*^9}, {3.8504082245844355`*^9, 3.850408228460683*^9}, {
   3.8504082702512283`*^9, 3.8504083433004293`*^9}, {3.850408391736351*^9, 
   3.8504084692662354`*^9}, {3.8504087677049923`*^9, 3.850409019284892*^9}, {
   3.8504090558370075`*^9, 3.8504090609312153`*^9}, {3.8504091022368665`*^9, 
   3.8504092822744045`*^9}, {3.850410055147817*^9, 3.850410098779961*^9}, {
   3.8504101562701273`*^9, 3.8504101590205097`*^9}, {3.850411243074305*^9, 
   3.850411301531823*^9}, {3.8504113795392327`*^9, 3.850411440279065*^9}, {
   3.8504116883696384`*^9, 3.8504116902135515`*^9}, {3.8504118383514524`*^9, 
   3.8504119601881313`*^9}, {3.8504120848238535`*^9, 
   3.8504120978282266`*^9}, {3.850412356139202*^9, 3.8504123886535387`*^9}, {
   3.8504124208751507`*^9, 3.8504127498974795`*^9}, {3.850414384318515*^9, 
   3.8504144098138947`*^9}, {3.850416289766465*^9, 3.8504163050832624`*^9}, {
   3.8504164348664446`*^9, 3.850416437320009*^9}, {3.8504165158598332`*^9, 
   3.850416518563015*^9}, {3.8504165491820536`*^9, 3.850416661477475*^9}, {
   3.8504167393187723`*^9, 3.850416771380473*^9}, {3.8504175895941625`*^9, 
   3.850417640639447*^9}, {3.8504453494788923`*^9, 3.8504453556452446`*^9}, 
   3.85044548126943*^9, {3.850446242941995*^9, 3.8504462663463335`*^9}, {
   3.858755384479707*^9, 3.8587557133135147`*^9}, {3.858755753281801*^9, 
   3.858755761433267*^9}, {3.8587560395981774`*^9, 3.858756162942232*^9}, {
   3.8587562102299366`*^9, 3.8587562110539837`*^9}, {3.8587564158836994`*^9, 
   3.8587564169627614`*^9}, {3.85875699966109*^9, 3.8587571621213818`*^9}, {
   3.8587590807131195`*^9, 3.858759183809016*^9}, {3.8587606227413177`*^9, 
   3.858760693324355*^9}, {3.858760731659548*^9, 3.8587607612192383`*^9}, {
   3.8587611374637585`*^9, 3.85876113767177*^9}, {3.85876385251305*^9, 
   3.8587638531290855`*^9}, {3.8587640260479765`*^9, 3.858764162086757*^9}, {
   3.8587642881109653`*^9, 3.858764314614481*^9}, {3.858764363229262*^9, 
   3.8587644381245456`*^9}, {3.858764492386649*^9, 3.85876455533925*^9}, {
   3.8587646723459425`*^9, 3.8587647022426524`*^9}, {3.8587647325853877`*^9, 
   3.858764981431621*^9}, {3.858765068940626*^9, 3.8587651155182905`*^9}, {
   3.8587653596982565`*^9, 3.858765488033597*^9}, {3.858767165349534*^9, 
   3.8587673193403416`*^9}, 3.8587674567552013`*^9, {3.858767754705243*^9, 
   3.85876776688894*^9}, {3.8587682446242647`*^9, 3.8587682512636447`*^9}, {
   3.8587682857516174`*^9, 3.858768361814968*^9}, {3.85876842094435*^9, 
   3.8587685768382664`*^9}, 3.8587686469142747`*^9, {3.858768732290158*^9, 
   3.8587687390925465`*^9}, 3.85876888268576*^9, {3.8587689261552467`*^9, 
   3.858768961681278*^9}, {3.858769029418153*^9, 3.858769095615939*^9}, {
   3.858769258905278*^9, 3.8587692627745*^9}, {3.858769311887309*^9, 
   3.8587693251740685`*^9}, {3.858769527754656*^9, 3.858769530411808*^9}, 
   3.858769609876353*^9, {3.8587701811910305`*^9, 3.858770199003049*^9}, {
   3.858770300620861*^9, 3.8587703270983753`*^9}, {3.858770539480523*^9, 
   3.8587705435027533`*^9}, {3.858771009663416*^9, 3.858771010356456*^9}, {
   3.858779899347877*^9, 3.858779963633554*^9}, {3.8587801350723596`*^9, 
   3.858780380095374*^9}, {3.85878046393417*^9, 3.8587804838133063`*^9}, {
   3.8587805139010277`*^9, 3.8587805399185157`*^9}, {3.858780593828599*^9, 
   3.858780619669077*^9}, {3.85878075155062*^9, 3.858780752179656*^9}, {
   3.8587815838712263`*^9, 3.8587816080866113`*^9}, {3.8587817936302233`*^9, 
   3.8587819116919765`*^9}, {3.8587819421887207`*^9, 3.858782022635322*^9}, {
   3.8587821551859035`*^9, 3.85878215565493*^9}, {3.858782587510631*^9, 
   3.858782756515298*^9}, {3.858782788923151*^9, 3.8587827999547825`*^9}, {
   3.858783493699462*^9, 3.858783494834527*^9}, 3.8587835426332607`*^9, {
   3.8587837010023193`*^9, 3.858783732184103*^9}, {3.858783777620702*^9, 
   3.8587837801038437`*^9}, {3.8587843336115026`*^9, 
   3.8587843857524843`*^9}, {3.859012050207283*^9, 3.8590121087172866`*^9}, {
   3.859012956111888*^9, 3.85901302847807*^9}, {3.8590136629341373`*^9, 
   3.859013740952004*^9}, {3.859013813638775*^9, 3.8590138760058765`*^9}, {
   3.8590417165968666`*^9, 3.859041800186434*^9}, {3.859041977031814*^9, 
   3.8590420235523963`*^9}, {3.8590424485078297`*^9, 
   3.8590425050209885`*^9}, {3.859042535482889*^9, 3.8590426036228085`*^9}, {
   3.859042850622978*^9, 3.859042903158701*^9}, {3.859044386383974*^9, 
   3.8590446319738846`*^9}, {3.859044705254281*^9, 3.859044914594019*^9}, {
   3.8590449857445593`*^9, 3.8590450217445817`*^9}, {3.8590450935446224`*^9, 
   3.859045127974939*^9}, {3.859045603702179*^9, 3.859045609694762*^9}, {
   3.8590459014290056`*^9, 3.859045942078935*^9}, {3.859046296889555*^9, 
   3.8590463093092723`*^9}, {3.8590463474390917`*^9, 3.859046395149968*^9}, {
   3.8590470854194283`*^9, 3.8590470877299747`*^9}, {3.8590471786197996`*^9, 
   3.8590471969698324`*^9}, {3.859047589252037*^9, 3.8590476631022806`*^9}, {
   3.8590476955623207`*^9, 3.8590477237220526`*^9}, {3.8590477894331865`*^9, 
   3.859047890942811*^9}, {3.8590479728691816`*^9, 3.8590480381024475`*^9}, {
   3.859048364752597*^9, 3.8590485387531652`*^9}, {3.859048595286194*^9, 
   3.8590486909132137`*^9}, {3.8590487292232018`*^9, 
   3.8590487384732533`*^9}, {3.8590488137232533`*^9, 3.859048842033739*^9}, {
   3.859048955527667*^9, 3.8590489585334044`*^9}, {3.8590499178201885`*^9, 
   3.8590499496696444`*^9}, {3.859050004269805*^9, 3.8590500048633194`*^9}, {
   3.8590504807254534`*^9, 3.8590505640601635`*^9}, {3.859050608480425*^9, 
   3.859050742560134*^9}, {3.859050773370059*^9, 3.8590507984205675`*^9}, {
   3.859050930070422*^9, 3.85905093060155*^9}, 3.8590510332709503`*^9, {
   3.8593568987787695`*^9, 3.859356919350946*^9}, {3.8593586041333103`*^9, 
   3.859358606333436*^9}, {3.859365942854061*^9, 3.859365971132678*^9}, {
   3.859366230844533*^9, 3.859366330010205*^9}, {3.8593664430706716`*^9, 
   3.8593664535292697`*^9}, {3.859366885967004*^9, 3.859366910542409*^9}, {
   3.8593672097665243`*^9, 3.859367218827042*^9}, {3.859367442641844*^9, 
   3.859367484607244*^9}, {3.8593685083718*^9, 3.859368670496073*^9}, {
   3.8593687120154476`*^9, 3.859368891502714*^9}, {3.859369473355994*^9, 
   3.8593698360067368`*^9}, {3.8593703677121477`*^9, 3.859370430439736*^9}, {
   3.859370469270957*^9, 3.8593704954394536`*^9}, {3.8593705435272045`*^9, 
   3.85937054800646*^9}, {3.859370618381486*^9, 3.8593707377643137`*^9}, {
   3.8593708445154195`*^9, 3.85937100082436*^9}, {3.8593714308929586`*^9, 
   3.8593714770115967`*^9}, {3.8593715233262453`*^9, 3.859371525123348*^9}, {
   3.8593825467837515`*^9, 3.859382554435189*^9}, {3.8593826071162024`*^9, 
   3.8593827846733575`*^9}},
 CellLabel->
  "In[968]:=",ExpressionUUID->"ecdda7ec-fa69-4d39-bc74-0c1c937e0baf"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"nIter", "=", "4000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"initialPerm", "=", 
    RowBox[{"RandomSample", "[", 
     RowBox[{"Range", "[", "n", "]"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"shortest", "\[LeftDoubleBracket]", 
     RowBox[{"2", ",", 
      RowBox[{"1", ";;", "n"}]}], "\[RightDoubleBracket]"}], ";"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"temp", "=", "0.05"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "shortestDist", ",", "shortestPerm", ",", "totalDistances", ",", 
      "savedPerm"}], "}"}], "=", 
    RowBox[{"MCSolutionOfTSP", "[", 
     RowBox[{
     "cities", ",", "distances", ",", "initialPerm", ",", "temp", ",", 
      "nIter", ",", "\"\<Cerny\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"temp", "=", "0.01"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "shortestDist", ",", "shortestPerm", ",", "totalDistances", ",", 
       "savedPerm"}], "}"}], "=", 
     RowBox[{"MCSolutionOfTSP", "[", 
      RowBox[{
      "cities", ",", "distances", ",", "shortestPerm", ",", "temp", ",", 
       "nIter", ",", "\"\<Cerny\>\""}], "]"}]}], ";"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nSave", "=", 
   RowBox[{"Length", "[", "savedPerm", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Shortest tour found (black) is \>\"", ",", "shortestDist", ",", " ", 
    "\"\<, but the actual shortest tour (green) is \>\"", ",", " ", 
    RowBox[{
    "shortest", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
   "]"}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Labeled", "[", 
         RowBox[{
          RowBox[{
          "cities", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          ",", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"PointSize", "[", "Medium", "]"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Black", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"cities", "\[LeftDoubleBracket]", 
         RowBox[{"Append", "[", 
          RowBox[{"shortestPerm", ",", 
           RowBox[{
           "shortestPerm", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]}], "]"}], "\[RightDoubleBracket]"}], 
        "]"}], ",", "Thin", ",", "Red", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"cities", "\[LeftDoubleBracket]", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"Last", "[", "savedPerm", "]"}], ",", 
           RowBox[{
            RowBox[{"Last", "[", "savedPerm", "]"}], "\[LeftDoubleBracket]", 
            "1", "\[RightDoubleBracket]"}]}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], ",", "Thin", ",", "Dashed", ",", 
       "Green", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"cities", "\[LeftDoubleBracket]", 
         RowBox[{
         "shortest", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "\[RightDoubleBracket]"}], "]"}]}], "}"}], "]"}]}], "}"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"totalDistances", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8590451524048386`*^9, 3.85904517817447*^9}, 
   3.8590489403630157`*^9, {3.8590489923656435`*^9, 3.8590489945235825`*^9}, {
   3.859050022465147*^9, 3.8590500277001524`*^9}, {3.859051000250376*^9, 
   3.8590510038005934`*^9}, 3.8590510459006414`*^9, {3.859051173910393*^9, 
   3.859051175805846*^9}, {3.859051249080512*^9, 3.859051250381168*^9}, {
   3.8593568126628437`*^9, 3.8593568650208387`*^9}, {3.859356922011098*^9, 
   3.8593569395791025`*^9}, {3.859356977083248*^9, 3.859356983106592*^9}, {
   3.85935889156075*^9, 3.859358921615469*^9}, 3.8593658851267586`*^9, {
   3.8593659821243067`*^9, 3.8593660032185135`*^9}, {3.8593661430275097`*^9, 
   3.859366146152689*^9}, {3.8593665397702026`*^9, 3.859366540647252*^9}, {
   3.8593665782014008`*^9, 3.859366584557764*^9}, {3.85936666664946*^9, 
   3.8593666699006453`*^9}, {3.859366726544885*^9, 3.8593667406466923`*^9}, {
   3.8593669357948537`*^9, 3.8593669517457657`*^9}, {3.8593669913180294`*^9, 
   3.8593669964243217`*^9}, 3.859367049141337*^9, 3.859367146637913*^9, 
   3.8593672422193804`*^9, {3.859367368864624*^9, 3.859367369757675*^9}, {
   3.859367549158936*^9, 3.859367571188196*^9}, {3.8593689020303164`*^9, 
   3.859368953642268*^9}, {3.859369003402114*^9, 3.8593690438334265`*^9}, {
   3.8593690811175594`*^9, 3.8593690902730827`*^9}, {3.859369251749319*^9, 
   3.859369257340638*^9}, {3.8593693133568425`*^9, 3.8593693218563285`*^9}, 
   3.8593694033299885`*^9, {3.8593710303750505`*^9, 3.859371049323134*^9}, {
   3.8593713794750175`*^9, 3.8593713937338333`*^9}, {3.859371551751871*^9, 
   3.859371556244128*^9}, {3.8593743814137187`*^9, 3.859374382585786*^9}, {
   3.8593745543756113`*^9, 3.8593745799180727`*^9}, {3.859375095252548*^9, 
   3.8593750963436103`*^9}, {3.859375182899561*^9, 3.859375183591601*^9}, {
   3.859375243267014*^9, 3.859375245663151*^9}, {3.8593823852825136`*^9, 
   3.859382393030957*^9}, {3.8593824480941067`*^9, 3.859382457318634*^9}, {
   3.8593827935918674`*^9, 3.859382838995465*^9}, 3.8593830763720417`*^9, {
   3.859383111338042*^9, 3.859383113367158*^9}, {3.8593831753027*^9, 
   3.859383209597662*^9}, {3.8593832563893385`*^9, 3.8593833279164295`*^9}, 
   3.8593835154281545`*^9, {3.8593836293476706`*^9, 3.859383690601174*^9}, {
   3.859383838761648*^9, 3.8593838391926727`*^9}, {3.859384470168762*^9, 
   3.859384470684792*^9}, {3.85938458341524*^9, 3.8593845837952614`*^9}, {
   3.8593846651269135`*^9, 3.8593848148494773`*^9}, {3.859431460785472*^9, 
   3.8594314948044176`*^9}, 3.859431554863853*^9, {3.8594315982313337`*^9, 
   3.8594316023955717`*^9}, {3.8594317159670677`*^9, 3.859431738704368*^9}, {
   3.859431908521081*^9, 3.85943196042505*^9}},
 CellLabel->
  "In[337]:=",ExpressionUUID->"acf4e686-9a95-417c-9ebd-460e38edbdd4"],

Cell[BoxData[
 TemplateBox[{
  "Set", "shape", 
   "\"Lists \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"shortestDist\\\", \\\",\\\
\", \\\"shortestPerm\\\", \\\",\\\", \\\"totalDistances\\\", \\\",\\\", \
\\\"savedPerm\\\"}], \\\"}\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"MCSolutionOfTSP\\\", \\\"[\\\", RowBox[{\\\"\
\[LeftSkeleton]\\\", \\\"1\\\", \\\"\[RightSkeleton]\\\"}], \\\"]\\\"}]\\) \
are not the same shape.\"", 2, 340, 3, 30093825131158965695, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8788874336271086`*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"1ed91fcc-1931-47cb-98ab-3e70b5ed4926"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Shortest tour found (black) is \"\>", "\[InvisibleSpace]", 
   "shortestDist", 
   "\[InvisibleSpace]", "\<\", but the actual shortest tour (green) is \"\>", 
   "\[InvisibleSpace]", "6.276727658227593`"}],
  SequenceForm[
  "Shortest tour found (black) is ", $CellContext`shortestDist, 
   ", but the actual shortest tour (green) is ", 6.276727658227593],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.859366960954293*^9, {3.8593670330704174`*^9, 3.8593670497133694`*^9}, 
   3.8593671503011227`*^9, {3.8593672267324944`*^9, 3.8593672430174255`*^9}, 
   3.859367370312707*^9, {3.859367533877062*^9, 3.859367571793231*^9}, {
   3.8593690288195677`*^9, 3.8593690447054763`*^9}, 3.8593690918271713`*^9, {
   3.859369258204688*^9, 3.859369268157257*^9}, {3.8593693226073713`*^9, 
   3.8593694309805703`*^9}, {3.859371036506401*^9, 3.8593710499911723`*^9}, {
   3.859371380143056*^9, 3.8593713946698866`*^9}, 3.8593714832769547`*^9, {
   3.859371534001856*^9, 3.8593715579442253`*^9}, 3.859374055388071*^9, {
   3.8593743274536324`*^9, 3.8593743491538734`*^9}, {3.8593743857139645`*^9, 
   3.859374397616646*^9}, {3.8593744958642645`*^9, 3.859374505954842*^9}, 
   3.859374583067253*^9, 3.859375099640799*^9, 3.8593751541139145`*^9, {
   3.8593751848756742`*^9, 3.8593752046568055`*^9}, 3.859381996525278*^9, 
   3.859382474415612*^9, 3.8593827985851536`*^9, 3.8593828462258787`*^9, 
   3.859382990175112*^9, 3.8593830774381027`*^9, 3.859383114507223*^9, {
   3.859383160523855*^9, 3.859383223871478*^9}, {3.8593833026079817`*^9, 
   3.8593833317626495`*^9}, 3.8593835184113255`*^9, 3.8593836938153577`*^9, 
   3.85938384002672*^9, {3.859384458340086*^9, 3.8593844727269087`*^9}, 
   3.859384585724372*^9, {3.859384668128085*^9, 3.8593848347176137`*^9}, {
   3.8594315414280844`*^9, 3.8594317589245243`*^9}, {3.8594319281822057`*^9, 
   3.8594319614321074`*^9}, 3.8594320570445757`*^9, 3.8788874338487062`*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"d5d330f0-d45d-408c-9697-4a54632ef118"],

Cell[BoxData[
 TemplateBox[{
  "Part", "partd", 
   "\"Part specification \\!\\(\\*RowBox[{\\\"shortestPerm\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"1\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"", 2, 343, 4, 30093825131158965695, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8788874340277033`*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"677bf3a6-6958-45c8-ac49-80bf830ac53d"],

Cell[BoxData[
 TemplateBox[{
  "Append", "normal", 
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Append\\\", \
\\\"[\\\", RowBox[{\\\"shortestPerm\\\", \\\",\\\", \
RowBox[{\\\"shortestPerm\\\", \\\"\[LeftDoubleBracket]\\\", \\\"1\\\", \\\"\
\[RightDoubleBracket]\\\"}]}], \\\"]\\\"}]\\).\"", 2, 343, 5, 
   30093825131158965695, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.878887434061945*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"9cad365b-5ee7-4ecf-b5fb-d80ffa7db4bb"],

Cell[BoxData[
 TemplateBox[{
  "Part", "pkspec1", 
   "\"The expression \\!\\(\\*RowBox[{\\\"Append\\\", \\\"[\\\", \
RowBox[{\\\"shortestPerm\\\", \\\",\\\", RowBox[{\\\"shortestPerm\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"1\\\", \\\"\[RightDoubleBracket]\\\"}]}], \\\"]\
\\\"}]\\) cannot be used as a part specification.\"", 2, 343, 6, 
   30093825131158965695, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.878887434072006*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"33e3febd-b409-4537-a3b6-dc59091e1316"],

Cell[BoxData[
 TemplateBox[{
  "Last", "normal", 
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Last\\\", \\\"[\\\", \
\\\"savedPerm\\\", \\\"]\\\"}]\\).\"", 2, 343, 7, 30093825131158965695, 
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.878887434103258*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"b756402d-28f7-4034-a90c-12e78ed08807"],

Cell[BoxData[
 TemplateBox[{
  "Last", "normal", 
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Last\\\", \\\"[\\\", \
\\\"savedPerm\\\", \\\"]\\\"}]\\).\"", 2, 343, 8, 30093825131158965695, 
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.878887434114338*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"59c7445c-2e8e-417e-8c8f-e0353bc82e02"],

Cell[BoxData[
 TemplateBox[{
  "Part", "pkspec1", 
   "\"The expression \\!\\(\\*RowBox[{\\\"savedPerm\\\"}]\\) cannot be used \
as a part specification.\"", 2, 343, 9, 30093825131158965695, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.878887434124383*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"61a186b4-b88a-4b42-a802-ee0ac09757f5"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQrfdJ3GvS2f/2+Vxfcw42fLJv0FrE2W7+3z7k1+mz
uz9+sTebNo9vguM/+wbzi13dzt+h4n/s9ddaNU1M/2n/bK69sX/AbzgNE4ep
g+mDmQMzF2YPzF6YOxjA4AOUZnBQfi2qVvvvFVw+gjsjpUPmGVw/w8TYVy8q
HsLNd/EW/b4z8Rbc/owORuPD+y7B3Zegu2CiYtEJuDtnzBET+/9sN9ydAht2
nZbjXwl3J8NLti+3zDrh7mRAAR/g8jB3wvTD3AkzH+ZOmP0wd8LcB6Nh4jB1
MH0wc2DmwuyB2QtzB1r4McDdDZWH+QumH+ZvmPmwcIHZDws3mPtg4QpzJyzc
Ye6ExQvMnbB4g7sTGq8wdwIAGCMm0Q==
       "]]}, {
      TagBox[
       {Opacity[0.], PointBox[{{1.9876883405951378`, 1.156434465040231}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {1}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.9510565162951536`, 1.3090169943749475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {2}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8910065241883678`, 1.4539904997395467`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {3}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8090169943749475`, 1.5877852522924731`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {4}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7071067811865475`, 1.7071067811865475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {5}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.5877852522924731`, 1.8090169943749475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {6}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.4539904997395467`, 1.8910065241883678`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {7}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.3090169943749475`, 1.9510565162951536`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {8}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.156434465040231, 1.9876883405951378`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {9}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1., 2.}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {10}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.8435655349597692, 1.9876883405951378`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {11}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.6909830056250525, 1.9510565162951536`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {12}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.5460095002604533, 1.8910065241883678`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {13}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.41221474770752686`, 1.8090169943749475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {14}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.29289321881345254`, 1.7071067811865475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {15}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.19098300562505255`, 1.5877852522924731`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {16}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.1089934758116321, 1.4539904997395467`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {17}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.04894348370484647, 1.3090169943749475`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {18}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.01231165940486223, 1.156434465040231}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {19}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0., 1.}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {20}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.01231165940486223, 0.8435655349597692}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {21}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.04894348370484647, 0.6909830056250525}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {22}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.1089934758116321, 0.5460095002604533}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {23}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.19098300562505255`, 0.41221474770752686`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {24}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.29289321881345254`, 0.29289321881345254`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {25}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.41221474770752686`, 0.19098300562505255`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {26}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.5460095002604533, 0.1089934758116321}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {27}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.6909830056250525, 0.04894348370484647}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {28}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{0.8435655349597692, 0.01231165940486223}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {29}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1., 0.}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {30}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.156434465040231, 0.01231165940486223}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {31}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.3090169943749475`, 0.04894348370484647}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {32}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.4539904997395467`, 0.1089934758116321}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {33}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.5877852522924731`, 0.19098300562505255`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {34}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.7071067811865475`, 0.29289321881345254`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {35}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8090169943749475`, 0.41221474770752686`}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {36}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.8910065241883678`, 0.5460095002604533}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {37}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.9510565162951536`, 0.6909830056250525}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {38}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{1.9876883405951378`, 0.8435655349597692}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {39}}]& ], 
      TagBox[
       {Opacity[0.], PointBox[{{2., 1.}}]},
       Annotation[#, {{Labeled}, Charting`Private`Tag$42956, {
         40}}]& ]}}, {{{{}, {GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 13.000000000000002`}, {
              1.9878946393438173`, 1.0121053606561827`}], 
             Offset[{1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.9878946393438173`, 1.0121053606561827`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.9878946393438173`, 
              1.0121053606561827`}], 
             Offset[{-17., 12.999999999999998`}, {1.9878946393438173`, 
              1.0121053606561827`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["40",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 6.5}, {1.9878946393438173, 1.0121053606561827}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {1.9997937012513205`, 
              0.8556708956159519}], 
             Offset[{17., 1.7763568394002505`*^-15}, {1.9997937012513205`, 
              0.8556708956159519}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.9997937012513205`, 0.8556708956159519}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              1.9997937012513205`, 0.8556708956159519}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["39",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {1.9997937012513205, 0.8556708956159519}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              1.938951155638971, 0.6788776449688698}], 
             Offset[{1.7763568394002505`*^-15, -12.999999999999998`}, {
              1.938951155638971, 0.6788776449688698}], 
             Offset[{-17., -13.000000000000002`}, {1.938951155638971, 
              0.6788776449688698}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {1.938951155638971, 
              0.6788776449688698}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["38",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, -6.5}, {1.938951155638971, 0.6788776449688698}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {1.908126089405759, 
              0.5460095002604533}], 
             Offset[{17., -6.499999999999998}, {1.908126089405759, 
              0.5460095002604533}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              1.908126089405759, 0.5460095002604533}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              1.908126089405759, 0.5460095002604533}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["37",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {1.908126089405759, 0.5460095002604533}], NCache[
           ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {1.8211223550311302`, 
              0.4243201083637096}], 
             Offset[{17., 1.7763568394002505`*^-15}, {1.8211223550311302`, 
              0.4243201083637096}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.8211223550311302`, 0.4243201083637096}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              1.8211223550311302`, 0.4243201083637096}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["36",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {1.8211223550311302, 0.4243201083637096}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {1.7192121418427302`, 
              0.30499857946963527`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {1.7192121418427302`, 
              0.30499857946963527`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.7192121418427302`, 0.30499857946963527`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              1.7192121418427302`, 0.30499857946963527`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["35",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {1.7192121418427302, 0.30499857946963527}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {1.6049048175098644`, 
              0.19098300562505255`}], 
             Offset[{17., -6.499999999999998}, {1.6049048175098644`, 
              0.19098300562505255`}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              1.6049048175098644`, 0.19098300562505255`}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              1.6049048175098644`, 0.19098300562505255`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["34",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {1.6049048175098644, 0.19098300562505255}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {1.471110064956938, 
              0.1089934758116321}], 
             Offset[{17., -6.499999999999998}, {1.471110064956938, 
              0.1089934758116321}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              1.471110064956938, 0.1089934758116321}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              1.471110064956938, 0.1089934758116321}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["33",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {1.471110064956938, 0.1089934758116321}], NCache[
           ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {1.3261365595923387`, 
              0.04894348370484647}], 
             Offset[{17., -6.499999999999998}, {1.3261365595923387`, 
              0.04894348370484647}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              1.3261365595923387`, 0.04894348370484647}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              1.3261365595923387`, 0.04894348370484647}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["32",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {1.3261365595923387, 0.04894348370484647}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              1.156434465040231, 0.029431224622253532`}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              1.156434465040231, 0.029431224622253532`}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              1.156434465040231, 0.029431224622253532`}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              1.156434465040231, 0.029431224622253532`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["31",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {1.156434465040231, 0.029431224622253532}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {1., 
              0.017119565217391303`}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {1., 
              0.017119565217391303`}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {1., 
              0.017119565217391303`}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {1., 
              0.017119565217391303`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["30",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], Offset[{0., 6.5}, {1., 0.017119565217391303}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.8435655349597692, 0.029431224622253532`}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.8435655349597692, 0.029431224622253532`}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.8435655349597692, 0.029431224622253532`}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.8435655349597692, 0.029431224622253532`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["29",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.8435655349597692, 0.029431224622253532}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.6909830056250525, 0.06606304892223777}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.6909830056250525, 0.06606304892223777}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.6909830056250525, 0.06606304892223777}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.6909830056250525, 0.06606304892223777}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["28",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.6909830056250525, 0.06606304892223777}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.5460095002604533, 0.1261130410290234}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.5460095002604533, 0.1261130410290234}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.5460095002604533, 0.1261130410290234}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.5460095002604533, 0.1261130410290234}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["27",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.5460095002604533, 0.1261130410290234}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.41221474770752686`, 0.20810257084244385`}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.41221474770752686`, 0.20810257084244385`}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.41221474770752686`, 0.20810257084244385`}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.41221474770752686`, 0.20810257084244385`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["26",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.41221474770752686, 0.20810257084244385}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 13.000000000000002`}, {
              0.2807878581572698, 0.30499857946963527`}], 
             Offset[{1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
              0.2807878581572698, 0.30499857946963527`}], 
             Offset[{-17., -1.7763568394002505`*^-15}, {0.2807878581572698, 
              0.30499857946963527`}], 
             Offset[{-17., 12.999999999999998`}, {0.2807878581572698, 
              0.30499857946963527`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["25",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-8.5, 6.5}, {0.2807878581572698, 0.30499857946963527}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.19098300562505255`, 0.4293343129249182}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.19098300562505255`, 0.4293343129249182}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.19098300562505255`, 0.4293343129249182}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.19098300562505255`, 0.4293343129249182}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["24",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.19098300562505255, 0.4293343129249182}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 1.7763568394002505`*^-15}, {
              0.1089934758116321, 0.5288899350430619}], 
             Offset[{8.500000000000002, -12.999999999999998`}, {
              0.1089934758116321, 0.5288899350430619}], 
             Offset[{-8.499999999999998, -13.000000000000002`}, {
              0.1089934758116321, 0.5288899350430619}], 
             Offset[{-8.500000000000002, -1.7763568394002505`*^-15}, {
              0.1089934758116321, 0.5288899350430619}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["23",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.5}, {0.1089934758116321, 0.5288899350430619}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.06104884436102921, 
              0.7030883662812353}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.06104884436102921, 
              0.7030883662812353}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.06104884436102921, 0.7030883662812353}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.06104884436102921, 0.7030883662812353}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["22",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.06104884436102921, 0.7030883662812353}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.024417020061044972`, 
              0.8556708956159519}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.024417020061044972`, 
              0.8556708956159519}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.024417020061044972`, 0.8556708956159519}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.024417020061044972`, 0.8556708956159519}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["21",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.024417020061044972, 0.8556708956159519}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.01210536065618274, 
              1.0121053606561827`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.01210536065618274, 
              1.0121053606561827`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.01210536065618274, 1.0121053606561827`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.01210536065618274, 1.0121053606561827`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["20",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.01210536065618274, 1.0121053606561827}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.024417020061044972`, 
              1.1685398256964137`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.024417020061044972`, 
              1.1685398256964137`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.024417020061044972`, 1.1685398256964137`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.024417020061044972`, 1.1685398256964137`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["19",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.024417020061044972, 1.1685398256964137}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.06104884436102921, 
              1.3211223550311302`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.06104884436102921, 
              1.3211223550311302`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.06104884436102921, 1.3211223550311302`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.06104884436102921, 1.3211223550311302`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["18",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.06104884436102921, 1.3211223550311302}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.12109883646781484`, 
              1.4660958603957295`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.12109883646781484`, 
              1.4660958603957295`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.12109883646781484`, 1.4660958603957295`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.12109883646781484`, 1.4660958603957295`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["17",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.12109883646781484, 1.4660958603957295}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {0.20308836628123528`, 
              1.5998906129486559`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {0.20308836628123528`, 
              1.5998906129486559`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.20308836628123528`, 1.5998906129486559`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              0.20308836628123528`, 1.5998906129486559`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["16",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {0.20308836628123528, 1.5998906129486559}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {0.31001278403084387`, 
              1.7071067811865475`}], 
             Offset[{17., -6.499999999999998}, {0.31001278403084387`, 
              1.7071067811865475`}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              0.31001278403084387`, 1.7071067811865475`}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              0.31001278403084387`, 1.7071067811865475`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["15",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {0.31001278403084387, 1.7071067811865475}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {0.4293343129249182, 
              1.8090169943749475`}], 
             Offset[{17., -6.499999999999998}, {0.4293343129249182, 
              1.8090169943749475`}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              0.4293343129249182, 1.8090169943749475`}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              0.4293343129249182, 1.8090169943749475`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["14",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {0.4293343129249182, 1.8090169943749475}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 6.500000000000002}, {0.5631290654778446, 
              1.8910065241883678`}], 
             Offset[{17., -6.499999999999998}, {0.5631290654778446, 
              1.8910065241883678`}], 
             Offset[{1.7763568394002505`*^-15, -6.500000000000002}, {
              0.5631290654778446, 1.8910065241883678`}], 
             Offset[{-1.7763568394002505`*^-15, 6.499999999999998}, {
              0.5631290654778446, 1.8910065241883678`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["13",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 0.}, {0.5631290654778446, 1.8910065241883678}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{8.499999999999998, 13.000000000000002`}, {
              0.6909830056250525, 1.9681760815125449`}], 
             Offset[{8.500000000000002, 1.7763568394002505`*^-15}, {
              0.6909830056250525, 1.9681760815125449`}], 
             Offset[{-8.499999999999998, -1.7763568394002505`*^-15}, {
              0.6909830056250525, 1.9681760815125449`}], 
             Offset[{-8.500000000000002, 12.999999999999998`}, {
              0.6909830056250525, 1.9681760815125449`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["12",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., 6.5}, {0.6909830056250525, 1.9681760815125449}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 1.7763568394002505`*^-15}, {0.8556708956159519, 
              1.975582979938955}], 
             Offset[{17., -12.999999999999998`}, {0.8556708956159519, 
              1.975582979938955}], 
             Offset[{1.7763568394002505`*^-15, -13.000000000000002`}, {
              0.8556708956159519, 1.975582979938955}], 
             Offset[{-1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              0.8556708956159519, 1.975582979938955}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["11",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, -6.5}, {0.8556708956159519, 1.975582979938955}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{17., 13.000000000000002`}, {1.0121053606561827`, 
              2.0121053606561827`}], 
             Offset[{17., 1.7763568394002505`*^-15}, {1.0121053606561827`, 
              2.0121053606561827`}], 
             Offset[{1.7763568394002505`*^-15, -1.7763568394002505`*^-15}, {
              1.0121053606561827`, 2.0121053606561827`}], 
             Offset[{-1.7763568394002505`*^-15, 12.999999999999998`}, {
              1.0121053606561827`, 2.0121053606561827`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["10",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{8.5, 6.5}, {1.0121053606561827, 2.0121053606561827}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{5.499999999999998, 8.881784197001252*^-16}, {
              1.156434465040231, 1.9705687753777466`}], 
             Offset[{5.500000000000002, -13.}, {1.156434465040231, 
              1.9705687753777466`}], 
             Offset[{-5.499999999999998, -13.}, {1.156434465040231, 
              1.9705687753777466`}], 
             Offset[{-5.500000000000002, -8.881784197001252*^-16}, {
              1.156434465040231, 1.9705687753777466`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["9",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{0., -6.5}, {1.156434465040231, 1.9705687753777466}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 13.}, {1.3211223550311302`, 
              1.9631618769513364`}], 
             Offset[{11.000000000000002`, 8.881784197001252*^-16}, {
              1.3211223550311302`, 1.9631618769513364`}], 
             Offset[{1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.3211223550311302`, 1.9631618769513364`}], 
             Offset[{-1.7763568394002505`*^-15, 13.}, {1.3211223550311302`, 
              1.9631618769513364`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["8",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, 6.5}, {1.3211223550311302, 1.9631618769513364}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 13.}, {1.4660958603957295`, 
              1.9031118848445505`}], 
             Offset[{11.000000000000002`, 8.881784197001252*^-16}, {
              1.4660958603957295`, 1.9031118848445505`}], 
             Offset[{1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.4660958603957295`, 1.9031118848445505`}], 
             Offset[{-1.7763568394002505`*^-15, 13.}, {1.4660958603957295`, 
              1.9031118848445505`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["7",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, 6.5}, {1.4660958603957295, 1.9031118848445505}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 13.}, {1.5998906129486559`, 
              1.8211223550311302`}], 
             Offset[{11.000000000000002`, 8.881784197001252*^-16}, {
              1.5998906129486559`, 1.8211223550311302`}], 
             Offset[{1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.5998906129486559`, 1.8211223550311302`}], 
             Offset[{-1.7763568394002505`*^-15, 13.}, {1.5998906129486559`, 
              1.8211223550311302`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["6",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, 6.5}, {1.5998906129486559, 1.8211223550311302}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 13.}, {1.7192121418427302`, 
              1.7192121418427302`}], 
             Offset[{11.000000000000002`, 8.881784197001252*^-16}, {
              1.7192121418427302`, 1.7192121418427302`}], 
             Offset[{1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.7192121418427302`, 1.7192121418427302`}], 
             Offset[{-1.7763568394002505`*^-15, 13.}, {1.7192121418427302`, 
              1.7192121418427302`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["5",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, 6.5}, {1.7192121418427302, 1.7192121418427302}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              1.8211223550311302`, 1.5756798916362904`}], 
             Offset[{11.000000000000002`, -13.}, {1.8211223550311302`, 
              1.5756798916362904`}], 
             Offset[{1.7763568394002505`*^-15, -13.}, {1.8211223550311302`, 
              1.5756798916362904`}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.8211223550311302`, 1.5756798916362904`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["4",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.5}, {1.8211223550311302, 1.5756798916362904}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              1.9031118848445505`, 1.441885139083364}], 
             Offset[{11.000000000000002`, -13.}, {1.9031118848445505`, 
              1.441885139083364}], 
             Offset[{1.7763568394002505`*^-15, -13.}, {1.9031118848445505`, 
              1.441885139083364}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.9031118848445505`, 1.441885139083364}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["3",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.5}, {1.9031118848445505, 1.441885139083364}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{-1.7763568394002505`*^-15, 8.881784197001252*^-16}, {
              1.938951155638971, 1.2969116337187647`}], 
             Offset[{1.7763568394002505`*^-15, -13.}, {1.938951155638971, 
              1.2969116337187647`}], 
             Offset[{-10.999999999999998`, -13.}, {1.938951155638971, 
              1.2969116337187647`}], 
             Offset[{-11.000000000000002`, -8.881784197001252*^-16}, {
              1.938951155638971, 1.2969116337187647`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["2",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{-5.5, -6.5}, {1.938951155638971, 1.2969116337187647}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
          {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
            NCache[
             Rational[2, 3], 0.6666666666666666]]}], 
           PolygonBox[{
            Offset[{10.999999999999998`, 8.881784197001252*^-16}, {
              1.9997937012513205`, 1.1443291043840482`}], 
             Offset[{11.000000000000002`, -13.}, {1.9997937012513205`, 
              1.1443291043840482`}], 
             Offset[{1.7763568394002505`*^-15, -13.}, {1.9997937012513205`, 
              1.1443291043840482`}], 
             Offset[{-1.7763568394002505`*^-15, -8.881784197001252*^-16}, {
              1.9997937012513205`, 1.1443291043840482`}]}]}, 
          {RGBColor[
           0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
           AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
           StyleBox[
            RotationBox["1",
             BoxRotation->0.],
            StripOnInput->False,
            LineOpacity->1,
            FrontFaceOpacity->1,
            BackFaceOpacity->1,
            Opacity->1,
            FontOpacity->1], 
           Offset[{5.5, -6.5}, {1.9997937012513205, 1.1443291043840482}], 
           NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
            ImageScaled[{0.5, 0.5}]]]}]}}, {}}, {}}}, {
    {GrayLevel[0], Thickness[Large], LineBox[Part[CompressedData["
1:eJxTTMoPSmViYGDQAGIQrfdJ3GvS2f/2+Vxfcw42fLJv0FrE2W7+3z7k1+mz
uz9+sTebNo9vguM/+wbzi13dzt+h4n/s9ddaNU1M/2n/bK69sX/AbzgNE4ep
g+mDmQMzF2YPzF6YOxjA4AOUZnBQfi2qVvvvFVw+gjsjpUPmGVw/w8TYVy8q
HsLNd/EW/b4z8Rbc/owORuPD+y7B3Zegu2CiYtEJuDtnzBET+/9sN9ydAht2
nZbjXwl3J8NLti+3zDrh7mRAAR/g8jB3wvTD3AkzH+ZOmP0wd8LcB6Nh4jB1
MH0wc2DmwuyB2QtzB1r4McDdDZWH+QumH+ZvmPmwcIHZDws3mPtg4QpzJyzc
Ye6ExQvMnbB4g7sTGq8wdwIAGCMm0Q==
       "], 
       Append[$CellContext`shortestPerm, 
        Part[$CellContext`shortestPerm, 1]]]]}, 
    {RGBColor[1, 0, 0], Thickness[Tiny], LineBox[Part[CompressedData["
1:eJxTTMoPSmViYGDQAGIQrfdJ3GvS2f/2+Vxfcw42fLJv0FrE2W7+3z7k1+mz
uz9+sTebNo9vguM/+wbzi13dzt+h4n/s9ddaNU1M/2n/bK69sX/AbzgNE4ep
g+mDmQMzF2YPzF6YOxjA4AOUZnBQfi2qVvvvFVw+gjsjpUPmGVw/w8TYVy8q
HsLNd/EW/b4z8Rbc/owORuPD+y7B3Zegu2CiYtEJuDtnzBET+/9sN9ydAht2
nZbjXwl3J8NLti+3zDrh7mRAAR/g8jB3wvTD3AkzH+ZOmP0wd8LcB6Nh4jB1
MH0wc2DmwuyB2QtzB1r4McDdDZWH+QumH+ZvmPmwcIHZDws3mPtg4QpzJyzc
Ye6ExQvMnbB4g7sTGq8wdwIAGCMm0Q==
       "], $CellContext`savedPerm]]}, 
    {RGBColor[0, 1, 0], Thickness[Tiny], Dashing[{Small, Small}], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQrfdJ3GvS2f/2+Vxfcw42fLJngAAHCPXBHiav/FpU
rfbfK/sGrUWc7eb/7SO4M1I6ZJ7Zm02bxzfB8Z89w8TYVy8qHtqH/Dp9dvfH
P/Yu3qLfdybesn82197YP+C3fUYHo/HhfZfs9ddaNU1M/2mfoLtgomLRCfsG
84td3c7f7WfMERP7/2w3VP8Xe4ENu07L8a9EuOsl25dbZp32MHdB3ckAcxdM
HuYumH6Yu2Dmw9wFsx/mLhgNE4epg+mDmQMzF2YPzF64O1DAB7g8zB8w/TB/
wsyHhQPMflg4wdwFC0eYu2DhDHMXLB5g7oLFE8xdsHhECz8HmLtg8jB3wfTD
3AUzH+YumP0wd8FomDhMHUwfzByYuTB70NMfAM6XLzw=
      "]]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{All, All}, {All, All}},
  ImageSize->{526.6666666666664, Automatic},
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 2.}, {0., 2.}},
  PlotRangePadding->{{0, 
     Scaled[0.08]}, {0, 
     Scaled[0.08]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8590452610658383`*^9, 3.8590500574739714`*^9, 3.859050853020894*^9, 
   3.8590509036002817`*^9, 3.8590509436805825`*^9, 3.859051017385399*^9, 
   3.859051058916754*^9, {3.859051165111351*^9, 3.859051180960532*^9}, {
   3.859051241215539*^9, 3.8590512578605976`*^9}, 3.8593559200407887`*^9, 
   3.8593559654633865`*^9, 3.859358733615716*^9, {3.8593588981281257`*^9, 
   3.859358939586497*^9}, 3.859365890463064*^9, 3.8593660080597906`*^9, 
   3.859366046099966*^9, 3.859366090273493*^9, 3.859366147455763*^9, {
   3.859366341757877*^9, 3.859366370415516*^9}, 3.859366463300829*^9, 
   3.859366542278346*^9, 3.8593665861758566`*^9, 3.8593666729818215`*^9, {
   3.8593667306791215`*^9, 3.8593667439328794`*^9}, {3.8593669531658473`*^9, 
   3.8593669611953063`*^9}, {3.8593670333164315`*^9, 3.859367049961384*^9}, 
   3.859367150536136*^9, {3.859367226983509*^9, 3.859367243289441*^9}, 
   3.8593673705567207`*^9, {3.859367534121076*^9, 3.859367572037245*^9}, {
   3.8593690290755825`*^9, 3.8593690449824924`*^9}, 3.859369092102187*^9, {
   3.859369258470703*^9, 3.8593692684262724`*^9}, {3.8593693228843875`*^9, 
   3.8593694312335844`*^9}, {3.8593710368094187`*^9, 3.859371050264188*^9}, {
   3.8593713804000707`*^9, 3.859371394924901*^9}, 3.859371483790984*^9, {
   3.859371534274872*^9, 3.8593715582132406`*^9}, 3.859374055632085*^9, {
   3.859374327713647*^9, 3.8593743494318895`*^9}, {3.85937438597998*^9, 
   3.859374397882661*^9}, {3.8593744961142793`*^9, 3.859374506220857*^9}, 
   3.859374583337268*^9, 3.8593750998988132`*^9, 3.8593751544389334`*^9, {
   3.8593751851396894`*^9, 3.859375204924821*^9}, 3.859381996769292*^9, 
   3.8593824746516256`*^9, 3.859382798821167*^9, 3.859382846468892*^9, 
   3.8593829904141254`*^9, 3.859383077700118*^9, 3.859383114769238*^9, {
   3.8593831607828703`*^9, 3.859383224131493*^9}, {3.859383302866997*^9, 
   3.8593833320286646`*^9}, 3.8593835186513386`*^9, 3.8593836940623717`*^9, 
   3.8593838401667285`*^9, {3.859384458680105*^9, 3.85938447309593*^9}, 
   3.859384586064391*^9, {3.8593846684711046`*^9, 3.8593848350786343`*^9}, {
   3.859431544936285*^9, 3.85943176233272*^9}, {3.8594319285302258`*^9, 
   3.859431961769127*^9}, 3.859432057356594*^9, 3.8788874341969423`*^9},
 CellLabel->
  "Out[343]=",ExpressionUUID->"0a365a70-60f0-4a45-b73e-c55cbf49dd20"],

Cell[BoxData[
 TemplateBox[{
  "ListPlot", "lpn", 
   "\"\\!\\(\\*RowBox[{\\\"totalDistances\\\"}]\\) is not a list of numbers \
or pairs of numbers.\"", 2, 344, 10, 30093825131158965695, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.878887434356147*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"31fdd8e8-5bed-45a2-b326-a39c74d5379a"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"totalDistances", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Output",
 CellChangeTimes->{
  3.8590452610658383`*^9, 3.8590500574739714`*^9, 3.859050853020894*^9, 
   3.8590509036002817`*^9, 3.8590509436805825`*^9, 3.859051017385399*^9, 
   3.859051058916754*^9, {3.859051165111351*^9, 3.859051180960532*^9}, {
   3.859051241215539*^9, 3.8590512578605976`*^9}, 3.8593559200407887`*^9, 
   3.8593559654633865`*^9, 3.859358733615716*^9, {3.8593588981281257`*^9, 
   3.859358939586497*^9}, 3.859365890463064*^9, 3.8593660080597906`*^9, 
   3.859366046099966*^9, 3.859366090273493*^9, 3.859366147455763*^9, {
   3.859366341757877*^9, 3.859366370415516*^9}, 3.859366463300829*^9, 
   3.859366542278346*^9, 3.8593665861758566`*^9, 3.8593666729818215`*^9, {
   3.8593667306791215`*^9, 3.8593667439328794`*^9}, {3.8593669531658473`*^9, 
   3.8593669611953063`*^9}, {3.8593670333164315`*^9, 3.859367049961384*^9}, 
   3.859367150536136*^9, {3.859367226983509*^9, 3.859367243289441*^9}, 
   3.8593673705567207`*^9, {3.859367534121076*^9, 3.859367572037245*^9}, {
   3.8593690290755825`*^9, 3.8593690449824924`*^9}, 3.859369092102187*^9, {
   3.859369258470703*^9, 3.8593692684262724`*^9}, {3.8593693228843875`*^9, 
   3.8593694312335844`*^9}, {3.8593710368094187`*^9, 3.859371050264188*^9}, {
   3.8593713804000707`*^9, 3.859371394924901*^9}, 3.859371483790984*^9, {
   3.859371534274872*^9, 3.8593715582132406`*^9}, 3.859374055632085*^9, {
   3.859374327713647*^9, 3.8593743494318895`*^9}, {3.85937438597998*^9, 
   3.859374397882661*^9}, {3.8593744961142793`*^9, 3.859374506220857*^9}, 
   3.859374583337268*^9, 3.8593750998988132`*^9, 3.8593751544389334`*^9, {
   3.8593751851396894`*^9, 3.859375204924821*^9}, 3.859381996769292*^9, 
   3.8593824746516256`*^9, 3.859382798821167*^9, 3.859382846468892*^9, 
   3.8593829904141254`*^9, 3.859383077700118*^9, 3.859383114769238*^9, {
   3.8593831607828703`*^9, 3.859383224131493*^9}, {3.859383302866997*^9, 
   3.8593833320286646`*^9}, 3.8593835186513386`*^9, 3.8593836940623717`*^9, 
   3.8593838401667285`*^9, {3.859384458680105*^9, 3.85938447309593*^9}, 
   3.859384586064391*^9, {3.8593846684711046`*^9, 3.8593848350786343`*^9}, {
   3.859431544936285*^9, 3.85943176233272*^9}, {3.8594319285302258`*^9, 
   3.859431961769127*^9}, 3.859432057356594*^9, 3.878887434366262*^9},
 CellLabel->
  "Out[344]=",ExpressionUUID->"530d3c3e-7a0e-42cb-b129-b57be2b71e4e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{
            RowBox[{
            "cities", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            ",", "i"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"PointSize", "[", "Medium", "]"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Line", "[", 
        RowBox[{"cities", "\[LeftDoubleBracket]", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{
           "savedPerm", "\[LeftDoubleBracket]", "j", 
            "\[RightDoubleBracket]"}], ",", 
           RowBox[{"savedPerm", "\[LeftDoubleBracket]", 
            RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], 
         "\[RightDoubleBracket]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "1", ",", "nSave", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8593567864943466`*^9, 3.8593568008411674`*^9}, {
  3.8593586691650295`*^9, 3.8593587015288806`*^9}, {3.859383375142131*^9, 
  3.859383400691592*^9}, {3.8593834888366337`*^9, 3.859383494841977*^9}},
 CellLabel->
  "In[1486]:=",ExpressionUUID->"75f1c713-a4e6-4bdd-af8f-204ba6adb139"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`j$$ = 55, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`j$$], 1, 127, 1}}, Typeset`size$$ = {
    540., {264., 271.90576171875}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`j$1609352$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`j$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`j$$, $CellContext`j$1609352$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[{
         ListPlot[
          Table[
           Labeled[
            
            Part[$CellContext`cities, $CellContext`i], $CellContext`i], \
{$CellContext`i, 1, $CellContext`n}], PlotStyle -> PointSize[Medium], 
          PlotRange -> {{$CellContext`xmin, $CellContext`xmax}, \
{$CellContext`ymin, $CellContext`ymax}}, AspectRatio -> 1], 
         Graphics[
          Line[
           Part[$CellContext`cities, 
            Append[
             Part[$CellContext`savedPerm, $CellContext`j$$], 
             Part[$CellContext`savedPerm, $CellContext`j$$, 1]]]]]}], 
      "Specifications" :> {{$CellContext`j$$, 1, 127, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{610., {328.2010498046875, 336.7989501953125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.8593586432705483`*^9, 3.859358710366386*^9, 3.8593589810688696`*^9, 
   3.8593658994195766`*^9, {3.8593661288697004`*^9, 3.8593661670738854`*^9}, 
   3.8593664097607665`*^9, 3.8593665597183437`*^9, 3.859366680347243*^9, 
   3.8593672573592463`*^9, 3.8593673795062323`*^9, 3.8593694420352025`*^9, 
   3.8593713649541874`*^9, 3.859373747641469*^9, 3.8593744050660715`*^9, 
   3.8593752154584236`*^9, {3.859382850752137*^9, 3.8593828617307653`*^9}, {
   3.8593830009917307`*^9, 3.8593830036858845`*^9}, {3.8593833396761017`*^9, 
   3.859383342285251*^9}, 3.859383401500638*^9, 3.859383495192997*^9, {
   3.8593835480000176`*^9, 3.859383571311351*^9}, 3.8593838613099375`*^9, 
   3.859384489199851*^9, 3.8593846090187044`*^9, {3.8593848963191366`*^9, 
   3.8593849163832846`*^9}, 3.859431792518446*^9, 3.8594319693535604`*^9, 
   3.859432063006917*^9},
 CellLabel->
  "Out[1486]=",ExpressionUUID->"d65e6ee6-105c-40ac-a520-f830f989f8aa"],

Cell[BoxData[
 TemplateBox[{
  "Part", "partd", 
   "\"Part specification \\!\\(\\*RowBox[{\\\"savedPerm\\\", \\\"\
\[LeftDoubleBracket]\\\", \\\"55\\\", \\\"\[RightDoubleBracket]\\\"}]\\) is \
longer than depth of object.\"", 2, 345, 11, 30093825131158965695, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.878887434582133*^9},
 CellLabel->"",ExpressionUUID->"30259f36-e518-4135-ad24-31b1219dec27"],

Cell[BoxData[
 TemplateBox[{
  "Part", "partd", 
   "\"Part specification \\!\\(\\*RowBox[{\\\"savedPerm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"55\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) is longer than depth of object.\"", 2, 345, 12,
    30093825131158965695, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8788874345982227`*^9},
 CellLabel->"",ExpressionUUID->"39c9ed9b-935b-42e9-8150-c1b66f215f40"],

Cell[BoxData[
 TemplateBox[{
  "Part", "pkspec1", 
   "\"The expression \\!\\(\\*RowBox[{\\\"savedPerm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"55\\\", \\\",\\\", \\\"1\\\"}], \\\"\
\[RightDoubleBracket]\\\"}]\\) cannot be used as a part specification.\"", 2, 
   345, 13, 30093825131158965695, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.878887434610482*^9},
 CellLabel->"",ExpressionUUID->"78816fbe-cf8d-4a25-87f0-3ed182d1a1de"],

Cell[BoxData[
 TemplateBox[{
  "Part", "pkspec1", 
   "\"The expression \\!\\(\\*RowBox[{\\\"savedPerm\\\", \\\"\
\[LeftDoubleBracket]\\\", RowBox[{\\\"55\\\", \\\",\\\", \
RowBox[{\\\"savedPerm\\\", \\\"\[LeftDoubleBracket]\\\", RowBox[{\\\"55\\\", \
\\\",\\\", \\\"1\\\"}], \\\"\[RightDoubleBracket]\\\"}]}], \\\"\
\[RightDoubleBracket]\\\"}]\\) cannot be used as a part specification.\"", 2, 
   345, 14, 30093825131158965695, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.878887434620546*^9},
 CellLabel->"",ExpressionUUID->"62e36cef-6176-42f6-84e7-ca6ab2644434"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1428., 862.5},
WindowMargins->{{Automatic, 0}, {Automatic, 86.25}},
Magnification:>1.5 Inherited,
FrontEndVersion->"13.1 for Microsoft Windows (64-bit) (August 22, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"625f1fa5-943c-4717-93d0-c270d57b82a2"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 355, 5, 146, "Title",ExpressionUUID->"b15229c8-5a8d-4e56-afb3-39951f71899b"],
Cell[CellGroupData[{
Cell[960, 31, 611, 9, 100, "Section",ExpressionUUID->"d8dca711-7222-4483-a9ec-b9d0ca08e28e"],
Cell[1574, 42, 170, 3, 52, "Text",ExpressionUUID->"591d67b5-7567-4a89-ab20-371f0f8ac8f8"],
Cell[1747, 47, 5095, 135, 528, "Input",ExpressionUUID->"45a6232c-391f-4210-9514-9e5d2300345f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6879, 187, 677, 11, 100, "Section",ExpressionUUID->"0df30b08-34d4-4ecd-a531-7a8c91a746de"],
Cell[CellGroupData[{
Cell[7581, 202, 1802, 47, 157, "Input",ExpressionUUID->"bd16330c-020d-4e25-9e43-640650c07835"],
Cell[9386, 251, 640, 13, 33, "Print",ExpressionUUID->"171a8f37-d473-416d-909f-bef09111b181"],
Cell[10029, 266, 60118, 1263, 481, "Output",ExpressionUUID->"af16ed3d-8aa8-4faf-9091-43c9d21e9e47"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[70196, 1535, 718, 12, 100, "Section",ExpressionUUID->"6045c388-2f2b-4767-9a08-97aaff3123e2"],
Cell[CellGroupData[{
Cell[70939, 1551, 312, 7, 67, "Subsubsection",ExpressionUUID->"0cc8be72-eacd-420d-9af0-32b8bf2826db"],
Cell[71254, 1560, 25204, 471, 28, "Input",ExpressionUUID->"ecdda7ec-fa69-4d39-bc74-0c1c937e0baf",
 CellOpen->False],
Cell[CellGroupData[{
Cell[96483, 2035, 6696, 143, 442, "Input",ExpressionUUID->"acf4e686-9a95-417c-9ebd-460e38edbdd4"],
Cell[103182, 2180, 648, 13, 41, "Message",ExpressionUUID->"1ed91fcc-1931-47cb-98ab-3e70b5ed4926"],
Cell[103833, 2195, 2069, 33, 33, "Print",ExpressionUUID->"d5d330f0-d45d-408c-9697-4a54632ef118"],
Cell[105905, 2230, 462, 10, 41, "Message",ExpressionUUID->"677bf3a6-6958-45c8-ac49-80bf830ac53d"],
Cell[106370, 2242, 589, 13, 41, "Message",ExpressionUUID->"9cad365b-5ee7-4ecf-b5fb-d80ffa7db4bb"],
Cell[106962, 2257, 563, 12, 41, "Message",ExpressionUUID->"33e3febd-b409-4537-a3b6-dc59091e1316"],
Cell[107528, 2271, 453, 11, 41, "Message",ExpressionUUID->"b756402d-28f7-4034-a90c-12e78ed08807"],
Cell[107984, 2284, 453, 11, 41, "Message",ExpressionUUID->"59c7445c-2e8e-417e-8c8f-e0353bc82e02"],
Cell[108440, 2297, 389, 9, 41, "Message",ExpressionUUID->"61a186b4-b88a-4b42-a802-ee0ac09757f5"],
Cell[108832, 2308, 62660, 1303, 811, "Output",ExpressionUUID->"0a365a70-60f0-4a45-b73e-c55cbf49dd20"],
Cell[171495, 3613, 386, 9, 41, "Message",ExpressionUUID->"31fdd8e8-5bed-45a2-b326-a39c74d5379a"],
Cell[171884, 3624, 2467, 36, 65, "Output",ExpressionUUID->"530d3c3e-7a0e-42cb-b129-b57be2b71e4e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174388, 3665, 1828, 45, 128, "Input",ExpressionUUID->"75f1c713-a4e6-4bdd-af8f-204ba6adb139"],
Cell[176219, 3712, 3065, 60, 692, "Output",ExpressionUUID->"d65e6ee6-105c-40ac-a520-f830f989f8aa"],
Cell[179287, 3774, 424, 8, 41, "Message",ExpressionUUID->"30259f36-e518-4135-ad24-31b1219dec27"],
Cell[179714, 3784, 462, 9, 41, "Message",ExpressionUUID->"39c9ed9b-935b-42e9-8150-c1b66f215f40"],
Cell[180179, 3795, 466, 9, 41, "Message",ExpressionUUID->"78816fbe-cf8d-4a25-87f0-3ed182d1a1de"],
Cell[180648, 3806, 593, 11, 41, "Message",ExpressionUUID->"62e36cef-6176-42f6-84e7-ca6ab2644434"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

